@@ -73,19 +73,19 @@ OC.L10N.register(
     "Where: %s" : "地點：%s",
     "%1$s via %2$s" : "%1$s 由 %2$s",
     "In the past on %1$s for the entire day" : "在過去 %1$s 的整天",
-    "_In a minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["將在 %n 分鐘之後於 %1$s 整天進行"],
-    "_In a hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["將在 %n 小時之後於 %1$s 整天進行"],
-    "_In a day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["將在 %n 天之後於 %1$s 整天進行"],
-    "_In a week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["將在 %n 星期之後於 %1$s 整天進行"],
-    "_In a month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["將在 %n 個月之後於 %1$s 整天進行"],
-    "_In a year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["將在 %n 年之後於 %1$s 整天進行"],
+    "_In %n minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["將在 %n 分鐘之後於 %1$s 整天進行"],
+    "_In %n hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["將在 %n 小時之後於 %1$s 整天進行"],
+    "_In %n day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["將在 %n 天之後於 %1$s 整天進行"],
+    "_In %n week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["將在 %n 星期之後於 %1$s 整天進行"],
+    "_In %n month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["將在 %n 個月之後於 %1$s 整天進行"],
+    "_In %n year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["將在 %n 年之後於 %1$s 整天進行"],
     "In the past on %1$s between %2$s - %3$s" : "於已經過去的 %1$s %2$s - %3$s 之間進行",
-    "_In a minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["將在 %n 分鐘之後於 %1$s %2$s - %3$s 之間進行"],
-    "_In a hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["將在 %n 小時之後於 %1$s %2$s - %3$s 之間進行"],
-    "_In a day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["將在 %n 天之後於 %1$s %2$s - %3$s 之間進行"],
-    "_In a week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["將在 %n 星期之後於 %1$s %2$s - %3$s 之間進行"],
-    "_In a month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["將在 %n 個月之後於 %1$s %2$s - %3$s 之間進行"],
-    "_In a year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["將在 %n 年之後於 %1$s %2$s - %3$s 之間進行"],
+    "_In %n minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["將在 %n 分鐘之後於 %1$s %2$s - %3$s 之間進行"],
+    "_In %n hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["將在 %n 小時之後於 %1$s %2$s - %3$s 之間進行"],
+    "_In %n day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["將在 %n 天之後於 %1$s %2$s - %3$s 之間進行"],
+    "_In %n week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["將在 %n 星期之後於 %1$s %2$s - %3$s 之間進行"],
+    "_In %n month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["將在 %n 個月之後於 %1$s %2$s - %3$s 之間進行"],
+    "_In %n year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["將在 %n 年之後於 %1$s %2$s - %3$s 之間進行"],
     "Could not generate when statement" : "無法產生 when 陳述",
     "Every Day for the entire day" : "每天一整天",
     "Every Day for the entire day until %1$s" : "每天一整天，直至 %1$s",
@@ -123,26 +123,26 @@ OC.L10N.register(
     "On specific dates for the entire day until %1$s" : "在特定日期的整天，直至 %1$s",
     "On specific dates between %1$s - %2$s until %3$s" : "在 %1$s - %2$s 之間的特定日期，直至 %3$s",
     "In the past on %1$s" : "於已經過去的 %1$s 進行",
-    "_In a minute on %1$s_::_In %n minutes on %1$s_" : ["將在 %n 分鐘之後於 %1$s 進行"],
-    "_In a hour on %1$s_::_In %n hours on %1$s_" : ["將在 %n 小時之後於 %1$s 進行"],
-    "_In a day on %1$s_::_In %n days on %1$s_" : ["將在 %n 天之後於 %1$s 進行"],
-    "_In a week on %1$s_::_In %n weeks on %1$s_" : ["將在 %n 星期之後於 %1$s 進行"],
-    "_In a month on %1$s_::_In %n months on %1$s_" : ["將在 %n 個月之後於 %1$s 進行"],
-    "_In a year on %1$s_::_In %n years on %1$s_" : ["將在 %n 年之後於 %1$s 進行"],
+    "_In %n minute on %1$s_::_In %n minutes on %1$s_" : ["將在 %n 分鐘之後於 %1$s 進行"],
+    "_In %n hour on %1$s_::_In %n hours on %1$s_" : ["將在 %n 小時之後於 %1$s 進行"],
+    "_In %n day on %1$s_::_In %n days on %1$s_" : ["將在 %n 天之後於 %1$s 進行"],
+    "_In %n week on %1$s_::_In %n weeks on %1$s_" : ["將在 %n 星期之後於 %1$s 進行"],
+    "_In %n month on %1$s_::_In %n months on %1$s_" : ["將在 %n 個月之後於 %1$s 進行"],
+    "_In %n year on %1$s_::_In %n years on %1$s_" : ["將在 %n 年之後於 %1$s 進行"],
     "In the past on %1$s then on %2$s" : "在過去的 %1$s，然後在 %2$s 進行",
-    "_In a minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["將在 %n 分鐘之後於 %1$s 進行，然後在 %2$s 再次進行"],
-    "_In a hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["將在 %n 小時之後於 %1$s 進行，然後在 %2$s 再次進行"],
-    "_In a day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["將在 %n 天之後於 %1$s 進行，然後在 %2$s 再次進行"],
-    "_In a week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["將在 %n 星期之後於 %1$s 進行，然後在 %2$s 再次進行"],
-    "_In a month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["將在 %n 個月之後於 %1$s 進行，然後在 %2$s 再次進行"],
-    "_In a year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["將在 %n 年之後於 %1$s 進行，然後在 %2$s 再次進行"],
+    "_In %n minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["將在 %n 分鐘之後於 %1$s 進行，然後在 %2$s 再次進行"],
+    "_In %n hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["將在 %n 小時之後於 %1$s 進行，然後在 %2$s 再次進行"],
+    "_In %n day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["將在 %n 天之後於 %1$s 進行，然後在 %2$s 再次進行"],
+    "_In %n week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["將在 %n 星期之後於 %1$s 進行，然後在 %2$s 再次進行"],
+    "_In %n month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["將在 %n 個月之後於 %1$s 進行，然後在 %2$s 再次進行"],
+    "_In %n year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["將在 %n 年之後於 %1$s 進行，然後在 %2$s 再次進行"],
     "In the past on %1$s then on %2$s and %3$s" : "在過去的 %1$s 進行，然後在 %2$s 及 %3$s 再次進行",
-    "_In a minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["將在 %n 分鐘之後於 %1$s 進行，然後在 %2$s 及 %3$s再次進行"],
-    "_In a hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["將在 %n 小時之後於 %1$s 進行，然後在 %2$s 及 %3$s再次進行"],
-    "_In a day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["將在 %n 天之後於 %1$s 進行，然後在 %2$s 及 %3$s再次進行"],
-    "_In a week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["將在 %n 星期之後於 %1$s 進行，然後在 %2$s 及 %3$s再次進行"],
-    "_In a month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["將在 %n 個月之後於 %1$s 進行，然後在 %2$s 及 %3$s再次進行"],
-    "_In a year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["將在 %n 年之後於 %1$s 進行，然後在 %2$s 及 %3$s再次進行"],
+    "_In %n minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["將在 %n 分鐘之後於 %1$s 進行，然後在 %2$s 及 %3$s再次進行"],
+    "_In %n hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["將在 %n 小時之後於 %1$s 進行，然後在 %2$s 及 %3$s再次進行"],
+    "_In %n day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["將在 %n 天之後於 %1$s 進行，然後在 %2$s 及 %3$s再次進行"],
+    "_In %n week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["將在 %n 星期之後於 %1$s 進行，然後在 %2$s 及 %3$s再次進行"],
+    "_In %n month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["將在 %n 個月之後於 %1$s 進行，然後在 %2$s 及 %3$s再次進行"],
+    "_In %n year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["將在 %n 年之後於 %1$s 進行，然後在 %2$s 及 %3$s再次進行"],
     "Could not generate next recurrence statement" : "無法產生下一個重複語句",
     "Cancelled: %1$s" : "已取消：%1$s",
     "\"%1$s\" has been canceled" : "\"%1$s\" 已被取消",
@@ -234,8 +234,8 @@ OC.L10N.register(
     "Could not rename part file to final file, canceled by hook" : "無法將部份檔案重新命名為最終檔案，被掛勾取消",
     "Could not rename part file to final file" : "無法將部份檔案重新命名為最終檔案",
     "Failed to check file size: %1$s" : "檢查檔案大小失敗：%1$s",
-    "Could not open file: %1$s, file does seem to exist" : "無法開啟檔案：%1$s，檔案似乎存在",
-    "Could not open file: %1$s, file doesn't seem to exist" : "無法開啟檔案：%1$s，檔案似乎不存在",
+    "Could not open file: %1$s (%2$d), file does seem to exist" : "無法開啟檔案：%1$s（%2$d），檔案似乎存在",
+    "Could not open file: %1$s (%2$d), file doesn't seem to exist" : "無法開啟檔案：%1$s（%2$d），檔案似乎不存在",
     "Encryption not ready: %1$s" : "尚未準備好加密：%1$s",
     "Failed to open file: %1$s" : "開啟檔案失敗：%1$s",
     "Failed to unlink: %1$s" : "解除連結失敗：%1$s",
@@ -280,8 +280,6 @@ OC.L10N.register(
     "Last day (inclusive)" : "最後一天（含）",
     "Out of office replacement (optional)" : "外出時的替代人員（非強制的）",
     "Name of the replacement" : "替代人員姓名",
-    "No results." : "沒有結果。",
-    "Start typing." : "開始輸入。",
     "Short absence status" : "短暫缺席狀態",
     "Long absence Message" : "長期缺席訊息",
     "Save" : "保存",
@@ -316,10 +314,6 @@ OC.L10N.register(
     "Import calendar event" : "導入日曆活動",
     "Uploading a new event will overwrite the existing one." : "上傳新活動將會覆寫原有的",
     "Upload event" : "上傳活動",
-    "Availability" : "空閒時間",
-    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "若您設定了您的工作時間，其他人仕在預約會議時就會知道您何時不在辦公室。",
-    "Absence" : "缺席",
-    "Configure your next absence period." : "設定您的下一個缺席時段。",
     "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "也安裝 {calendarappstoreopen}日曆應用程式{linkclose}或安裝{calendardocopen}以連接您的桌面電腦和流動裝置進行同步↗{linkclose}。",
     "Please make sure to properly set up {emailopen}the email server{linkclose}." : "請確保正確設置{emailopen}電郵伺服器{linkclose}。",
     "Calendar server" : "日曆伺服器",
@@ -334,11 +328,49 @@ OC.L10N.register(
     "Enable notifications for events via push" : "啟用推送活動通知",
     "Example content" : "範例內容",
     "Example content serves to showcase the features of Nextcloud. Default content is shipped with Nextcloud, and can be replaced by custom content." : "範例內容用來展示 Nextcloud 的功能。Nextcloud 隨附預設內容，可由自訂內容取代。",
+    "Availability" : "空閒時間",
+    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "若您設定了您的工作時間，其他人仕在預約會議時就會知道您何時不在辦公室。",
+    "Absence" : "缺席",
+    "Configure your next absence period." : "設定您的下一個缺席時段。",
     "There was an error updating your attendance status." : "更新您的參與狀況時發生錯誤",
     "Please contact the organizer directly." : "請直接聯繫絡主辦人",
     "Are you accepting the invitation?" : "接受邀請嗎？",
     "Tentative" : "暫定",
     "Your attendance was updated successfully." : "您的參與狀況成功更新",
+    "_In a minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["將在 %n 分鐘之後於 %1$s 整天進行"],
+    "_In a hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["將在 %n 小時之後於 %1$s 整天進行"],
+    "_In a day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["將在 %n 天之後於 %1$s 整天進行"],
+    "_In a week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["將在 %n 星期之後於 %1$s 整天進行"],
+    "_In a month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["將在 %n 個月之後於 %1$s 整天進行"],
+    "_In a year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["將在 %n 年之後於 %1$s 整天進行"],
+    "_In a minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["將在 %n 分鐘之後於 %1$s %2$s - %3$s 之間進行"],
+    "_In a hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["將在 %n 小時之後於 %1$s %2$s - %3$s 之間進行"],
+    "_In a day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["將在 %n 天之後於 %1$s %2$s - %3$s 之間進行"],
+    "_In a week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["將在 %n 星期之後於 %1$s %2$s - %3$s 之間進行"],
+    "_In a month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["將在 %n 個月之後於 %1$s %2$s - %3$s 之間進行"],
+    "_In a year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["將在 %n 年之後於 %1$s %2$s - %3$s 之間進行"],
+    "_In a minute on %1$s_::_In %n minutes on %1$s_" : ["將在 %n 分鐘之後於 %1$s 進行"],
+    "_In a hour on %1$s_::_In %n hours on %1$s_" : ["將在 %n 小時之後於 %1$s 進行"],
+    "_In a day on %1$s_::_In %n days on %1$s_" : ["將在 %n 天之後於 %1$s 進行"],
+    "_In a week on %1$s_::_In %n weeks on %1$s_" : ["將在 %n 星期之後於 %1$s 進行"],
+    "_In a month on %1$s_::_In %n months on %1$s_" : ["將在 %n 個月之後於 %1$s 進行"],
+    "_In a year on %1$s_::_In %n years on %1$s_" : ["將在 %n 年之後於 %1$s 進行"],
+    "_In a minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["將在 %n 分鐘之後於 %1$s 進行，然後在 %2$s 再次進行"],
+    "_In a hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["將在 %n 小時之後於 %1$s 進行，然後在 %2$s 再次進行"],
+    "_In a day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["將在 %n 天之後於 %1$s 進行，然後在 %2$s 再次進行"],
+    "_In a week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["將在 %n 星期之後於 %1$s 進行，然後在 %2$s 再次進行"],
+    "_In a month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["將在 %n 個月之後於 %1$s 進行，然後在 %2$s 再次進行"],
+    "_In a year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["將在 %n 年之後於 %1$s 進行，然後在 %2$s 再次進行"],
+    "_In a minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["將在 %n 分鐘之後於 %1$s 進行，然後在 %2$s 及 %3$s再次進行"],
+    "_In a hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["將在 %n 小時之後於 %1$s 進行，然後在 %2$s 及 %3$s再次進行"],
+    "_In a day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["將在 %n 天之後於 %1$s 進行，然後在 %2$s 及 %3$s再次進行"],
+    "_In a week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["將在 %n 星期之後於 %1$s 進行，然後在 %2$s 及 %3$s再次進行"],
+    "_In a month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["將在 %n 個月之後於 %1$s 進行，然後在 %2$s 及 %3$s再次進行"],
+    "_In a year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["將在 %n 年之後於 %1$s 進行，然後在 %2$s 及 %3$s再次進行"],
+    "Could not open file: %1$s, file does seem to exist" : "無法開啟檔案：%1$s，檔案似乎存在",
+    "Could not open file: %1$s, file doesn't seem to exist" : "無法開啟檔案：%1$s，檔案似乎不存在",
+    "No results." : "沒有結果。",
+    "Start typing." : "開始輸入。",
     "Time zone:" : "時區："
 },
 "nplurals=1; plural=0;");
