@@ -108,6 +108,43 @@ OC.L10N.register(
     "Type" : "Mota",
     "Active filters" : "Iragazki aktiboak",
     "Remove filter" : "Kendu iragazkia",
+    "Appearance" : "Itxura",
+    "Show hidden files" : "Erakutsi ezkutuko fitxategiak",
+    "Show file type column" : "Erakutsi fitxategi luzapenen zutabea",
+    "Show file extensions" : "Erakutsi fitxategien luzapena",
+    "Crop image previews" : "Moztu irudien aurrebistak",
+    "General" : "Orokorra",
+    "Sort favorites first" : "Ordenatu gogokoak lehenengo",
+    "Sort folders before files" : "Ordenatu karpetak fitxategien aurretik",
+    "Enable folder tree view" : "Gaitu karpeten zuhaitz ikuspegia",
+    "Default view" : "Ikuspegi lehenetsia",
+    "All files" : "Fitxategi guztiak",
+    "Personal files" : "Fitxategi pertsonalak",
+    "Additional settings" : "Ezarpen gehiago",
+    "Actions" : "Ekintzak",
+    "File actions" : "Fitxategi ekintzak",
+    "Selection" : "Hautapena",
+    "Select all files" : "Fitxategi guztiak aukeratu",
+    "Deselect all" : "Deshautatu dena",
+    "Select or deselect" : "Hautatu edo desautatu",
+    "Select a range" : "Hautatu tarte bat",
+    "Navigation" : "Nabigazioa",
+    "Go to parent folder" : "Joan karpeta gurasora",
+    "Go to file above" : "Joan goiko fitxategira",
+    "Go to file below" : "Joan beheko fitxategira",
+    "Go left in grid" : "Joan ezkerrera saretan",
+    "Go right in grid" : "Joan eskuinera saretan",
+    "View" : "Ikusi",
+    "Toggle grid view" : "Txandakatu sareta ikuspegia",
+    "Open file sidebar" : "Ireki alboko barra",
+    "Show those shortcuts" : "Erakutsi lasterbide horiek",
+    "Warnings" : "Oharrak",
+    "Warn before changing a file extension" : "Abisatu fitxategiaren luzapena aldatu aurretik",
+    "Warn before deleting a file" : "Abisatu fitxategi bat ezabatu aurretik",
+    "WebDAV URL" : "WebDAV URLa",
+    "Create an app password" : "Sortu aplikazioaren pasahitza",
+    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "WebDAV autentifikaziorako beharrezkoa da, kontu honetan bi faktoreko autentifikazioa gaituta dagoelako.",
+    "How to access files using WebDAV" : "Nola sartu fitxategietara WebDAV erabiliz",
     "Total rows summary" : "Errenkaden guztirako laburpena",
     "Toggle selection for all files and folders" : "Ordeztu hautatutako fitxategi eta karpeta guztiak",
     "Name" : "Izena",
@@ -116,7 +153,6 @@ OC.L10N.register(
     "{displayName}: failed on some elements" : "{displayName}: huts egin du elementu batzuetan",
     "{displayName}: done" : "{displayName}: egina",
     "{displayName}: failed" : "{displayName}: huts egin du",
-    "Actions" : "Ekintzak",
     "(selected)" : "(hautatuta)",
     "List of files and folders." : "Fitxategi eta karpeten zerrenda.",
     "You have used your space quota and cannot upload files anymore." : "Zure espazio-kuota erabili duzu eta ezin duzu fitxategi gehiago kargatu.",
@@ -124,8 +160,11 @@ OC.L10N.register(
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Zerrenda hau ez da guztiz ikusten errendimendu arrazoiengatik. Fitxategiak zerrendan zehar nabigatzen duten heinean bistaratuko dira.",
     "File not found" : "Ez da fitxategia aurkitu",
     "_{count} selected_::_{count} selected_" : ["{count} hautatuta","{count} hautatuta"],
+    "Search everywhere …" : "Bilatu nonahi …",
+    "Search here …" : "Bilatu hemen …",
     "Search scope options" : "Bilaketa-eremuaren aukerak",
     "Search here" : "Bilatu hemen",
+    "Owner" : "Jabea",
     "{usedQuotaByte} used" : "{usedQuotaByte} erabilita",
     "{used} of {quota} used" : "{used} / {quota} erabilita",
     "{relative}% used" : "%{relative} erabilita",
@@ -142,6 +181,7 @@ OC.L10N.register(
     "Failed to refresh filename sanitization status." : "Ezin izan da fitxategi-izenen garbiketa egoera freskatu.",
     "Filename sanitization in progress." : "Fitxategi-izenen garbiketa martxan da.",
     "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Une honetan {totalUsers}kontuetatik {processedUsers}prozesatu dira.",
+    "Preparing …" : "Prestatzen …",
     "Refresh" : "Freskatu",
     "All files have been santized for Windows filename support." : "Fitxategi guztiak garbitu dira Windows-en fitxategi-izenaren onarpenerako.",
     "Some files could not be sanitized, please check your logs." : "Fitxategi batzuk ezin izan dira garbitu, begiratu erregistroak.",
@@ -156,6 +196,7 @@ OC.L10N.register(
     "Sanitize filenames" : "Garbitu fitxategi-izenak",
     "(starting)" : "(abiatzen)",
     "Fill template fields" : "Bete txantiloien eremuak",
+    "Submitting fields …" : "Eremuak bidaltzen …",
     "Submit" : "Bidali",
     "Choose a file or folder to transfer" : "Aukeratu fitxategi edo karpeta bat transferitzeko",
     "Transfer" : "Transferitu",
@@ -179,51 +220,7 @@ OC.L10N.register(
     "Do not show this dialog again." : "Ez erakutsi elkarrizketa hau berriro",
     "Select file or folder to link to" : "Hautatu estekatzeko fitxategia edo karpeta",
     "Choose {file}" : "Aukeratu {file}",
-    "Clipboard is not available" : "Arbela ez dago erabilgarri",
-    "WebDAV URL copied" : "WebDAV URLa kopiatu da",
     "Files settings" : "FItxategien ezarpenak",
-    "General" : "Orokorra",
-    "Default view" : "Ikuspegi lehenetsia",
-    "All files" : "Fitxategi guztiak",
-    "Personal files" : "Fitxategi pertsonalak",
-    "Sort favorites first" : "Ordenatu gogokoak lehenengo",
-    "Sort folders before files" : "Ordenatu karpetak fitxategien aurretik",
-    "Folder tree" : "Fitxategien zuhaitza",
-    "Appearance" : "Itxura",
-    "Show hidden files" : "Erakutsi ezkutuko fitxategiak",
-    "Show file type column" : "Erakutsi fitxategi luzapenen zutabea",
-    "Show file extensions" : "Erakutsi fitxategien luzapena",
-    "Crop image previews" : "Moztu irudien aurrebistak",
-    "Additional settings" : "Ezarpen gehiago",
-    "WebDAV" : "WebDAV",
-    "WebDAV URL" : "WebDAV URLa",
-    "Copy" : "Kopiatu",
-    "How to access files using WebDAV" : "Nola sartu fitxategietara WebDAV erabiliz",
-    "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client." : "Bi faktoreko autentifikazioa aktibatuta dago zure kontuan, eta, beraz, aplikazioaren pasahitza erabili behar duzu kanpoko WebDAV bezero bat konektatzeko.",
-    "Warnings" : "Oharrak",
-    "Warn before changing a file extension" : "Abisatu fitxategiaren luzapena aldatu aurretik",
-    "Warn before deleting files" : "Abisatu fitxategiak ezabatu aurretik",
-    "Keyboard shortcuts" : "Teklatuaren lasterbideak",
-    "File actions" : "Fitxategi ekintzak",
-    "Rename" : "Berrizendatu",
-    "Delete" : "Ezabatu",
-    "Add or remove favorite" : "Gehitu edo kendu gogokoetatik",
-    "Manage tags" : "Kudeatu etiketak",
-    "Selection" : "Hautapena",
-    "Select all files" : "Fitxategi guztiak aukeratu",
-    "Deselect all" : "Deshautatu dena",
-    "Select or deselect" : "Hautatu edo desautatu",
-    "Select a range" : "Hautatu tarte bat",
-    "Navigation" : "Nabigazioa",
-    "Go to parent folder" : "Joan karpeta gurasora",
-    "Go to file above" : "Joan goiko fitxategira",
-    "Go to file below" : "Joan beheko fitxategira",
-    "Go left in grid" : "Joan ezkerrera saretan",
-    "Go right in grid" : "Joan eskuinera saretan",
-    "View" : "Ikusi",
-    "Toggle grid view" : "Txandakatu sareta ikuspegia",
-    "Open file sidebar" : "Ireki alboko barra",
-    "Show those shortcuts" : "Erakutsi lasterbide horiek",
     "Share" : "Partekatu",
     "Shared by link" : "Esteka bidez partekatuta",
     "Shared" : "Partekatuta",
@@ -242,14 +239,7 @@ OC.L10N.register(
     "Upload some content or sync with your devices!" : "Igo edukiren bat edo sinkronizatu zure gailuekin!",
     "Go back" : "Atzera",
     "Views" : "Ikuspegiak",
-    "You" : "Zu ",
-    "Shared multiple times with different people" : "Hainbat aldiz partekatua pertsona ezberdinekin",
-    "Unable to change the favorite state of the file" : "Ezin da fitxategiaren gogoko egoera aldatu",
-    "Error while loading the file data" : "Errorea fitxategiaren datuak kargatzerakoan",
-    "Owner" : "Jabea",
-    "Remove from favorites" : "Kendu gogokoetatik",
-    "Add to favorites" : "Gehitu gogokoetara",
-    "Tags" : "Etiketak",
+    "Loading …" : "Kargatzen …",
     "Your files" : "Zure fitxategiak",
     "Open in files" : "Ireki Fitxategiak aplikazioan",
     "File cannot be accessed" : "Ezin da fitxategia atzitu",
@@ -268,16 +258,20 @@ OC.L10N.register(
     "Create a new file with the selected template" : "Sortu fitxategi berria hautatutako txantiloiarekin",
     "Creating file" : "Fitxategia sortzen",
     "Save as {displayName}" : "Gorde honela: {displayName}",
+    "Save as …" : "Gorde honela …",
+    "Converting files …" : "Fitxategiak bihurtzen …",
     "Failed to convert files: {message}" : "Huts egin du fitxategiak bihurtzeak: {message}",
     "All files failed to be converted" : "Huts egin du fitxategi guztiak bihurtzean",
     "One file could not be converted: {message}" : "Fitxategi bat ezin izan da bihurtu: {message}",
-    "_One file could not be converted_::_%n files could not be converted_" : ["Fitxategi bat ezin izan da bihurtu","%n fitxategi ezin izan dira bihurtu"],
-    "_One file successfully converted_::_%n files successfully converted_" : ["Fitxategi bat behar bezala bihurtu da","%n fitxategi behar bezala bihurtu dira"],
-    "Files successfully converted" : "Fitxategiak behar bezala bihurtu dira",
+    "_%n file could not be converted_::_%n files could not be converted_" : ["Fitxategi %n ezin izan da bihurtu","%n fitxategi ezin izan dira bihurtu"],
+    "_%n file converted_::_%n files converted_" : ["Fitxategi %n bihurtu da","%n fitxategi bihurtu dira"],
+    "Files converted" : "Fitxategiak bihurtu dira",
     "Failed to convert files" : "Huts egin du fitxategien bihurtzeak",
+    "Converting file …" : "Fitxategia bihurtzen …",
     "File successfully converted" : "Fitxategia behar bezala bihurtu da",
     "Failed to convert file: {message}" : "Fitxategi honen bihurtzeak huts egin du: {message}",
     "Failed to convert file" : "Huts egin du fitxategiaren bihurtzeak",
+    "Delete" : "Ezabatu",
     "Leave this share" : "Utzi partekatze hau",
     "Leave these shares" : "Utzi partekatze hauek",
     "Disconnect storage" : "Deskonektatu biltegia",
@@ -295,6 +289,11 @@ OC.L10N.register(
     "Download" : "Deskargatu",
     "The requested file is not available." : "Eskatutako fitxategia ez dago eskuragarri.",
     "The requested files are not available." : "Eskatutako fitxategiak ez daude eskuragarri.",
+    "Add to favorites" : "Gehitu gogokoetara",
+    "Remove from favorites" : "Kendu gogokoetatik",
+    "Add or remove favorite" : "Gehitu edo kendu gogokoetatik",
+    "Moving \"{source}\" to \"{destination}\" …" : "\"{source}\"  \"{destination}\"-ra eramaten …",
+    "Copying \"{source}\" to \"{destination}\" …" : " \"{source}\" \"{destination}\"-ra kopiatzen …",
     "Destination is not a folder" : "Helburua ez da karpeta bat",
     "This file/folder is already in that directory" : "Fitxategi/karpeta hau dagoeneko karpeta horretan dago",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Ezin duzu fitxategi/karpeta bat berera edo bere azpikarpeta batera mugitu",
@@ -305,10 +304,12 @@ OC.L10N.register(
     "The file does not exist anymore" : "Fitxategia ez da existizen dagoeneko",
     "Choose destination" : "Aukeratu helburua",
     "Copy to {target}" : "Kopiatu hona: {target}",
+    "Copy" : "Kopiatu",
     "Move to {target}" : "Mugitu hona: {target}",
     "Move" : "Mugitu",
     "Move or copy operation failed" : "Mugitzeko edo kopiatzeko eragiketak huts egin du",
     "Move or copy" : "Mugitu edo kopiatu",
+    "Open folder" : "Ireki karpeta",
     "Open folder {displayName}" : "Ireki {displayName} karpeta",
     "Open in Files" : "Ireki Fitxategiak aplikazioan",
     "Open locally" : "Ireki lokalean",
@@ -317,7 +318,9 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Fitxategia orain zure gailuan ireki beharko litzateke. Hala ez bada, egiaztatu mahaigaineko aplikazioa instalatuta duzula.",
     "Retry and close" : "Saiatu berriro eta itxi",
     "Open online" : "Ireki linean",
+    "Rename" : "Berrizendatu",
     "Details" : "Xehetasunak",
+    "Unfavorite" : "Kendu gogokoetatik",
     "View in folder" : "Ikusi karpetan",
     "Today" : "Gaur",
     "Last 7 days" : "Azken 7 egunetan",
@@ -372,6 +375,7 @@ OC.L10N.register(
     "No favorites yet" : "Gogokorik ez oraindik",
     "Files and folders you mark as favorite will show up here" : "Gogokotzat markatutako fitxategi eta karpetak hemen agertuko dira",
     "List of your files and folders." : "Zure fitxategi eta karpeten zerrenda.",
+    "Folder tree" : "Fitxategien zuhaitza",
     "List of your files and folders that are not shared." : "Partekatu ez diren zure fitxategi eta karpeten zerrenda.",
     "No personal files found" : "Ez dago fitxategi pertsonalik",
     "Files that are not shared will show up here." : "Partekatu ez dituzun fitxategiak hemen agertuko dira",
@@ -396,14 +400,17 @@ OC.L10N.register(
     "Submitting fields …" : "Bidaltzeko eremuak",
     "\"{displayName}\" action executed successfully" : "\"{displayName}\" ekintza behar bezala exekutatu da",
     "Filter file names …" : "Iragazi fitxategien izenak...",
+    "Clipboard is not available" : "Arbela ez dago erabilgarri",
     "WebDAV URL copied to clipboard" : "WebDAV URLa arbelean kopiatu da",
     "Enable the grid view" : "Gaitu sareta ikuspegira",
     "Enable folder tree" : "Gaitu karpeta-zuhaitza",
+    "WebDAV" : "WebDAV",
     "Copy to clipboard" : "Kopiatu arbelera",
     "Use this address to access your Files via WebDAV" : "Erabili helbide hau WebDAV bidez zure fitxategietara sartzeko",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "2FA gaitu baduzu, aplikazioaren pasahitz berria sortu eta erabili behar duzu hemen klik eginez.",
     "Prevent warning dialogs from open or reenable them." : "Ohar-elkarrizketak ez irekitzea edo berriro aktibatzea.",
     "Show a warning dialog when changing a file extension." : "Erakutsi oharra fitxategi baten luzapena aldatzean",
+    "Keyboard shortcuts" : "Teklatuaren lasterbideak",
     "Speed up your Files experience with these quick shortcuts." : "Azkartu zure Fitxategi esperientzia lasterbide bizkor hauekin",
     "Open the actions menu for a file" : "Ireki ekintza menua fitxategi baterako",
     "Rename a file" : "Fitxategi bat berrizendatu",
@@ -420,6 +427,11 @@ OC.L10N.register(
     "Navigate to the file on the right (in grid mode)" : "Nabigatu eskuineko fitxategira (sareta moduan)",
     "Toggle the grid view" : "Txandakatu sareta ikuspegia",
     "Open the sidebar for a file" : "Ireki alboko barra fitxategi baterako",
+    "You" : "Zu ",
+    "Shared multiple times with different people" : "Hainbat aldiz partekatua pertsona ezberdinekin",
+    "Unable to change the favorite state of the file" : "Ezin da fitxategiaren gogoko egoera aldatu",
+    "Error while loading the file data" : "Errorea fitxategiaren datuak kargatzerakoan",
+    "Tags" : "Etiketak",
     "Save as …" : "Gorde honela...",
     "Converting files …" : "Fitxategiak bihurtzen...",
     "Converting file …" : "Fitxategia bihurtzen...",
