@@ -45,7 +45,7 @@ OC.L10N.register(
     "A favorite file or folder has been <strong>changed</strong>" : "<strong>Cambiouse</strong> un ficheiro ou cartafol favorito",
     "Failed to authorize" : "Produciuse un fallo ao autorizar",
     "Invalid folder path" : "A ruta ao cartafol non é correcta.",
-    "Folder not found" : "Non se atopou o cartafolNon se atopou o cartafol",
+    "Folder not found" : "Non se atopou o cartafol",
     "The file cannot be found" : "Non é posíbel atopar o ficheiro",
     "The destination path does not exist: %1$s" : "Non existe a ruta de destino: %1$s",
     "You do not have permission to create a file at the specified location" : "Vde. non ten permiso para crear un ficheiro na localización especificada",
@@ -108,6 +108,43 @@ OC.L10N.register(
     "Type" : "Escribir",
     "Active filters" : "Filtros activos",
     "Remove filter" : "Retirar o filtro",
+    "Appearance" : "Aparencia",
+    "Show hidden files" : "Amosar os ficheiros agochados",
+    "Show file type column" : "Amosar a columna de tipo de ficheiro",
+    "Show file extensions" : "Amosar as extensións de ficheiro",
+    "Crop image previews" : "Recortar a vista previa das imaxes",
+    "General" : "Xeral",
+    "Sort favorites first" : "Ordenar primeiro os favoritos",
+    "Sort folders before files" : "Ordenar os cartafoles antes que os ficheiros",
+    "Enable folder tree view" : "Activar a vista en árbore de cartafoles",
+    "Default view" : "Vista predeterminada",
+    "All files" : "Todos os ficheiros",
+    "Personal files" : "Ficheiros persoais",
+    "Additional settings" : "Axustes adicionais",
+    "Actions" : "Accións",
+    "File actions" : "Accións de ficheiro",
+    "Selection" : "Selección",
+    "Select all files" : "Seleccionar todos os ficheiros",
+    "Deselect all" : "Deseleccionar todo",
+    "Select or deselect" : "Seleccionar ou deseleccionar",
+    "Select a range" : "Seleccionar un intervalo",
+    "Navigation" : "Navegación",
+    "Go to parent folder" : "Ir ao cartafol superior",
+    "Go to file above" : "Ir ao ficheiro de arriba",
+    "Go to file below" : "Ir ao ficheiro de abaixo",
+    "Go left in grid" : "Ir á esquerda na grella",
+    "Go right in grid" : "Ir á dereita na grella",
+    "View" : "Ver",
+    "Toggle grid view" : "Alternar a vista como grade",
+    "Open file sidebar" : "Abrir a barra lateral do ficheiro",
+    "Show those shortcuts" : "Amosar eses atallos",
+    "Warnings" : "Advertencias",
+    "Warn before changing a file extension" : "Advertir antes de cambiar unha extensión de ficheiro",
+    "Warn before deleting a file" : "Advertir antes de borrar un ficheiro",
+    "WebDAV URL" : "URL de WebDAV",
+    "Create an app password" : "Crear un contrasinal de aplicación",
+    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "É necesario para a autenticación WebDAV porque a autenticación de dous factores está activada para esta conta.",
+    "How to access files using WebDAV" : "Como acceder aos ficheiros empregando WebDAV",
     "Total rows summary" : "Resumo total de filas",
     "Toggle selection for all files and folders" : "Conmutar a selección para todos os ficheiros e cartafoles",
     "Name" : "Nome",
@@ -116,7 +153,6 @@ OC.L10N.register(
     "{displayName}: failed on some elements" : "Produciuse un fallo nalgúns elementos de {displayName}",
     "{displayName}: done" : "{displayName}: feito",
     "{displayName}: failed" : "{displayName}: produciuse un fallo",
-    "Actions" : "Accións",
     "(selected)" : "(seleccionado)",
     "List of files and folders." : "Lista de ficheiros e cartafoles",
     "You have used your space quota and cannot upload files anymore." : "Vde. usou a súa cota de espazo e xa non pode enviar ningún ficheiro más",
@@ -128,6 +164,7 @@ OC.L10N.register(
     "Search here …" : "Buscar aquí…",
     "Search scope options" : "Opcións do alcance da busca",
     "Search here" : "Buscar aquí",
+    "Owner" : "Propietario",
     "{usedQuotaByte} used" : "{usedQuotaByte} usado",
     "{used} of {quota} used" : "Usados {used} de {quota}",
     "{relative}% used" : "{relative}% usado",
@@ -183,51 +220,7 @@ OC.L10N.register(
     "Do not show this dialog again." : "Non volver amosar este diálogo",
     "Select file or folder to link to" : "Seleccione o ficheiro ou cartafol ao que ligar",
     "Choose {file}" : "Escoller {file}",
-    "Clipboard is not available" : "O portapapeis non está dispoñíbel",
-    "WebDAV URL copied" : "URL de WebDAV copiado",
     "Files settings" : "Axustes de Ficheiros",
-    "General" : "Xeral",
-    "Default view" : "Vista predeterminada",
-    "All files" : "Todos os ficheiros",
-    "Personal files" : "Ficheiros persoais",
-    "Sort favorites first" : "Ordenar primeiro os favoritos",
-    "Sort folders before files" : "Ordenar os cartafoles antes que os ficheiros",
-    "Folder tree" : "Árbore de cartafoles",
-    "Appearance" : "Aparencia",
-    "Show hidden files" : "Amosar os ficheiros agochados",
-    "Show file type column" : "Amosar a columna de tipo de ficheiro",
-    "Show file extensions" : "Amosar as extensións de ficheiro",
-    "Crop image previews" : "Recortar a vista previa das imaxes",
-    "Additional settings" : "Axustes adicionais",
-    "WebDAV" : "WebDAV",
-    "WebDAV URL" : "URL de WebDAV",
-    "Copy" : "Copiar",
-    "How to access files using WebDAV" : "Como acceder aos ficheiros empregando WebDAV",
-    "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client." : "A autenticación de dous factores está activada para a súa conta e, polo tanto, necesita usar un contrasinal de aplicación para conectar un cliente WebDAV externo.",
-    "Warnings" : "Advertencias",
-    "Warn before changing a file extension" : "Advertir antes de cambiar unha extensión de ficheiro",
-    "Warn before deleting files" : "Advertir antes de borrar ficheiros",
-    "Keyboard shortcuts" : "Atallos de teclado",
-    "File actions" : "Accións de ficheiro",
-    "Rename" : "Cambiar o nome",
-    "Delete" : "Eliminar",
-    "Add or remove favorite" : "Engadir ou retirar favoritos",
-    "Manage tags" : "Xestionar as etiquetas",
-    "Selection" : "Selección",
-    "Select all files" : "Seleccionar todos os ficheiros",
-    "Deselect all" : "Deseleccionar todo",
-    "Select or deselect" : "Seleccionar ou deseleccionar",
-    "Select a range" : "Seleccionar un intervalo",
-    "Navigation" : "Navegación",
-    "Go to parent folder" : "Ir ao cartafol superior",
-    "Go to file above" : "Ir ao ficheiro de arriba",
-    "Go to file below" : "Ir ao ficheiro de abaixo",
-    "Go left in grid" : "Ir á esquerda na grella",
-    "Go right in grid" : "Ir á dereita na grella",
-    "View" : "Ver",
-    "Toggle grid view" : "Alternar a vista como grade",
-    "Open file sidebar" : "Abrir a barra lateral do ficheiro",
-    "Show those shortcuts" : "Amosar eses atallos",
     "Share" : "Compartir",
     "Shared by link" : "Compartido por ligazón",
     "Shared" : "Compartido",
@@ -246,14 +239,7 @@ OC.L10N.register(
     "Upload some content or sync with your devices!" : "Envíe algún contido ou sincronice cos seus dispositivos!",
     "Go back" : "Volver",
     "Views" : "Vistas",
-    "You" : "Vde.",
-    "Shared multiple times with different people" : "Compartido varias veces con diferentes persoas",
-    "Unable to change the favorite state of the file" : "Non é posíbel cambiar o estado de favorito do ficheiro",
-    "Error while loading the file data" : "Produciuse un erro ao cargar os datos do ficheiro",
-    "Owner" : "Propietario",
-    "Remove from favorites" : "Retirar de favoritos",
-    "Add to favorites" : "Engadir a favoritos",
-    "Tags" : "Etiquetas",
+    "Loading …" : "Cargando…",
     "Your files" : "Os seus ficheiros",
     "Open in files" : "Abrir en ficheiros",
     "File cannot be accessed" : "Non é posíbel acceder ao ficheiro",
@@ -277,14 +263,15 @@ OC.L10N.register(
     "Failed to convert files: {message}" : "Produciuse un fallo ao converter os ficheiros: {message}",
     "All files failed to be converted" : "Non foi posíbel converter ningún ficheiro",
     "One file could not be converted: {message}" : "Non foi posíbel converter un ficheiro: {message}",
-    "_One file could not be converted_::_%n files could not be converted_" : ["Non foi posíbel converter un ficheiro","Non foi posíbel converter %n ficheiros"],
-    "_One file successfully converted_::_%n files successfully converted_" : ["Foi convertido correctamente un ficheiro","%n ficheiros foron convertidos correctamente"],
-    "Files successfully converted" : "Os ficheiros foron convertidos correctamente",
+    "_%n file could not be converted_::_%n files could not be converted_" : ["Non foi posíbel converter %n ficheiro","Non foi posíbel converter %n ficheiros"],
+    "_%n file converted_::_%n files converted_" : ["%n ficheiro convertido","%n ficheiros convertidos"],
+    "Files converted" : "Ficheiros convertidos",
     "Failed to convert files" : "Produciuse un fallo ao converter os ficheiros",
     "Converting file …" : "Convertendo o ficheiro…",
     "File successfully converted" : "O ficheiro foi convertido correctamente",
     "Failed to convert file: {message}" : "Produciuse un fallo ao converter o ficheiro: {message}",
     "Failed to convert file" : "Produciuse un fallo ao converter o ficheiro",
+    "Delete" : "Eliminar",
     "Leave this share" : "Deixar esta compartición",
     "Leave these shares" : "Deixar estas comparticións",
     "Disconnect storage" : "Desconectar o almacenamento",
@@ -302,6 +289,9 @@ OC.L10N.register(
     "Download" : "Descargar",
     "The requested file is not available." : "O ficheiro solicitado non está dispoñíbel.",
     "The requested files are not available." : "Os ficheiros solicitados non están dispoñíbeis",
+    "Add to favorites" : "Engadir a favoritos",
+    "Remove from favorites" : "Retirar de favoritos",
+    "Add or remove favorite" : "Engadir ou retirar favoritos",
     "Moving \"{source}\" to \"{destination}\" …" : "Movendo «{source}» a «{destination}»…",
     "Copying \"{source}\" to \"{destination}\" …" : "Copiando «{source}» en «{destination}»…",
     "Destination is not a folder" : "O destino non é un cartafol",
@@ -314,10 +304,12 @@ OC.L10N.register(
     "The file does not exist anymore" : "O ficheiro xa non existe",
     "Choose destination" : "Escoller o destino",
     "Copy to {target}" : "Copiar en {target}",
+    "Copy" : "Copiar",
     "Move to {target}" : "Mover a {target}",
     "Move" : "Mover",
     "Move or copy operation failed" : "Produciuse un erro na operación de copia ou de movemento",
     "Move or copy" : "Mover ou copiar",
+    "Open folder" : "Abrir o cartafol",
     "Open folder {displayName}" : "Abrir o cartafol  {displayName}",
     "Open in Files" : "Abrir en Ficheiros",
     "Open locally" : "Abrir localmente",
@@ -326,7 +318,9 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "O ficheiro debería abrirse agora no seu dispositivo. Se non é así, comprobe se ten instalada a aplicación de escritorio.",
     "Retry and close" : "Tentar de novo e pechar",
     "Open online" : "Abrir en liña",
+    "Rename" : "Cambiar o nome",
     "Details" : "Detalles",
+    "Unfavorite" : "Retirar de favoritos",
     "View in folder" : "Ver no cartafol",
     "Today" : "Hoxe",
     "Last 7 days" : "Últimos 7 días",
@@ -352,7 +346,7 @@ OC.L10N.register(
     "One of the dropped files could not be processed" : "Non foi posíbel procesar un dos ficheiros arrastrados",
     "Your browser does not support the Filesystem API. Directories will not be uploaded" : "O seu navegador non é compatíbel coa API do sistema de ficheiros. Os directorios non van ser enviados",
     "No files to upload" : "Non hai ficheiros que enviar",
-    "Unable to create the directory {directory}" : "Non foi posíbel crear o directorio {directory}",
+    "Unable to create the directory {directory}" : "Non é posíbel crear o directorio {directory}",
     "Some files could not be uploaded" : "Non foi posíbel enviar algúns ficheiros",
     "Files uploaded successfully" : "Ficheiros enviados satisfactoriamente",
     "No files to process" : "Non hai ficheiros para procesar",
@@ -381,6 +375,7 @@ OC.L10N.register(
     "No favorites yet" : "Aínda non hai favoritos",
     "Files and folders you mark as favorite will show up here" : "Os ficheiros e cartafoles que marque como favoritos amosaranse aquí",
     "List of your files and folders." : "Lista dos seus ficheiros e cartafoles",
+    "Folder tree" : "Árbore de cartafoles",
     "List of your files and folders that are not shared." : "Lista dos seus ficheiros e cartafoles que non están a seren compartidos.",
     "No personal files found" : "Non se atopou ningún ficheiro persoal",
     "Files that are not shared will show up here." : "Os ficheiros que non se comparten amosaranse aquí.",
@@ -405,14 +400,17 @@ OC.L10N.register(
     "Submitting fields …" : "Enviando os campos...",
     "\"{displayName}\" action executed successfully" : "A acción «{displayName}» executouse correctamente",
     "Filter file names …" : "Filtrar os nomes de ficheiro…",
+    "Clipboard is not available" : "O portapapeis non está dispoñíbel",
     "WebDAV URL copied to clipboard" : "O URL de WebDAV foi copiado no portapapeis",
     "Enable the grid view" : "Activar a vista de grade",
     "Enable folder tree" : "Activar a árbore de cartafoles",
+    "WebDAV" : "WebDAV",
     "Copy to clipboard" : "Copiar no portapapeis.",
     "Use this address to access your Files via WebDAV" : "Empregue este enderezo para acceder ao seu Ficheiros mediante WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Se activou 2FA, cree e utilice un novo contrasinal de aplicación premendo aquí.",
     "Prevent warning dialogs from open or reenable them." : "Impedir abrir ou reactivar os diálogos de advertencia",
     "Show a warning dialog when changing a file extension." : "Amosar un diálogo de advertencia ao cambiar unha extensión de ficheiro.",
+    "Keyboard shortcuts" : "Atallos de teclado",
     "Speed up your Files experience with these quick shortcuts." : "Acelere a súa experiencia con Ficheiros con estes atallos rápidos.",
     "Open the actions menu for a file" : "Abrir o menú de accións dun ficheiro",
     "Rename a file" : "Cambiar o nome dun ficheiro",
@@ -429,6 +427,11 @@ OC.L10N.register(
     "Navigate to the file on the right (in grid mode)" : "Navegar ata o ficheiro da dereita (en modo de grade)",
     "Toggle the grid view" : "Cambiar á vista de grade",
     "Open the sidebar for a file" : "Abrir a barra lateral dun ficheiro",
+    "You" : "Vde.",
+    "Shared multiple times with different people" : "Compartido varias veces con diferentes persoas",
+    "Unable to change the favorite state of the file" : "Non é posíbel cambiar o estado de favorito do ficheiro",
+    "Error while loading the file data" : "Produciuse un erro ao cargar os datos do ficheiro",
+    "Tags" : "Etiquetas",
     "Save as …" : "Gardar como…",
     "Converting files …" : "Convertendo ficheiros…",
     "Converting file …" : "Convertendo o ficheiro…",
