@@ -108,6 +108,39 @@ OC.L10N.register(
     "Type" : "Tegund",
     "Active filters" : "Virkar síur",
     "Remove filter" : "Fjarlægja síu",
+    "Appearance" : "Útlit",
+    "Show hidden files" : "Sýna faldar skrár",
+    "Show file type column" : "Sýna dálk fyrir skráategund",
+    "Show file extensions" : "Birta skráaendingar",
+    "Crop image previews" : "Skera utan af forskoðun mynda",
+    "General" : "Almennt",
+    "Sort favorites first" : "Raða eftirlætum fremst",
+    "Sort folders before files" : "Raða möppum á undan skrám",
+    "Default view" : "Sjálfgefin sýn",
+    "All files" : "Allar skrár",
+    "Personal files" : "Einkaskrár",
+    "Additional settings" : "Valfrjálsar stillingar",
+    "Actions" : "Aðgerðir",
+    "File actions" : "Skráaaðgerðir",
+    "Selection" : "Val",
+    "Select all files" : "Velja allar skrár",
+    "Deselect all" : "Afvelja allt",
+    "Select or deselect" : "Velja eða afvelja",
+    "Select a range" : "Veldu svið",
+    "Navigation" : "Yfirsýn",
+    "Go to parent folder" : "Fara í yfirmöppu",
+    "Go to file above" : "Fara í skrá fyrir ofan",
+    "Go to file below" : "Fara í skrá fyrir neðan",
+    "Go left in grid" : "Fara til vinstri í reitum",
+    "Go right in grid" : "Fara til hægri í reitum",
+    "View" : "Skoða",
+    "Toggle grid view" : "Víxla reitasýn af/á",
+    "Open file sidebar" : "Opna hliðarspjald skráa",
+    "Show those shortcuts" : "Sýna þessa flýtilykla",
+    "Warnings" : "Aðvaranir",
+    "Warn before changing a file extension" : "Aðvara áður en skráarendingu er breytt",
+    "WebDAV URL" : "WebDAV-slóð",
+    "How to access files using WebDAV" : "Hvernig á að nálgast skrár í gegnum WebDAV",
     "Total rows summary" : "Samantek á fjölda raða",
     "Toggle selection for all files and folders" : "Víxla vali af/á fyrir allar skrár og möppur",
     "Name" : "Heiti",
@@ -116,7 +149,6 @@ OC.L10N.register(
     "{displayName}: failed on some elements" : "{displayName}: mistókst á einhverjum atriðum",
     "{displayName}: done" : "{displayName}: lokið",
     "{displayName}: failed" : "{displayName}: mistókst",
-    "Actions" : "Aðgerðir",
     "(selected)" : "(valið)",
     "List of files and folders." : "Listi yfir skrár og möppur.",
     "You have used your space quota and cannot upload files anymore." : "Þú hefur fullnýtt geymslukvótann þinn og getur ekki lengur sent inn skrár.",
@@ -128,6 +160,7 @@ OC.L10N.register(
     "Search here …" : "Leita hér …",
     "Search scope options" : "Valkostir leitarsviðs",
     "Search here" : "Leita hér",
+    "Owner" : "Eigandi",
     "{usedQuotaByte} used" : "{usedQuotaByte} notað",
     "{used} of {quota} used" : "{used} af {quota} notað",
     "{relative}% used" : "{relative}% notað",
@@ -183,51 +216,7 @@ OC.L10N.register(
     "Do not show this dialog again." : "Ekki sýna þennan glugga aftur.",
     "Select file or folder to link to" : "Veldu skrá eða möppu til að tengja í",
     "Choose {file}" : "Veldu {file}",
-    "Clipboard is not available" : "Klippispjald er ekki tiltækt",
-    "WebDAV URL copied" : "WebDAV-slóð afrituð",
     "Files settings" : "Stillingar skráaforritsins",
-    "General" : "Almennt",
-    "Default view" : "Sjálfgefin sýn",
-    "All files" : "Allar skrár",
-    "Personal files" : "Einkaskrár",
-    "Sort favorites first" : "Raða eftirlætum fremst",
-    "Sort folders before files" : "Raða möppum á undan skrám",
-    "Folder tree" : "Möppugreinar",
-    "Appearance" : "Útlit",
-    "Show hidden files" : "Sýna faldar skrár",
-    "Show file type column" : "Sýna dálk fyrir skráategund",
-    "Show file extensions" : "Birta skráaendingar",
-    "Crop image previews" : "Skera utan af forskoðun mynda",
-    "Additional settings" : "Valfrjálsar stillingar",
-    "WebDAV" : "WebDAV",
-    "WebDAV URL" : "WebDAV-slóð",
-    "Copy" : "Afrita",
-    "How to access files using WebDAV" : "Hvernig á að nálgast skrár í gegnum WebDAV",
-    "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client." : "Tveggja-þátta auðkenning fyrir aðganginn þinn er virk og þar með þarft þú að nota lykilorð forrits til að tengjast utanaðkomandi WebDAV-forriti.",
-    "Warnings" : "Aðvaranir",
-    "Warn before changing a file extension" : "Aðvara áður en skráarendingu er breytt",
-    "Warn before deleting files" : "Aðvara áður en skrám er eytt",
-    "Keyboard shortcuts" : "Flýtileiðir á lyklaborði",
-    "File actions" : "Skráaaðgerðir",
-    "Rename" : "Endurnefna",
-    "Delete" : "Eyða",
-    "Add or remove favorite" : "Bæta við eða fjarlægja eftirlæti",
-    "Manage tags" : "Sýsla með merki",
-    "Selection" : "Val",
-    "Select all files" : "Velja allar skrár",
-    "Deselect all" : "Afvelja allt",
-    "Select or deselect" : "Velja eða afvelja",
-    "Select a range" : "Veldu svið",
-    "Navigation" : "Yfirsýn",
-    "Go to parent folder" : "Fara í yfirmöppu",
-    "Go to file above" : "Fara í skrá fyrir ofan",
-    "Go to file below" : "Fara í skrá fyrir neðan",
-    "Go left in grid" : "Fara til vinstri í reitum",
-    "Go right in grid" : "Fara til hægri í reitum",
-    "View" : "Skoða",
-    "Toggle grid view" : "Víxla reitasýn af/á",
-    "Open file sidebar" : "Opna hliðarspjald skráa",
-    "Show those shortcuts" : "Sýna þessa flýtilykla",
     "Share" : "Deila",
     "Shared by link" : "Deilt með tengli",
     "Shared" : "Sameiginlegt",
@@ -246,14 +235,6 @@ OC.L10N.register(
     "Upload some content or sync with your devices!" : "Sendu inn eitthvað efni eða samstilltu við tækin þín!",
     "Go back" : "Fara til baka",
     "Views" : "Skoðun",
-    "You" : "Þú",
-    "Shared multiple times with different people" : "Deilt mörgum sinnum með mismunandi fólki",
-    "Unable to change the favorite state of the file" : "Get ekki breytt stöðu sem eftirlæti á skránni",
-    "Error while loading the file data" : "Villa við að hlaða inn skráagögnum",
-    "Owner" : "Eigandi",
-    "Remove from favorites" : "Fjarlægja úr eftirlætum",
-    "Add to favorites" : "Bæta í eftirlæti",
-    "Tags" : "Merki",
     "Your files" : "Skrárnar þínar",
     "Open in files" : "Opna í skráaforritinu",
     "File cannot be accessed" : "Skráin er ekki aðgengileg",
@@ -277,14 +258,12 @@ OC.L10N.register(
     "Failed to convert files: {message}" : "Mistókst að umbreyta skrám: {message}",
     "All files failed to be converted" : "Mistókst að umbreyta öllum skrám",
     "One file could not be converted: {message}" : "Ekki var hægt að umbreyta einni skrá: {message}",
-    "_One file could not be converted_::_%n files could not be converted_" : ["Ekki var hægt að umbreyta einni skrá","Ekki var hægt að umbreyta %n skrám"],
-    "_One file successfully converted_::_%n files successfully converted_" : ["Tókst að umbreyta einni skrá","Tókst að umbreyta %n skrám"],
-    "Files successfully converted" : "Tókst að umbreyta skrám",
     "Failed to convert files" : "Mistókst að umbreyta skrám",
     "Converting file …" : "Umbreyti skrá…",
     "File successfully converted" : "Tókst að umbreyta skrá",
     "Failed to convert file: {message}" : "Mistókst að umbreyta skrá: {message}",
     "Failed to convert file" : "Mistókst að umbreyta skrá",
+    "Delete" : "Eyða",
     "Leave this share" : "Yfirgefa þessa sameign",
     "Leave these shares" : "Yfirgefa þessar sameignir",
     "Disconnect storage" : "Aftengja geymslu",
@@ -302,6 +281,9 @@ OC.L10N.register(
     "Download" : "Niðurhal",
     "The requested file is not available." : "Umbeðin skrá er ekki tiltæk.",
     "The requested files are not available." : "Umbeðnar skrár eru ekki tiltækar.",
+    "Add to favorites" : "Bæta í eftirlæti",
+    "Remove from favorites" : "Fjarlægja úr eftirlætum",
+    "Add or remove favorite" : "Bæta við eða fjarlægja eftirlæti",
     "Moving \"{source}\" to \"{destination}\" …" : "Færi \"{source}\" í \"{destination}\" …",
     "Copying \"{source}\" to \"{destination}\" …" : "Afrita \"{source}\" í \"{destination}\" …",
     "Destination is not a folder" : "Áfangastaðurinn er ekki mappa",
@@ -314,10 +296,12 @@ OC.L10N.register(
     "The file does not exist anymore" : "Skráin  er ekki lengur til",
     "Choose destination" : "Veldu áfangastað",
     "Copy to {target}" : "Afrita í {target}",
+    "Copy" : "Afrita",
     "Move to {target}" : "Færa í {target}",
     "Move" : "Færa",
     "Move or copy operation failed" : "Aðgerð við að færa eða afrita mistókst",
     "Move or copy" : "Færa eða afrita",
+    "Open folder" : "Opna möppu",
     "Open folder {displayName}" : "Opna möppu {displayName}",
     "Open in Files" : "Opna í skráaforritinu",
     "Open locally" : "Opna staðvært",
@@ -326,6 +310,7 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Skráin ætti núna að opnast á tækinu þínu. Ef það gerist ekki, ættirðu að ganga úr skugga um að þú sért með vinnutölvuforritið uppsett.",
     "Retry and close" : "Prófa aftur og loka",
     "Open online" : "Opna á netinu",
+    "Rename" : "Endurnefna",
     "Details" : "Nánar",
     "View in folder" : "Skoða í möppu",
     "Today" : "Í dag",
@@ -381,6 +366,7 @@ OC.L10N.register(
     "No favorites yet" : "Engin eftirlæti ennþá",
     "Files and folders you mark as favorite will show up here" : "Skrár og möppur sem þú merkir sem eftirlæti birtast hér",
     "List of your files and folders." : "Listi yfir skrárnar þínar og möppur.",
+    "Folder tree" : "Möppugreinar",
     "List of your files and folders that are not shared." : "Listi yfir skrárnar þínar og möppur sem ekki er deilt.",
     "No personal files found" : "Engar einkaskrár fundust",
     "Files that are not shared will show up here." : "Skrár sem ekki er deilt birtast hér.",
@@ -404,13 +390,16 @@ OC.L10N.register(
     "Submitting fields …" : "Sendi inn gagnasvið…",
     "\"{displayName}\" action executed successfully" : "Tókst að framkvæma \"{displayName}\" aðgerð",
     "Filter file names …" : "Sía skráaheiti …",
+    "Clipboard is not available" : "Klippispjald er ekki tiltækt",
     "WebDAV URL copied to clipboard" : "WebDAV-slóð afrituð á klippispjaldið",
     "Enable the grid view" : "Virkja reitasýnina",
     "Enable folder tree" : "Virkja möppugreinar",
+    "WebDAV" : "WebDAV",
     "Copy to clipboard" : "Afrita á klippispjald",
     "Use this address to access your Files via WebDAV" : "Notaðu þetta vistfang til að nálgast skráaforritið þitt með WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Ef þú hefur virkjað 2FA tveggja-þrepa-auðkenningu, þarftu að útbúa nýtt lykilorð forrits og nota það með því að smella hér.",
     "Show a warning dialog when changing a file extension." : "Birta aðvörunarglugga þegar skráarendingu er breytt.",
+    "Keyboard shortcuts" : "Flýtileiðir á lyklaborði",
     "Speed up your Files experience with these quick shortcuts." : "Flýttu fyrir vinnu þinni með skrár með þessum flýtilyklum.",
     "Open the actions menu for a file" : "Opna aðgerðavalmynd fyrir skrá",
     "Rename a file" : "Endurnefna skrá",
@@ -427,6 +416,11 @@ OC.L10N.register(
     "Navigate to the file on the right (in grid mode)" : "Fara á skrána til hægri (í reitayfirliti)",
     "Toggle the grid view" : "Víxla reitayfirliti af/á",
     "Open the sidebar for a file" : "Opna hliðarspjald fyrir skrá",
+    "You" : "Þú",
+    "Shared multiple times with different people" : "Deilt mörgum sinnum með mismunandi fólki",
+    "Unable to change the favorite state of the file" : "Get ekki breytt stöðu sem eftirlæti á skránni",
+    "Error while loading the file data" : "Villa við að hlaða inn skráagögnum",
+    "Tags" : "Merki",
     "Save as …" : "Vista sem …",
     "Converting files …" : "Umbreyti skrám …",
     "Converting file …" : "Umbreyti skrá…",
