@@ -50,6 +50,11 @@ OC.L10N.register(
     "The destination path does not exist: %1$s" : "Патеката не постои: %1$s",
     "You do not have permission to create a file at the specified location" : "Немате дозвола да креирате датотека на специфираната локација",
     "The file could not be converted." : "Датотеката неможе да се конвертира.",
+    "Could not get relative path to converted file" : "Не може да добие релативна патека до конвертираната датотека",
+    "Limit must be a positive integer." : "Лимитот мора да биде позитивен цел број.",
+    "The replacement character may only be a single character." : "Заменскиот карактер може да биде само еден карактер.",
+    "Filename sanitization already started." : "Санизацијата на имињата на датотеки веќе започна.",
+    "No filename sanitization in progress." : "Нема санизација на имиња на датотеки во тек.",
     "Favorite files" : "Омилени датотеки",
     "No favorites" : "Нема омилени",
     "More favorites" : "Повеќе омилени",
@@ -67,7 +72,6 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Трансферот на сопственост на {path} од {user} е комплетиран.",
     "in %s" : "во %s",
     "Transferred from %1$s on %2$s" : "Трансфер од %1$s на %2$s",
-    "Files compatibility" : "Компатибилност со датотеки",
     "File Management" : "Датотеки",
     "Home" : "Дома",
     "Target folder does not exist any more" : "Папката не постои повеќе",
@@ -79,6 +83,8 @@ OC.L10N.register(
     "Drag and drop files here to upload" : "Повлечи и испушти датотеки за прикачување",
     "Favorite" : "Омилени",
     "Back" : "Назад",
+    "Toggle selection for file \"{displayName}\"" : "Префрли избор за датотека \"{displayName}\"",
+    "Toggle selection for folder \"{displayName}\"" : "Префрли избор за папка \"{displayName}\"",
     "File is loading" : "Датотеката се вчитува",
     "Folder is loading" : "Папката се вчитува",
     "Filename" : "Име на датотека",
@@ -90,6 +96,10 @@ OC.L10N.register(
     "Rename file" : "Преименувај датотека",
     "Folder" : "Папка",
     "Unknown file type" : "Непознат тип на датотека",
+    "{ext} image" : "{ext} слика",
+    "{ext} video" : "{ext} видео",
+    "{ext} audio" : "{ext} аудио",
+    "{ext} text" : "{ext} текст",
     "Pending" : "Чека",
     "Unknown date" : "Непознат датум",
     "Clear filter" : "Исчисти филтри",
@@ -97,12 +107,51 @@ OC.L10N.register(
     "Search everywhere" : "Барај насекаде",
     "Type" : "Вид",
     "Active filters" : "Активни филтри",
-    "Remove filter" : "Острани филтер",
+    "Remove filter" : "Отстрани филтер",
+    "Appearance" : "Изглед",
+    "Show hidden files" : "Прикажи сокриени датотеки",
+    "Show file type column" : "Прикажи колона за тип на датотека",
+    "Show file extensions" : "Прикажи наставки на датотеки",
+    "Crop image previews" : "Исечи ја сликата за преглед",
+    "General" : "Општо",
+    "Sort favorites first" : "Прво омилените",
+    "Sort folders before files" : "Подреди ги папките пред датотеките",
+    "Enable folder tree view" : "Овозможи поглед на дрво",
+    "Default view" : "Стандарден поглед",
+    "All files" : "Сите датотеки",
+    "Personal files" : "Лични датотеки",
+    "Additional settings" : "Дополнителни параметри",
+    "Actions" : "Акции",
+    "File actions" : "Акции со датотеки",
+    "Selection" : "Селектирање",
+    "Select all files" : "Селектирај ги сите датотеки",
+    "Deselect all" : "Одселектирај се",
+    "Select or deselect" : "Избери или одизбери",
+    "Select a range" : "Избери опсег",
+    "Navigation" : "Навигација",
+    "Go to parent folder" : "Оди во предходна папка",
+    "Go to file above" : "Оди на датотеката погоре",
+    "Go to file below" : "Оди на датотеката подолу",
+    "Go left in grid" : "Помести се лево во мрежата",
+    "Go right in grid" : "Помести се десно во мрежата",
+    "View" : "Поглед",
+    "Toggle grid view" : "Промена во мрежа",
+    "Open file sidebar" : "Отвори странична лента на датотеката",
+    "Show those shortcuts" : "Покажи ги овие кратенки",
+    "Warnings" : "Предупредувања",
+    "Warn before changing a file extension" : "Предупреди пред промена на наставката на датотека",
+    "Warn before deleting a file" : "Предупреди пред бришење датотека",
+    "WebDAV URL" : "WebDAV адреса",
+    "Create an app password" : "Креирај лозинка за апликација",
+    "How to access files using WebDAV" : "Како да пристапиш до датотеките преку WebDAV",
     "Total rows summary" : "Резиме на вкупно редови",
+    "Toggle selection for all files and folders" : "Префрли избор за сите датотеки и папки",
     "Name" : "Име",
     "File type" : "Вид на датотека",
     "Size" : "Големина",
-    "Actions" : "Акции",
+    "{displayName}: failed on some elements" : "{displayName}: неуспешно на некои елементи",
+    "{displayName}: done" : "{displayName}: завршено",
+    "{displayName}: failed" : "{displayName}: неуспешно",
     "(selected)" : "(означени)",
     "List of files and folders." : "Листа на датотеки и папки.",
     "You have used your space quota and cannot upload files anymore." : "Го имате искористено лимитот на просторот за прикачување и повеќе неможете да прикачувате датотеки.",
@@ -110,19 +159,43 @@ OC.L10N.register(
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Оваа листа не е целосно прикажана поради заштеда на перформанси. Датотеките ќе се прикажуваат додека се движите низ листата.",
     "File not found" : "Датотеката не е пронајдена",
     "_{count} selected_::_{count} selected_" : ["{count} означена","{count} означени"],
+    "Search everywhere …" : "Барај насекаде …",
+    "Search here …" : "Барај овде…",
     "Search scope options" : "Параметри за опсег на пребарување",
+    "Search here" : "Барај овде",
+    "Owner" : "Сопственик",
     "{usedQuotaByte} used" : "искористено {usedQuotaByte}",
     "{used} of {quota} used" : "Искористени {used} од {quota}",
     "{relative}% used" : "искористено {relative}% ",
     "Could not refresh storage stats" : "Неможе да се ажурира статистиката за складиштата",
     "Your storage is full, files can not be updated or synced anymore!" : "Вашето складиште е исполнето, датотеките веќе не можат да се ажирираат или синхронизираат!",
     "Storage information" : "Информации за складиште",
+    "Storage quota" : "Квота за складирање",
     "New folder" : "Нова папка",
     "Create new folder" : "Креирај нова папка",
     "This name is already in use." : "Името е веќе во употреба.",
     "Create" : "Креирај",
+    "Files starting with a dot are hidden by default" : "Датотеките што почнуваат со точка се скриени по стандард",
+    "Failed to start filename sanitization." : "Неуспешно започнување на прочистување на имиња на датотеки.",
+    "Failed to refresh filename sanitization status." : "Неуспешно освежување на статусот на прочистување на имиња на датотеки.",
+    "Filename sanitization in progress." : "Прочистување на имиња на датотеки е во тек.",
+    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Моментално се обработени {processedUsers} од {totalUsers} кориснички сметки.",
+    "Preparing …" : "Подготовка …",
+    "Refresh" : "Освежи",
+    "All files have been santized for Windows filename support." : "Сите датотеки се прочистени за поддршка на Windows имиња на датотеки.",
+    "Some files could not be sanitized, please check your logs." : "Некои датотеки не можеа да се прочистат, провери ги логовите.",
+    "Sanitization errors" : "Грешки при прочистување",
+    "Not sanitized filenames" : "Непрочистени имиња на датотеки",
+    "Windows filename support has been enabled." : "Поддршката за Windows имиња на датотеки е овозможена.",
+    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Ова ќе спречи корисниците да создаваат нови датотеки со неподдржани имиња, но постоечките датотеки сè уште не се преименувани и може да предизвикаат проблеми при синхронизација на Windows.",
+    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Можеш да покренеш преименување на датотеки со неважечки имиња, тоа ќе се изврши во позадина и може да потрае некое време.",
+    "Please note that this may cause high workload on the sync clients." : "Имај предвид дека ова може да предизвика голем товар на клиентите за синхронизација.",
+    "Limit" : "Ограничување",
+    "This allows to configure how many users should be processed in one background job run." : "Ова овозможува да се конфигурира колку корисници ќе се обработуваат во едно извршување на позадинска задача.",
+    "Sanitize filenames" : "Прочисти имиња на датотеки",
+    "(starting)" : "(во тек)",
     "Fill template fields" : "Пополни ги полињата за шаблон",
-    "Submitting fields …" : "Испраќање полиња ...",
+    "Submitting fields …" : "Испраќање на полињата …",
     "Submit" : "Испрати",
     "Choose a file or folder to transfer" : "Избери датотека или папка за трансфер",
     "Transfer" : "Трансфер",
@@ -135,6 +208,8 @@ OC.L10N.register(
     "Choose file or folder to transfer" : "Избери датотека или папка за трансфер",
     "Change" : "Измени",
     "New owner" : "Нов сопственик",
+    "Keep {old}" : "Задржи {old}",
+    "Keep without extension" : "Задржи без наставка",
     "Use {new}" : "Користи {new}",
     "Remove extension" : "Отстрани екстензија",
     "Change file extension" : "Промени екстензија",
@@ -144,6 +219,7 @@ OC.L10N.register(
     "Do not show this dialog again." : "Не го прикажувај овој дијалог повторно.",
     "Select file or folder to link to" : "Изберете датотека или папка за линк до",
     "Choose {file}" : "Избери {file}",
+    "Files settings" : "Параметри за датотеки",
     "Share" : "Сподели",
     "Shared by link" : "Споделено со линк",
     "Shared" : "Споделено",
@@ -162,61 +238,45 @@ OC.L10N.register(
     "Upload some content or sync with your devices!" : "Прикачете некоја содржина или синхронизирајте со вашите уреди!",
     "Go back" : "Назад",
     "Views" : "Прегледи",
-    "Files settings" : "Параметри за датотеки",
+    "Loading …" : "Се вчитува …",
     "Your files" : "Ваши датотеки",
     "Open in files" : "Отвори во датотеките",
     "File cannot be accessed" : "Неможе да се пристапи до датотеката",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Датотеката не може да се пронајде или немате дозволи за да ја видите. Побарајте од испраќачот да ја сподели.",
     "No search results for “{query}”" : "Нема резултати од пребарувањето за \"{query}\"",
     "Search for files" : "Пребарај датотеки",
-    "Clipboard is not available" : "Клипбордот не е достапен",
-    "General" : "Општо",
-    "Default view" : "Стандарден поглед",
-    "All files" : "Сите датотеки",
-    "Personal files" : "Лични датотеки",
-    "Sort favorites first" : "Прво омилените",
-    "Sort folders before files" : "Подреди ги папките пред датотеките",
-    "Appearance" : "Изглед",
-    "Show hidden files" : "Прикажи сокриени датотеки",
-    "Show file type column" : "Прикажи колона за тип на датотека",
-    "Crop image previews" : "Исечи ја сликата за преглед",
-    "Additional settings" : "Дополнителни параметри",
-    "WebDAV" : "WebDAV",
-    "WebDAV URL" : "WebDAV адреса",
-    "Copy" : "Копирај",
-    "Warnings" : "Предупредувања",
-    "Keyboard shortcuts" : "Кратенки преку тастатура",
-    "File actions" : "Акции со датотеки",
-    "Rename" : "Преименувај",
-    "Delete" : "Избриши",
-    "Manage tags" : "Уреди ги ознаките",
-    "Selection" : "Селектирање",
-    "Select all files" : "Селектирај ги сите датотеки",
-    "Deselect all" : "Одселектирај се",
-    "Navigation" : "Навигација",
-    "View" : "Поглед",
-    "Toggle grid view" : "Промена во мрежа",
-    "Show those shortcuts" : "Покажи ги овие кратенки",
-    "You" : "Вас",
-    "Shared multiple times with different people" : "Споделено повеќе пати со различни луѓе",
-    "Unable to change the favorite state of the file" : "Неможе да се промени статусот на омимени на датотеката",
-    "Error while loading the file data" : "Грешка при вчитување на податоците од датотеката",
-    "Owner" : "Сопственик",
-    "Remove from favorites" : "Отстрани од фаворити",
-    "Add to favorites" : "Додади во фаворити",
-    "Tags" : "Ознаки",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Овозможи ограничување на имиња на датотеки за да се осигура дека можат да се синхронизираат со сите клиенти. Стандардно се дозволени сите имиња што се валидни на POSIX системи (на пр. Linux или macOS).",
+    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "По овозможување на имиња компатибилни со Windows, постоечките датотеки повеќе не може да се изменуваат, но нивните сопственици можат да ги преименуваат во валидни нови имиња.",
+    "Failed to toggle Windows filename support" : "Неуспешно менување на статусот на поддршка за Windows имиња на датотеки",
+    "Files compatibility" : "Компатибилност со датотеки",
+    "Enforce Windows compatibility" : "Присили компатибилност со Windows",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Ова ќе ги блокира имињата на датотеки што не се валидни на Windows системи, како резервирани имиња или специјални знаци. Сепак, нема да се наметне компатибилност во однос на големи и мали букви.",
     "Blank" : "Празно",
     "Unable to create new file from template" : "Неможе да се креира датотека од шаблон",
     "Pick a template for {name}" : "Избери шаблон за {name}",
     "Create a new file with the selected template" : "Креирај нова датотека со избраниот шаблон",
     "Creating file" : "Креирање на датотека",
     "Save as {displayName}" : "Зачувај како {displayName}",
-    "Save as …" : "Зачувај како ...",
-    "Converting files …" : "Конвертирање датотеки …",
+    "Save as …" : "Зачувај како …",
+    "Converting files …" : "Конвертирање датотеки …",
+    "Failed to convert files: {message}" : "Неуспешно конвертирање датотеки: {message}",
+    "All files failed to be converted" : "Сите датотеки неуспешно се конвертирани",
+    "One file could not be converted: {message}" : "Една датотека не може да се конвертира: {message}",
+    "_%n file could not be converted_::_%n files could not be converted_" : ["%n датотека не може да се конвертира","%n датотеки не можеа да се конвертираат"],
+    "_%n file converted_::_%n files converted_" : ["%n датотека е конвертирана","%n датотеки се конвертирани"],
+    "Files converted" : "Конвертирани датотеки",
+    "Failed to convert files" : "Неуспешно конвертирање датотеки",
+    "Converting file …" : "Конвертирање датотека …",
+    "File successfully converted" : "Датотеката е успешно конвертирана",
+    "Failed to convert file: {message}" : "Неуспешно конвертирање датотека: {message}",
+    "Failed to convert file" : "Неуспешно конвертирање датотека",
+    "Delete" : "Избриши",
     "Leave this share" : "Напушти го ова споделување",
     "Leave these shares" : "Напушти ги овие споделувања",
     "Disconnect storage" : "Исклучи складиште",
+    "Disconnect storages" : "Исклучи складишта",
     "Delete permanently" : "Избриши",
+    "Delete and unshare" : "Избриши и отстрани споделување",
     "Delete file" : "Избриши датотека",
     "Delete files" : "Избриши датотеки",
     "Delete folder" : "Избриши папка",
@@ -226,6 +286,13 @@ OC.L10N.register(
     "Confirm deletion" : "Потврди бришење",
     "Cancel" : "Откажи",
     "Download" : "Преземи",
+    "The requested file is not available." : "Бараната датотека не е достапна.",
+    "The requested files are not available." : "Бараните датотеки не се достапни.",
+    "Add to favorites" : "Додади во фаворити",
+    "Remove from favorites" : "Отстрани од фаворити",
+    "Add or remove favorite" : "Додај или отстрани омилено",
+    "Moving \"{source}\" to \"{destination}\" …" : "Преместување \"{source}\" во \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Копирање \"{source}\" во \"{destination}\" …",
     "Destination is not a folder" : "Дестинацијата не е папка",
     "This file/folder is already in that directory" : "Оваа папка/датотека се наоѓа веќе во таа папка",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Неможете да преместите датотека/папка во себеси или во подпапка во себеси",
@@ -236,14 +303,21 @@ OC.L10N.register(
     "The file does not exist anymore" : "Датотеката не постои",
     "Choose destination" : "Избери дестинација",
     "Copy to {target}" : "Копирај во {target}",
+    "Copy" : "Копирај",
     "Move to {target}" : "Премести во {target}",
     "Move" : "Премести",
+    "Move or copy operation failed" : "Преместувањето или копирањето не успеа",
     "Move or copy" : "Премести или копирај",
+    "Open folder" : "Отвори папка",
     "Open folder {displayName}" : "Отвори папка {displayName}",
     "Open in Files" : "Отвори во датотеките",
     "Open locally" : "Отвори локално",
     "Failed to redirect to client" : "Неуспешно пренасочување кон клиентот",
     "Open file locally" : "Отвори ја датотеката локално",
+    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Датотеката сега треба да се отвори на твојот уред. Ако не се отвори, провери дали ја имаш инсталирано десктоп апликацијата.",
+    "Retry and close" : "Повтори и затвори",
+    "Open online" : "Отвори онлајн",
+    "Rename" : "Преименувај",
     "Details" : "Детали:",
     "View in folder" : "Погледни во папката",
     "Today" : "Денес",
@@ -265,20 +339,31 @@ OC.L10N.register(
     "Templates" : "Шаблони",
     "New template folder" : "Нова папка за шаблони",
     "In folder" : "Во папка",
+    "Search in all files" : "Пребарај во сите датотеки",
     "Search in folder: {folder}" : "Барај во папка: {folder}",
     "One of the dropped files could not be processed" : "Една од испуштените датотеки неможе да се процесоира",
+    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Твојот прелистувач не ја поддржува Filesystem API. Папките нема да бидат прикачени.",
+    "No files to upload" : "Нема датотеки за прикачување",
     "Unable to create the directory {directory}" : "Неможе да се креира папка {directory}",
     "Some files could not be uploaded" : "Некој датотеки неможат да се прикачат",
     "Files uploaded successfully" : "Успешно прикачени датотеки",
+    "No files to process" : "Нема датотеки за обработка",
+    "Some files could not be copied" : "Некои датотеки не можеа да се копираат",
     "Some files could not be moved" : "Некои датотеки не можат да се преместат",
+    "Files copied successfully" : "Датотеките се успешно копирани",
+    "Files moved successfully" : "Датотеките се успешно преместени",
+    "Conflicts resolution skipped" : "Разрешувањето на конфликти е прескокнато",
+    "Upload cancelled" : "Прикачувањето е откажано",
     "Could not rename \"{oldName}\", it does not exist any more" : "Неможе да се преименува \"{oldName}\", не постои повеќе",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Името \"{newName}\" веќе се користи во папката \"{dir}\". Ве молиме изберете друго име.",
     "Could not rename \"{oldName}\"" : "Неможе да се преименува \"{oldName}\"",
     "This operation is forbidden" : "Операцијата не е дозволена",
+    "This folder is unavailable, please try again later or contact the administration" : "Оваа папка не е достапна, обиди се повторно подоцна или контактирај го администраторот",
     "Storage is temporarily not available" : "Складиштето моментално не е достапно",
     "Unexpected error: {error}" : "Неочекувана грешка: {error}",
     "_%n file_::_%n files_" : ["%n датотека","%n датотеки"],
     "_%n folder_::_%n folders_" : ["%n папка","%n папки"],
+    "_%n hidden_::_%n hidden_" : ["%n скриена","%n скриени"],
     "Filename must not be empty." : "Името на датотеката не може да биде празно.",
     "\"{char}\" is not allowed inside a filename." : "\"{char}\" не е дозволен во името на датотеката.",
     "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" е резервирано име и не е дозволено во името на датотеката.",
@@ -288,124 +373,47 @@ OC.L10N.register(
     "No favorites yet" : "Сеуште нема фаворити",
     "Files and folders you mark as favorite will show up here" : "Датотеките и папките кои ќе ги означите како чести, ќе се појават тука",
     "List of your files and folders." : "Листа на вашите датотеки и папки.",
+    "Folder tree" : "Структура на папки",
+    "List of your files and folders that are not shared." : "Листа на твоите датотеки и папки кои не се споделени.",
     "No personal files found" : "Не се пронајдени лични датотеки ",
+    "Files that are not shared will show up here." : "Датотеките што не се споделени ќе се прикажат тука.",
     "Recent" : "Неодамнешни",
     "List of recently modified files and folders." : "Листа на скоро изменети датотеки и папки.",
     "No recently modified files" : "Нема скоро изменети датотеки",
     "Files and folders you recently modified will show up here." : "Датотеките и папките кои скоро ќе ги измените ќе се појават тука.",
     "Search" : "Барај",
+    "Search results within your files." : "Резултати од пребарување во рамките на твоите датотеки.",
     "No entries found in this folder" : "Нема ништо во оваа папка",
     "Select all" : "Избери се",
     "Upload too large" : "Фајлот кој се вчитува е преголем",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Датотеките кои се обидувате да ги подигнете ја надминуваат максималната големина за подигнување датотеки на овој сервер.",
-    "File could not be found" : "Неможе да се пронајде датотеката",
-    "Show list view" : "Прикажи поглед во листа",
-    "Show grid view" : "Прикажи поглед во мрежа",
-    "Close" : "Затвори",
-    "Could not create folder \"{dir}\"" : "Неможе да се креира папка \"{dir}\"",
-    "This will stop your current uploads." : "Ова ќе го прекине вашето моментално прикачување.",
-    "Upload cancelled." : "Преземањето е прекинато.",
-    "Processing files …" : "Обработка на датотеки ...",
-    "…" : "…",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Неможе да се прикачи {filename} бидејќи е директориум или е 0 бајти",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Нема доволно слободен простор, прикачувате {size1} а слободен простор има {size2}",
-    "Target folder \"{dir}\" does not exist any more" : "Папката \"{dir}\" не постои повеќе",
-    "An unknown error has occurred" : "Се појави непозната грешка",
-    "File could not be uploaded" : "Датотеката неможе да се прикачи",
-    "Uploading …" : "Прикачување …",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "Прикачување … ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} од {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "Прикачување на таа датотека не е дозволено",
-    "Error when assembling chunks, status code {status}" : "Грешка при составување на парчиња, статусен код {status}",
-    "Choose target folder" : "Избери папка",
-    "Set reminder" : "Постави потсетник",
-    "Edit locally" : "Уреди локално",
-    "Open" : "Отвори",
-    "Could not load info for file \"{file}\"" : "Неможе да се вчитаат информации за датотеката \"{file}\"",
-    "Please select tag(s) to add to the selection" : "Избери ознаки за одбележаното",
-    "Apply tag(s) to selection" : "Примени ознаки на обележаните",
-    "Select directory \"{dirName}\"" : "Избери папка \"{dirName}\"",
-    "Select file \"{fileName}\"" : "Избери датотека \"{fileName}\"",
-    "Unable to determine date" : "Неможе да се одреди датумот",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Овој директориум е недостапен, ве молиме проверете ги логовите или контактирајте со администраторот",
-    "Could not move \"{file}\", target exists" : "Не може да се премести \"{file}\", веќе постои",
-    "Could not move \"{file}\"" : "Не може да се премести \"{file}\"",
-    "copy" : "копирај",
-    "Could not copy \"{file}\", target exists" : "Не може да се копира \"{file}\", веќе постои",
-    "Could not copy \"{file}\"" : "Не може да се копира \"{file}\"",
-    "Copied {origin} inside {destination}" : "Копирана {origin} во {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "Копирана {origin} и {nbfiles} други датотеки во {destination}",
-    "{newName} already exists" : "{newName} веќе постои",
-    "Could not create file \"{file}\"" : "Неможе да се креира датотека \"{file}\"",
-    "Could not create file \"{file}\" because it already exists" : "Неможе да се креира датотека \"{file}\" бидејќи веќе постои",
-    "Could not create folder \"{dir}\" because it already exists" : "Неможе да се креира папка \"{dir}\" бидејќи веќе постои",
-    "Could not fetch file details \"{file}\"" : "Неможе да се вчитаат деталите за датотеката \"{file}\"",
-    "Error deleting file \"{fileName}\"." : "Грешка при бришење на датотека \"{fileName}\".",
-    "No search results in other folders for {tag}{filter}{endtag}" : "Нема резултати од пребарувањето на други места за {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "Внесете повеќе од два карактери за да пребарувате во другите папки",
-    "{dirs} and {files}" : "{dirs} и {files}",
-    "_including %n hidden_::_including %n hidden_" : ["вклучувајќи %n скриена","вклучувајќи %n скриени"],
-    "You do not have permission to upload or create files here" : "Немате дозвола да прикачувате или да креирате датотеки овде",
-    "_Uploading %n file_::_Uploading %n files_" : ["Прикачување %n датотека","Прикачување на %n датотеки"],
-    "New" : "Нов/a",
-    "New file/folder menu" : "Мени Нова датотека/папка",
-    "Select file range" : "Избери опсег на датотеки",
-    "{used}%" : "{used}%",
-    "{used} used" : "Искористени {used}",
-    "\"{name}\" is an invalid file name." : "\"{name}\" е невалидно име за датотека.",
-    "File name cannot be empty." : "Името на датотеката не може да биде празно.",
-    "\"/\" is not allowed inside a file name." : "\"/\" не е дозволено во името.",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" не е дозволен вид на датотека",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Складиштето на {owner} е исполнето, повеќе нема да може да сикхронизира и да прикачува датотеки!",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Групната папка \"{mountPoint}\" е исполнета, датотеките веќе не можат да се ажирираат или синхронизираат!",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Надворешното складиште \"{mountPoint}\" е исполнето, датотеките веќе не можат да се ажирираат или синхронизираат!",
-    "Your storage is full, files cannot be updated or synced anymore!" : "Вашето складиште е исполнето, датотеките веќе не можат да се ажирираат или синхронизираат!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Скалдиштето на {owner} е скоро исполнето ({usedSpacePercent}%).",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Групната папка \"{mountPoint}\" е скоро исполнета ({usedSpacePercent}%).",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Надворешното складиште \"{mountPoint}\" е скоро исполнето ({usedSpacePercent}%).",
-    "Your storage is almost full ({usedSpacePercent}%)." : "Вашето складиште е скоро исполнето ({usedSpacePercent}%).",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["содржи '{filter}'","содржи '{filter}'"],
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Копиран е директен линк (работи само за корисници кој имаат директен пристап до датотеката/папката)",
-    "Path" : "Патека",
-    "_%n byte_::_%n bytes_" : ["%n бајт","%n бајти"],
-    "Copy direct link (only works for people who have access to this file/folder)" : "Копирај директен линк (работи само за корисници кој имаат директен пристап до датотеката/папката)",
-    "Upload file" : "Прикачи датотека",
-    "An error occurred while trying to update the tags" : "Се случи грешка додека се обидувавте да ги освежите таговите",
+    "%1$s (renamed)" : "%1$s (преименувано)",
+    "renamed file" : "преименувана датотека",
     "Upload (max. %s)" : "Префрлање (макс. %s)",
-    "\"{displayName}\" action executed successfully" : "\"{displayName}\" акцијата е успешно извршена",
-    "\"{displayName}\" action failed" : "\"{displayName}\" акцијата не успеа",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "По овозможување на имиња компатибилни со Windows, постоечките датотеки повеќе не може да се изменуваат, но сопственикот може да ги преименува во валидни нови имиња.",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Можно е и автоматски да се мигрираат датотеките по овозможување на оваа поставка — погледни ја документацијата за occ командата.",
+    "\"{displayName}\" failed on some elements" : "\"{displayName}\" не успеа на некои елементи",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" сериската акција е успешно извршена",
-    "Filter filenames…" : "Филтрирај имиња на датотеки ...",
+    "\"{displayName}\" action failed" : "\"{displayName}\" акцијата не успеа",
+    "Submitting fields …" : "Испраќање полиња ...",
+    "\"{displayName}\" action executed successfully" : "\"{displayName}\" акцијата е успешно извршена",
+    "Filter file names …" : "Филтрирај имиња на датотеки ...",
+    "Clipboard is not available" : "Клипбордот не е достапен",
     "WebDAV URL copied to clipboard" : "CalDAV линкот е копиран",
     "Enable the grid view" : "Овозможи поглед во мрежа",
     "Enable folder tree" : "Овозможи поглед на дрво",
+    "WebDAV" : "WebDAV",
     "Copy to clipboard" : "Копирај во клипборд",
     "Use this address to access your Files via WebDAV" : "Користи ја оваа адреса за пристап до вашите датотеки преку WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Ако имате овозможено 2FA, мора да креирате и користите нова лозинка за апликација со кликнување овде.",
-    "Deletion cancelled" : "Бришењето е откажано",
-    "Cancelled move or copy operation" : "Откажана операција на копирање или преместување",
-    "Open details" : "Отвори детали",
-    "Photos and images" : "Фотографии и слики",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} папка","{folderCount} папки"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} датотека","{fileCount} датотеки"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 датотека и {folderCount} папки","1 датотека и {folderCount} папки"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} датотека и 1 папка","{fileCount} датотеки и 1 папка"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} датотеки и {folderCount} папки",
-    "All folders" : "Сите папки",
-    "Personal Files" : "Лични датотеки",
-    "Text file" : "Текстуална датотека",
-    "New text file.txt" : "Нова текстуална датотека file.txt",
-    "%1$s (renamed)" : "%1$s (преименувано)",
-    "renamed file" : "преименувана датотека",
-    "Filter file names …" : "Филтрирај имиња на датотеки ...",
     "Prevent warning dialogs from open or reenable them." : "Спречете ги дијалозите за предупредување да се отвораат или повторно овозможете ги.",
     "Show a warning dialog when changing a file extension." : "Прикажи дијалог за предупредување при промена на екстензија на датотека.",
+    "Keyboard shortcuts" : "Кратенки преку тастатура",
     "Speed up your Files experience with these quick shortcuts." : "Забрзајте го вашето искуство со овие брзи кратенки.",
     "Open the actions menu for a file" : "Отвори Мени со акции за датотека",
     "Rename a file" : "Преименувај датотека",
     "Delete a file" : "Избриши датотека",
-    "Favorite or remove a file from favorites" : "Додади или острани од омилени",
+    "Favorite or remove a file from favorites" : "Додади или отстрани од омилени",
     "Manage tags for a file" : "Управувај со ознаки за датотека",
     "Deselect all files" : "Деселектирај ги сите датотеки",
     "Select or deselect a file" : "Селектирај или деселектирај датотека",
@@ -416,6 +424,29 @@ OC.L10N.register(
     "Navigate to the file on the left (in grid mode)" : "Оди до датотека лево (само во мрежен приказ)",
     "Navigate to the file on the right (in grid mode)" : "Оди до датотека десно (само во мрежен приказ)",
     "Toggle the grid view" : "Вклучи/исклучи мрежен приказ",
-    "Open the sidebar for a file" : "Отвори странична лента за датотека"
+    "Open the sidebar for a file" : "Отвори странична лента за датотека",
+    "You" : "Вас",
+    "Shared multiple times with different people" : "Споделено повеќе пати со различни луѓе",
+    "Unable to change the favorite state of the file" : "Неможе да се промени статусот на омимени на датотеката",
+    "Error while loading the file data" : "Грешка при вчитување на податоците од датотеката",
+    "Tags" : "Ознаки",
+    "Save as …" : "Зачувај како ...",
+    "Converting files …" : "Конвертирање датотеки …",
+    "Converting file …" : "Се конвертира датотека …",
+    "Deletion cancelled" : "Бришењето е откажано",
+    "Edit locally" : "Уреди локално",
+    "Moving \"{source}\" to \"{destination}\" …" : "Се преместува \"{source}\" во \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Се копира \"{source}\" во \"{destination}\" …",
+    "Move cancelled" : "Преместувањето е откажано",
+    "Cancelled move or copy of \"{filename}\"." : "Откажано е преместувањето или копирањето на \"{filename}\".",
+    "Cancelled move or copy operation" : "Откажана операција на копирање или преместување",
+    "Open details" : "Отвори детали",
+    "Photos and images" : "Фотографии и слики",
+    "New folder creation cancelled" : "Креирањето на нова папка е откажано",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Овој директориум е недостапен, ве молиме проверете ги логовите или контактирајте со администраторот",
+    "All folders" : "Сите папки",
+    "Search everywhere …" : "Пребарај насекаде …",
+    "Search here …" : "Пребарај тука …",
+    "Preparing …" : "Подготовка ..."
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
