@@ -39,13 +39,25 @@ OC.L10N.register(
     "{user} renamed {oldfile} to {newfile}" : "{user} ئۆزگەرتىلگەن {oldfile} دىن {newfile}",
     "You moved {oldfile} to {newfile}" : "سىز {oldfile} نى {newfile} غا يۆتكىدىڭىز",
     "{user} moved {oldfile} to {newfile}" : "{user} {oldfile} نى {newfile} غا يۆتكىدى",
-    "A file has been added to or removed from your <strong>favorites</strong>" : "ھۆججەتلىرىڭىز <strong> ياقتۇرىدىغان </ strong> غا قوشۇلدى ياكى ئۆچۈرۈلدى",
+    "A file has been added to or removed from your <strong>favorites</strong>" : "ھۆججەتلىرىڭىز <strong> ياقتۇرىدىغان </strong> غا قوشۇلدى ياكى ئۆچۈرۈلدى",
     "Files" : "ھۆججەتلەر",
-    "A file or folder has been <strong>changed</strong>" : "ھۆججەت ياكى ھۆججەت قىسقۇچ <strong> ئۆزگەرتىلدى </ strong>",
-    "A favorite file or folder has been <strong>changed</strong>" : "ياقتۇرىدىغان ھۆججەت ياكى ھۆججەت قىسقۇچ <strong> ئۆزگەرتىلدى </ strong>",
+    "A file or folder has been <strong>changed</strong>" : "ھۆججەت ياكى ھۆججەت قىسقۇچ <strong> ئۆزگەرتىلدى </strong>",
+    "A favorite file or folder has been <strong>changed</strong>" : "ياقتۇرىدىغان ھۆججەت ياكى ھۆججەت قىسقۇچ <strong> ئۆزگەرتىلدى </strong>",
     "Failed to authorize" : "ھوقۇق بېرىش مەغلۇب بولدى",
     "Invalid folder path" : "ھۆججەت قىسقۇچ يولى ئىناۋەتسىز",
     "Folder not found" : "ھۆججەت قىسقۇچ تېپىلمىدى",
+    "The file cannot be found" : "ھۆججەتنى تاپقىلى بولمىدى",
+    "The destination path does not exist: %1$s" : "نىشان يول مەۋجۇت ئەمەس: %1$s",
+    "You do not have permission to create a file at the specified location" : "سىزنىڭ بەلگىلەنگەن ئورۇندا ھۆججەت قۇرۇش ھوقوقىڭىز يوق",
+    "The file could not be converted." : "ھۆججەتنى ئايلاندۇرغىلى بولمىدى",
+    "Could not get relative path to converted file" : "ئايلاندۇرغان ھۆججەتنىڭ نىسپىي يولىغا ئېرىشكىلى بولمىدى",
+    "Limit must be a positive integer." : "چەك چوقۇم مۇسبەت سان بولىشى كېرەك",
+    "The replacement character may only be a single character." : "ئالماشتۇرۇش ھەرىپى چوقۇم تاق ھەرىپ بولىشى كېرەك",
+    "Filename sanitization already started." : "ھۆججەت نامىنى دىزىنفىكسىيەلەش باشلاندى.",
+    "No filename sanitization in progress." : "ھۆججەت نامىنى دىزىنفىكسىيەلەش داۋاملىشىۋاتىدۇ",
+    "Favorite files" : "ياقتۇردىغان ھۆججەتلەر",
+    "No favorites" : "ياقتۇردىغان يوق",
+    "More favorites" : "كۆپ ياقتۇردىغان",
     "Accept" : "قوبۇل قىلىڭ",
     "Reject" : "رەت قىلىش",
     "Incoming ownership transfer from {user}" : "{user} دىن كەلگەن ئىگىدارلىق ھوقۇقىنى يۆتكەش",
@@ -58,8 +70,8 @@ OC.L10N.register(
     "Ownership transfer done" : "ئىگىدارلىق ھوقۇقىنى يۆتكەش ئېلىپ بېرىلدى",
     "Your ownership transfer of {path} to {user} has completed." : "ئىگىدارلىق ھوقۇقىڭىزنى {path} دىن {user} غا يۆتكەش تاماملاندى.",
     "The ownership transfer of {path} from {user} has completed." : "{path} نىڭ {user} دىن ئىگىدارلىق ھوقۇقىنى يۆتكەش تاماملاندى.",
-    "in %s" : "% s",
-    "Transferred from %1$s on %2$s" : "%2 $ s دىكى%1 $ s دىن يۆتكەلدى",
+    "in %s" : "%s دە",
+    "Transferred from %1$s on %2$s" : "%2$s دا %1$s دىن يۆتكەلدى",
     "File Management" : "ھۆججەت باشقۇرۇش",
     "Home" : "ئۆي",
     "Target folder does not exist any more" : "نىشان ھۆججەت قىسقۇچ ئەمدى مەۋجۇت ئەمەس",
@@ -67,6 +79,7 @@ OC.L10N.register(
     "Go to the \"{dir}\" directory" : "\"{dir}\" مۇندەرىجىسىگە كىرىڭ",
     "Current directory path" : "نۆۋەتتىكى مۇندەرىجە يولى",
     "Your have used your space quota and cannot upload files anymore" : "بوشلۇق نورمىسىنى ئىشلىتىپ ، ھۆججەتلەرنى ئەمدى يۈكلىيەلمەيسىز",
+    "You do not have permission to upload or create files here." : "بۇ يەرگە ھۆججەت يوللاش ياكى قۇرۇش ھوقۇقىڭىز يوق.",
     "Drag and drop files here to upload" : "ھۆججەتلەرنى بۇ يەرگە سۆرەپ تاشلاڭ",
     "Favorite" : "يىغقۇچ",
     "Back" : "قايتىش",
@@ -82,23 +95,76 @@ OC.L10N.register(
     "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" غا \"{newName}\" غا ئۆزگەرتىلدى",
     "Rename file" : "ھۆججەتنىڭ نامىنى ئۆزگەرتىش",
     "Folder" : "قىسقۇچ",
+    "Unknown file type" : "نامەلۇم ھۆججەت تىپى",
+    "{ext} image" : "{ext} سۈرەت",
+    "{ext} video" : "{ext} سىن",
+    "{ext} audio" : "{ext} ئاۋاز",
+    "{ext} text" : "{ext} تېكىست",
     "Pending" : "كۈتۈۋاتىدۇ",
+    "Unknown date" : "نامەلۇم چېسلا",
     "Clear filter" : "سۈزگۈچنى تازىلاش",
     "Modified" : "ئۆزگەرتكەن",
     "Search everywhere" : "ھەممە يەردىن ئىزدەڭ",
     "Type" : "تىپ",
     "Active filters" : "ئاكتىپ سۈزگۈچ",
     "Remove filter" : "سۈزگۈچنى ئۆچۈرۈڭ",
+    "Appearance" : "كۆرۈنۈش",
+    "Show hidden files" : "يوشۇرۇن ھۆججەتلەرنى كۆرسەت",
+    "Show file type column" : "ھۆججەت تىپى قاتارىنى كۆرسەت",
+    "Show file extensions" : "ھۆججەت كېڭەيتمىسىنى كۆرسەت",
+    "Crop image previews" : "رەسىمنى ئالدىن كۆرۈش",
+    "General" : "ئۇمۇمىي",
+    "Sort favorites first" : "ياقتۇرىدىغانلارنى رەتلەڭ",
+    "Sort folders before files" : "ھۆججەتلەرنى ھۆججەتتىن بۇرۇن تەرتىپلەڭ",
+    "Enable folder tree view" : "قىسقۇچ شاخسىمان كۆرۈنۈشىنى قوزغات",
+    "Default view" : "كۆڭۈلدىكى كۆرۈنۈش",
+    "All files" : "بارلىق ھۆججەتلەر",
+    "Personal files" : "شەخسىي ھۆججەتلەر",
+    "Additional settings" : "قوشۇمچە تەڭشەكلەر",
+    "Actions" : "مەشغۇلاتلار",
+    "File actions" : "ھۆججەت ھەرىكىتى",
+    "Selection" : "تاللاش",
+    "Select all files" : "ھەممە ھۆججەتلەرنى تاللا",
+    "Deselect all" : "ھەممىنى تاللاڭ",
+    "Select or deselect" : "تاللا ياكى تاللىما",
+    "Select a range" : "بىر دائىرىنى تاللا",
+    "Navigation" : "يول باشلاش",
+    "Go to parent folder" : "باش قىسقۇچقا بار",
+    "Go to file above" : "ئۈستىدىكى ھۆججەتكە بار",
+    "Go to file below" : "ئاستىدىكى ھۆججەتكە بار",
+    "Go left in grid" : "سولغا بار",
+    "Go right in grid" : "ئوڭغا بار",
+    "View" : "كۆرۈنۈش",
+    "Toggle grid view" : "تورسىمان كۆرۈنۈشنى قوزغات",
+    "Open file sidebar" : "ھۆججەت يانبالداقنى ئاچ",
+    "Show those shortcuts" : "ئۇ قىسقايولنى كۆرسەت",
+    "Warnings" : "ئاگاھلاندۇرۇش",
+    "Warn before changing a file extension" : "بىر ھۆججەت كېڭەيتىلمىسىنى ئۆزگەرتىشتىن بۇرۇن ئاگاھلاندۇر",
+    "Warn before deleting a file" : "بىر ھۆججەتنى ئۆچۈرۈشتىن بۇرۇن ئاگاھلاندۇر",
+    "WebDAV URL" : "WebDAV URL",
+    "Create an app password" : "بىر ئەپ پارولى قۇر",
+    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "بۇ ھېسابات ئۈچۈن ئىككى ئامىللىق دەلىللەش قوزغىتىلغان بولغاچقا، WebDAV دەلىللەش ئۈچۈن تەلەپ قىلىنىدۇ.",
+    "How to access files using WebDAV" : "WebDAV ئارقىلىق ھۆججەتلەرگە قانداق كىرىش كېرەك",
     "Total rows summary" : "ئومۇمىي قۇر خۇلاسىسى",
     "Toggle selection for all files and folders" : "بارلىق ھۆججەت ۋە ھۆججەت قىسقۇچلارنى تاللاڭ",
     "Name" : "ئاتى",
+    "File type" : "ھۆججەت تىپى",
     "Size" : "چوڭلۇقى",
-    "Actions" : "مەشغۇلاتلار",
+    "{displayName}: failed on some elements" : "{displayName}: بەزى ئېلېمېنتلاردا مەغلۇپ بولدى ",
+    "{displayName}: done" : "{displayName}: پۈتتى",
+    "{displayName}: failed" : "{displayName}: مەغلۇپ بولدى",
     "(selected)" : "(تاللانغان)",
     "List of files and folders." : "ھۆججەت ۋە ھۆججەت قىسقۇچلارنىڭ تىزىملىكى.",
+    "You have used your space quota and cannot upload files anymore." : "بوشلۇق كۋوتىڭىزنى ئىشلەتتىڭىز، ئەمدى ھۆججەتلەرنى يۈكلىيەلمەيسىز.",
     "Column headers with buttons are sortable." : "كۇنۇپكىلار بار ئىستون ماۋزۇلىرى تەرتىپلىك.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "بۇ تىزىملىك ئىقتىدار سەۋەبىدىن تولۇق كۆرسىتىلمىگەن. ھۆججەتلەر تىزىملىكتىن ئۆتكەندە كۆرسىتىلىدۇ.",
     "File not found" : "ھۆججەت تېپىلمىدى",
+    "_{count} selected_::_{count} selected_" : ["{count} تاللاندى","{count} تاللاندى"],
+    "Search everywhere …" : "ھەممە يەردە ئىزدە  ...",
+    "Search here …" : "بۇ يەردە ئىزدە  ...",
+    "Search scope options" : "ئىزدەش دائىرە تاللانمىسى",
+    "Search here" : "بۇ يەردە ئىزدە",
+    "Owner" : "ئىگىسى",
     "{usedQuotaByte} used" : "{usedQuotaByte} ئىشلىتىلگەن",
     "{used} of {quota} used" : "{used} {quota} ئىشلىتىلگەن",
     "{relative}% used" : "{relative}% ئىشلىتىلگەن",
@@ -110,9 +176,27 @@ OC.L10N.register(
     "Create new folder" : "يېڭى ھۆججەت قىسقۇچ قۇر",
     "This name is already in use." : "بۇ ئىسىم ئاللىقاچان ئىشلىتىلىۋاتىدۇ.",
     "Create" : "قۇر",
+    "Files starting with a dot are hidden by default" : "نۇقتا بىلەن باشلانغان ھۆججەتلەر ئۆزلۈكىدىن يوشۇرۇنغان بولىدۇ",
+    "Failed to start filename sanitization." : "ھۆججەت نامىنى تازىلاشنى باشلاش مەغلۇب بولدى.",
+    "Failed to refresh filename sanitization status." : "ھۆججەت نامىنى تازىلاش ھالىتىنى يېڭىلاش مەغلۇب بولدى.",
+    "Filename sanitization in progress." : "ھۆججەت نامىنى تازىلاش داۋاملىشىۋاتىدۇ.",
+    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "ھازىر {totalUsers} ھېساباتنىڭ {processedUsers} سانى بىر تەرەپ قىلىندى.",
+    "Preparing …" : "تەييارلاۋاتىدۇ  ...",
     "Refresh" : "يېڭىلاش",
+    "All files have been santized for Windows filename support." : "بارلىق ھۆججەتلەر Windows ھۆججەت نامىنى قوللاش ئۈچۈن تازىلىنىدۇ.",
+    "Some files could not be sanitized, please check your logs." : "بەزى ھۆججەتلەرنى تازىلىغىلى بولمىدى، خاتىرىلىرىڭىزنى تەكشۈرۈپ بېقىڭ.",
+    "Sanitization errors" : "تازىلاش خاتالىقى",
+    "Not sanitized filenames" : "تازىلانمىغان ھۆججەت نامى قالمىدى",
+    "Windows filename support has been enabled." : "Windows ھۆججەت نامىنى قوللاش ئىقتىدارى قوزغىتىلدى.",
+    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "بۇ ئىشلەتكۈچىلەرنىڭ قوللىمايدىغان ھۆججەت ئىسمى بىلەن يېڭى ھۆججەتلەرنى قۇرۇشىنى توسسىمۇ، مەۋجۇت ھۆججەتلەرنىڭ ئىسمى ئۆزگەرتىلمىگەن، شۇڭا Windows سىستېمىسىدا يەنىلا ماسلىشىشنى بۇزۇلۇشى مۇمكىن.",
+    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "سىز خاتا ئىسىملىق ھۆججەتلەرنىڭ ئىسمىنى ئۆزگەرتەلەيسىز، بۇ ئارقا كۆرۈنۈشتە ئېلىپ بېرىلىدۇ ھەمدە بىر ئاز ۋاقىت كېتىشى مۇمكىن.",
+    "Please note that this may cause high workload on the sync clients." : "بۇنىڭ سىنخرونلاشتۇرۇش خېرىدارلىرىغا يۇقىرى يۈك ئېلىپ كېلىشى مۇمكىنلىكىنى ئۇنۇتماڭ.",
     "Limit" : "چەك",
+    "This allows to configure how many users should be processed in one background job run." : "بۇ ئارقىلىق بىر قېتىم ئارقا كۆرۈنۈش خىزمىتى ئىجرا قىلىنىۋاتقاندا قانچە ئىشلەتكۈچىنىڭ بىر تەرەپ قىلىنىشى كېرەكلىكىنى تەڭشەشكە بولىدۇ.",
+    "Sanitize filenames" : "ھۆججەت نامىنى تازىلا",
+    "(starting)" : "(باشلىندۇ)",
     "Fill template fields" : "قېلىپ بۆلەكلىرىنى تولدۇرۇڭ",
+    "Submitting fields …" : "ئورۇنلارنى تاپشۇرۋاتىدۇ  ...",
     "Submit" : "يوللاڭ",
     "Choose a file or folder to transfer" : "يۆتكەش ئۈچۈن ھۆججەت ياكى ھۆججەت قىسقۇچنى تاللاڭ",
     "Transfer" : "يۆتكەش",
@@ -125,36 +209,24 @@ OC.L10N.register(
     "Choose file or folder to transfer" : "يۆتكەش ئۈچۈن ھۆججەت ياكى ھۆججەت قىسقۇچنى تاللاڭ",
     "Change" : "ئۆزگەرتىش",
     "New owner" : "يېڭى خوجايىن",
+    "Keep {old}" : "{old} ساقلا",
+    "Keep without extension" : "كېڭەيتىلمىسىز ساقلا",
+    "Use {new}" : "{new} نى ئىشلەت",
+    "Remove extension" : "كېڭەيتىلمىنى ئۆچۈر",
+    "Change file extension" : "ھۆججەت كېڭەيتىلمىسىنى ئۆزگەرت",
+    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "ھۆججەت كېڭەيتىلمىسىنى «{old}» دىن «{new}» غا ئۆزگەرتسىڭىز، ھۆججەتنى ئوقۇغىلى بولمايدىغان ھالغا كەلتۈرۈشى مۇمكىن.",
+    "Removing the file extension \"{old}\" may render the file unreadable." : "«{old}» ھۆججەت كېڭەيتىلمىسىنى ئۆچۈرۈۋەتسىڭىز، ھۆججەتنى ئوقۇغىلى بولمايدىغان ھالغا كەلتۈرۈشى مۇمكىن.",
+    "Adding the file extension \"{new}\" may render the file unreadable." : "«{new}» ھۆججەت كېڭەيتىلمىسىنى قوشسىڭىز، ھۆججەتنى ئوقۇغىلى بولمايدىغان ھالغا كەلتۈرۈشى مۇمكىن.",
+    "Do not show this dialog again." : "بۇ دىئالوگنى قايتا كۆرسەتمە.",
     "Select file or folder to link to" : "ئۇلىنىدىغان ھۆججەت ياكى ھۆججەت قىسقۇچنى تاللاڭ",
     "Choose {file}" : "{file} نى تاللاڭ",
-    "Clipboard is not available" : "چاپلاش تاختىسى يوق",
     "Files settings" : "ھۆججەت تەڭشىكى",
-    "General" : "General",
-    "All files" : "بارلىق ھۆججەتلەر",
-    "Personal files" : "شەخسىي ھۆججەتلەر",
-    "Sort favorites first" : "ياقتۇرىدىغانلارنى رەتلەڭ",
-    "Sort folders before files" : "ھۆججەتلەرنى ھۆججەتتىن بۇرۇن تەرتىپلەڭ",
-    "Appearance" : "كۆرۈنۈش",
-    "Show hidden files" : "يوشۇرۇن ھۆججەتلەرنى كۆرسەت",
-    "Crop image previews" : "رەسىمنى ئالدىن كۆرۈش",
-    "Additional settings" : "قوشۇمچە تەڭشەكلەر",
-    "WebDAV" : "WebDAV",
-    "WebDAV URL" : "WebDAV URL",
-    "Copy" : "كۆچۈرۈڭ",
-    "Keyboard shortcuts" : "كۇنۇپكا تاختىسى تېزلەتمىسى",
-    "File actions" : "ھۆججەت ھەرىكىتى",
-    "Rename" : "ئات ئۆزگەرت",
-    "Delete" : "ئۆچۈر",
-    "Manage tags" : "خەتكۈچلەرنى باشقۇرۇش",
-    "Selection" : "تاللاش",
-    "Deselect all" : "ھەممىنى تاللاڭ",
-    "Navigation" : "يول باشلاش",
-    "View" : "كۆرۈش",
     "Share" : "ھەمبەھىرلەش",
     "Shared by link" : "ئۇلىنىش ئارقىلىق ئورتاقلاشتى",
     "Shared" : "ئورتاقلاشتى",
     "Switch to list view" : "تىزىملىك كۆرۈنۈشىگە ئالماشتۇرۇڭ",
     "Switch to grid view" : "كاتەكچە كۆرۈنۈشكە ئالماشتۇرۇڭ",
+    "The file could not be found" : "بۇ ھۆججەت تېپىلمىدى",
     "Upload was cancelled by user" : "ئىشلەتكۈچى يوللاش ئەمەلدىن قالدۇرۇلدى",
     "Not enough free space" : "يېتەرلىك بوشلۇق يوق",
     "Operation is blocked by access control" : "زىيارەتنى كونترول قىلىش ئارقىلىق مەشغۇلات توسۇلۇپ قالىدۇ",
@@ -167,18 +239,16 @@ OC.L10N.register(
     "Upload some content or sync with your devices!" : "بەزى مەزمۇنلارنى يۈكلەڭ ياكى ئۈسكۈنىڭىز بىلەن ماسقەدەملەڭ!",
     "Go back" : "قايتىڭ",
     "Views" : "كۆرۈنۈشلەر",
-    "You" : "سەن",
-    "Shared multiple times with different people" : "ئوخشىمىغان كىشىلەر بىلەن كۆپ قېتىم ئورتاقلاشتى",
-    "Error while loading the file data" : "ھۆججەت سانلىق مەلۇماتلىرىنى يۈكلەۋاتقاندا خاتالىق",
-    "Owner" : "ئىگىسى",
-    "Remove from favorites" : "Remove from favorites",
-    "Add to favorites" : "Add to favorites",
-    "Tags" : "بەلگەلەر",
+    "Loading …" : "يۈكلەۋاتىدۇ ...",
     "Your files" : "ھۆججەتلىرىڭىز",
     "Open in files" : "ھۆججەتلەرنى ئېچىڭ",
     "File cannot be accessed" : "ھۆججەتنى زىيارەت قىلغىلى بولمايدۇ",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "ھۆججەت تېپىلمىدى ياكى ئۇنى كۆرۈش ھوقۇقىڭىز يوق. ئەۋەتكۈچىدىن ئورتاقلىشىشنى سوراڭ.",
+    "No search results for “{query}”" : "\"{query}\" نىڭ ئىزدەش نەتىنجىسى يوق",
+    "Search for files" : "ھۆججەتلەرنى ئىزدە",
     "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "ھۆججەت نامىنى چەكلەشكە يول قويۇڭ ، ھۆججەتلەرنىڭ بارلىق خېرىدارلار بىلەن ماسقەدەملىنىشىگە كاپالەتلىك قىلىڭ. سۈكۈتتىكى ھالەتتە POSIX (ئىناۋەتلىك Linux ياكى macOS) دىكى بارلىق ھۆججەت ئىسمى رۇخسەت قىلىنىدۇ.",
+    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Windows بىلەن ماس كېلىدىغان ھۆججەت ئىسىملىرىنى قوزغىتقاندىن كېيىن، مەۋجۇت ھۆججەتلەرنى ئۆزگەرتكىلى بولمايدۇ، لېكىن ئۇلارنىڭ ئىگىسى ئۇلارنى كۈچكە ئىگە يېڭى ئىسىملار بىلەن ئۆزگەرتەلەيدۇ.",
+    "Failed to toggle Windows filename support" : "Windows ھۆججەت نامىنى قوللاش ئىقتىدارىنى ئالماشتۇرۇش مەغلۇب بولدى",
     "Files compatibility" : "ھۆججەتلەرنىڭ ماسلىشىشچانلىقى",
     "Enforce Windows compatibility" : "Windows ماسلىشىشچانلىقىنى كۈچەيتىڭ",
     "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "بۇ Windows سىستېمىسىدا كۈچكە ئىگە بولمىغان ھۆججەت نامىنى چەكلەيدۇ ، مەسىلەن زاپاس ئىسىم ياكى ئالاھىدە ھەرپلەرنى ئىشلىتىش دېگەندەك. ئەمما بۇ ئەھۋال سەزگۈرلۈكىنىڭ ماسلىشىشچانلىقىنى ئىجرا قىلمايدۇ.",
@@ -187,6 +257,21 @@ OC.L10N.register(
     "Pick a template for {name}" : "{name} for نىڭ قېلىپىنى تاللاڭ",
     "Create a new file with the selected template" : "تاللانغان قېلىپ بىلەن يېڭى ھۆججەت قۇر",
     "Creating file" : "ھۆججەت قۇرۇش",
+    "Save as {displayName}" : "{displayName} سۈپىتىدە ساقلا",
+    "Save as …" : "سۈپىتىدە ساقلا  ...",
+    "Converting files …" : "ھۆججەتلەرنى ئايلاندۇرۋاتىدۇ  ...",
+    "Failed to convert files: {message}" : "ھۆججەتنى ئايلاندۇرۇش مەغلۇپ بولدى: {message}",
+    "All files failed to be converted" : "ھەممە ھۆججەتنى ئايلاندۇرۇش مەغلۇپ بولدى",
+    "One file could not be converted: {message}" : "بىر ھۆججەتنى ئايلاندۇرغىلى بولمىدى: {message}",
+    "_%n file could not be converted_::_%n files could not be converted_" : ["%n ھۆججەتنى ئايلاندۇرغىلى بولمىدى","%n ھۆججەتنى ئايلاندۇرغىلى بولمىدى"],
+    "_%n file converted_::_%n files converted_" : ["%nھۆججەت ئايلاندۇرۇلدى","%n ئايلاندۇرۇلدى"],
+    "Files converted" : "ھۆججەتلەر ئايلاندۇرۇلدى",
+    "Failed to convert files" : "ھۆججەتلەرنى ئايلاندۇرۇش مەغلۇب بولدى",
+    "Converting file …" : "ھۆججەتنى ئايلاندۇرۋاتىدۇ  ...",
+    "File successfully converted" : "ھۆججەت مۇۋاپىقىيەتلىك ئايلاندۇرۇلدى",
+    "Failed to convert file: {message}" : "ھۆججەتنى ئايلاندۇرۇش مەغلۇپ بولدى: {message}",
+    "Failed to convert file" : "ھۆججەتنى ئايلاندۇرۇش مەغلۇپ بولدى",
+    "Delete" : "ئۆچۈر",
     "Leave this share" : "بۇ ئۈلۈشنى قالدۇرۇڭ",
     "Leave these shares" : "بۇ پايلارنى قالدۇرۇڭ",
     "Disconnect storage" : "ساقلاشنى ئۈزۈڭ",
@@ -197,27 +282,45 @@ OC.L10N.register(
     "Delete files" : "ھۆججەتلەرنى ئۆچۈرۈڭ",
     "Delete folder" : "ھۆججەت قىسقۇچنى ئۆچۈرۈڭ",
     "Delete folders" : "ھۆججەت قىسقۇچلارنى ئۆچۈرۈڭ",
+    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["سىز {count} تارماقنى مەڭگۈلۈك ئۆچۈرمەكچى بولىۋاتىسىز","سىز {count} تارماقنى مەڭگۈلۈك ئۆچۈرمەكچى بولىۋاتىسىز"],
+    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["سىز {count} تارماقنى ئۆچۈرمەكچى بولىۋاتىسىز","سىز {count} تارماقنى ئۆچۈرمەكچى بولىۋاتىسىز"],
     "Confirm deletion" : "ئۆچۈرۈشنى جەزملەشتۈرۈڭ",
     "Cancel" : "ۋاز كەچ",
     "Download" : "چۈشۈر",
+    "The requested file is not available." : "تەلەپ قىلىنغان ھۆججەت مەۋجۇت ئەمەس.",
+    "The requested files are not available." : "تەلەپ قىلىنغان ھۆججەتلەر مەۋجۇت ئەمەس.",
+    "Add to favorites" : "ياقتۇردىغانغا قوش",
+    "Remove from favorites" : "ياقتۇردىغاندىن چىقىرۋەت",
+    "Add or remove favorite" : "ياقتۇردىغانغا قوش ياكى ئۆچۈر",
+    "Moving \"{source}\" to \"{destination}\" …" : "\"{source}\" نى \" {destination}\" غا يۆتكەۋاتىدۇ  ...",
+    "Copying \"{source}\" to \"{destination}\" …" : "\"{source}\" نى \" {destination}\" غا كۆچۈرۋاتىدۇ  ...",
+    "Destination is not a folder" : "نىشان بىر قىسقۇچ ئەمەس",
+    "This file/folder is already in that directory" : "بۇ ھۆججەت/قىسقۇچ ئۇ مۇندەرىجىدە مەۋجۇت",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "ھۆججەت ياكى ھۆججەت قىسقۇچنى ئۆزىڭىزگە ياكى تارماق قىسقۇچقا يۆتكىيەلمەيسىز",
     "(copy)" : "(كۆپەيتىلگەن نۇسخىسى)",
-    "(copy %n)" : "(% n)",
+    "(copy %n)" : "(%nنى كۆچۈر)",
     "A file or folder with that name already exists in this folder" : "بۇ ھۆججەت قىسقۇچتا بۇ ئىسىم بار ھۆججەت ياكى ھۆججەت قىسقۇچ بار",
     "The files are locked" : "ھۆججەتلەر قۇلۇپلاندى",
     "The file does not exist anymore" : "بۇ ھۆججەت ئەمدى مەۋجۇت ئەمەس",
     "Choose destination" : "مەنزىلنى تاللاڭ",
     "Copy to {target}" : "{target} غا كۆچۈرۈڭ",
+    "Copy" : "كۆچۈرۈڭ",
     "Move to {target}" : "{target} يۆتكەڭ",
-    "Move" : "Move",
+    "Move" : "يۆتكە",
     "Move or copy operation failed" : "يۆتكەش ياكى كۆچۈرۈش مەشغۇلاتى مەغلۇپ بولدى",
     "Move or copy" : "يۆتكەش ياكى كۆچۈرۈش",
+    "Open folder" : "ھۆججەت قىسقۇچنى ئېچىڭ",
     "Open folder {displayName}" : "ھۆججەت قىسقۇچ {displayName}",
     "Open in Files" : "ھۆججەتلەرنى ئېچىڭ",
     "Open locally" : "يەرلىكتە ئېچىڭ",
     "Failed to redirect to client" : "خېرىدارغا قايتا نىشانلاش مەغلۇپ بولدى",
     "Open file locally" : "ھۆججەتنى يەرلىكتە ئېچىڭ",
+    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "ھۆججەت ھازىر ئۈسكۈنىڭىزدە ئېچىلىشى كېرەك. ئەگەر ئېچىلمىسا، ئۈستەل يۈزى ئەپىڭىزنىڭ ئورنىتىلغانلىقىنى تەكشۈرۈڭ.",
+    "Retry and close" : "قايتا سىناپ بېقىڭ ۋە تاقاپ قويۇڭ",
+    "Open online" : "توردا ئاچ",
+    "Rename" : "ئات ئۆزگەرت",
     "Details" : "تەپسىلاتى",
+    "Unfavorite" : "ياقتۇرمايدىغان",
     "View in folder" : "قىسقۇچتا كۆرۈش",
     "Today" : "بۈگۈن",
     "Last 7 days" : "ئاخىرقى 7 كۈن",
@@ -226,10 +329,10 @@ OC.L10N.register(
     "Last year ({year})" : "ئۆتكەن يىلى ({year})",
     "Documents" : "ھۆججەتلەر",
     "Spreadsheets" : "ئېلېكترونلۇق جەدۋەل",
-    "Presentations" : "Presentations",
+    "Presentations" : "لېكسىيە",
     "PDFs" : "PDF",
     "Folders" : "ھۆججەت قىسقۇچ",
-    "Audio" : "Audio",
+    "Audio" : "ئاۋاز",
     "Images" : "سۈرەتلەر",
     "Videos" : "سىنلار",
     "Created new folder \"{name}\"" : "يېڭى ھۆججەت قىسقۇچ \"{name}\" قۇرۇلدى",
@@ -238,7 +341,8 @@ OC.L10N.register(
     "Templates" : "قېلىپلار",
     "New template folder" : "يېڭى قېلىپ ھۆججەت قىسقۇچى",
     "In folder" : "ھۆججەت قىسقۇچتا",
-    "Search in folder: {folder}" : "ھۆججەت قىسقۇچتىن ئىزدەش: {folder} قىسقۇچ}",
+    "Search in all files" : "ئۇ ھۆججەتلەرنىڭ ھەممىسىدە ئىزدە",
+    "Search in folder: {folder}" : "ھۆججەت قىسقۇچتىن ئىزدەش: {folder} قىسقۇچ",
     "One of the dropped files could not be processed" : "تاشلانغان ھۆججەتلەرنىڭ بىرىنى بىر تەرەپ قىلالمىدى",
     "Your browser does not support the Filesystem API. Directories will not be uploaded" : "توركۆرگۈڭىز Filesystem API نى قوللىمايدۇ. مۇندەرىجە يۈكلەنمەيدۇ",
     "No files to upload" : "يۈكلەيدىغان ھۆججەت يوق",
@@ -256,8 +360,12 @@ OC.L10N.register(
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{dir}\" ھۆججەت قىسقۇچىدا \"{newName}\" ئىسمى ئاللىبۇرۇن ئىشلىتىلگەن. باشقا ئىسىمنى تاللاڭ.",
     "Could not rename \"{oldName}\"" : "\"{oldName}\" نىڭ نامىنى ئۆزگەرتەلمىدى",
     "This operation is forbidden" : "بۇ مەشغۇلات مەنئى قىلىنىدۇ",
+    "This folder is unavailable, please try again later or contact the administration" : "بۇ قىسقۇچ ئىشلىتىلمەيدۇ، كېيىن قايتا سىناپ بېقىڭ ياكى باشقۇرۇش بىلەن ئالاقىلىشىڭ.",
     "Storage is temporarily not available" : "ساقلاش ۋاقتىنى ۋاقىتلىق ئىشلەتكىلى بولمايدۇ",
     "Unexpected error: {error}" : "ئويلىمىغان خاتالىق: {error}",
+    "_%n file_::_%n files_" : ["%n ھۆججەت","%n ھۆججەتلەر"],
+    "_%n folder_::_%n folders_" : ["%n قىسقۇچ","%n قىسقۇچلار"],
+    "_%n hidden_::_%n hidden_" : ["يۇشۇرۇن %n","يۇشۇرۇن %n"],
     "Filename must not be empty." : "ھۆججەت ئىسمى بوش بولماسلىقى كېرەك.",
     "\"{char}\" is not allowed inside a filename." : "ھۆججەت نامىدا \"{char}\" رۇخسەت قىلىنمايدۇ.",
     "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" زاپاس ئىسىم بولۇپ ، ھۆججەت نامىغا رۇخسەت قىلىنمايدۇ.",
@@ -267,6 +375,7 @@ OC.L10N.register(
     "No favorites yet" : "ياقتۇرىدىغانلار تېخى يوق",
     "Files and folders you mark as favorite will show up here" : "سىز ياقتۇرىدىغان ھۆججەت ۋە ھۆججەت قىسقۇچلار بۇ يەردە كۆرۈنىدۇ",
     "List of your files and folders." : "ھۆججەت ۋە ھۆججەت قىسقۇچلىرىڭىزنىڭ تىزىملىكى.",
+    "Folder tree" : "قىسقۇچ شېخى",
     "List of your files and folders that are not shared." : "ئورتاقلاشمىغان ھۆججەت ۋە ھۆججەت قىسقۇچلىرىڭىزنىڭ تىزىملىكى.",
     "No personal files found" : "شەخسىي ھۆججەت تېپىلمىدى",
     "Files that are not shared will show up here." : "ئورتاقلاشمىغان ھۆججەتلەر بۇ يەردە كۆرۈنىدۇ.",
@@ -275,31 +384,71 @@ OC.L10N.register(
     "No recently modified files" : "يېقىندا ئۆزگەرتىلگەن ھۆججەت يوق",
     "Files and folders you recently modified will show up here." : "سىز يېقىندا ئۆزگەرتكەن ھۆججەت ۋە ھۆججەت قىسقۇچلار بۇ يەردە كۆرۈنىدۇ.",
     "Search" : "ئىزدەش",
+    "Search results within your files." : "ھۆججەتلىرىڭىزدىكى ئىزدەش نەتىنجىسى",
     "No entries found in this folder" : "بۇ ھۆججەت قىسقۇچتا ھېچقانداق مەزمۇن تېپىلمىدى",
     "Select all" : "ھەممىنى تاللاڭ",
     "Upload too large" : "يۈكلەندىغىنى بەك چوڭ",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "سىز يۈكلىمەكچى بولغان ھۆججەتلەر بۇ مۇلازىمېتىردا ھۆججەت يوللاشنىڭ ئەڭ چوڭ چوڭلۇقىدىن ئېشىپ كەتتى.",
-    "Upload (max. %s)" : "يۈكلەش (max.% S)",
+    "%1$s (renamed)" : "%1$s (قايتا ئسىملاندى)",
+    "renamed file" : "قايتا ئىسىملانغان ھۆججەت",
+    "Upload (max. %s)" : "يۈكلەش (ئەڭ چوڭ %s)",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Windows بىلەن ماس كېلىدىغان ھۆججەت ئىسىملىرىنى قوزغىتقاندىن كېيىن، مەۋجۇت ھۆججەتلەرنى ئۆزگەرتكىلى بولمايدۇ، لېكىن ئۇلارنىڭ ئىگىسى ئۇلارنى يېڭى ئىسىملار بىلەن ئۆزگەرتەلەيدۇ.",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "بۇ تەڭشەكنى قوزغىتىپ بولغاندىن كېيىن ھۆججەتلەرنى ئاپتوماتىك كۆچۈرۈشكىمۇ بولىدۇ، occ بۇيرۇقى ھەققىدىكى ھۆججەتلەرگە قاراڭ.",
+    "\"{displayName}\" failed on some elements" : "\"{displayName}\" بەزى تارماقلاردا مەغلۇپ بولدى",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" تۈركۈمدىكى ھەرىكەت مۇۋەپپەقىيەتلىك ئىجرا قىلىندى",
     "\"{displayName}\" action failed" : "\"{displayName}\" ھەرىكىتى مەغلۇپ بولدى",
+    "Submitting fields …" : "ئورۇنلارنى تاپشۇرۋاتىدۇ ...",
     "\"{displayName}\" action executed successfully" : "\"{displayName}\" ھەرىكىتى مۇۋەپپەقىيەتلىك ئىجرا قىلىندى",
+    "Filter file names …" : "ھۆججەت ناملىرىنى سۈز ...",
+    "Clipboard is not available" : "چاپلاش تاختىسى يوق",
     "WebDAV URL copied to clipboard" : "WebDAV URL چاپلاش تاختىسىغا كۆچۈرۈلدى",
     "Enable the grid view" : "كاتەكچە كۆرۈنۈشىنى قوزغىتىڭ",
     "Enable folder tree" : "ھۆججەت قىسقۇچنى قوزغىتىڭ",
+    "WebDAV" : "WebDAV",
     "Copy to clipboard" : "چاپلاش تاختىسىغا كۆچۈرۈڭ",
     "Use this address to access your Files via WebDAV" : "بۇ ئادرېسنى ئىشلىتىپ WebDAV ئارقىلىق ھۆججەتلىرىڭىزنى زىيارەت قىلىڭ",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "ئەگەر سىز 2FA نى قوزغىتىپ قويغان بولسىڭىز ، بۇ يەرنى چېكىپ چوقۇم يېڭى ئەپ پارولى قۇرالايسىز ۋە ئىشلىتىڭ.",
+    "Prevent warning dialogs from open or reenable them." : "ئاگاھلاندۇرۇش سۆزلەشكۈلىرىنىڭ ئېچىلىشىنىڭ ئالدىنى ئېلىڭ ياكى ئۇلارنى قايتا قوزغىتىڭ.",
+    "Show a warning dialog when changing a file extension." : "ھۆججەت كېڭەيتىلمىسىنى ئۆزگەرتكەندە ئاگاھلاندۇرۇش سۆزلەشكۈسىنى كۆرسىتىش.",
+    "Keyboard shortcuts" : "ھەرىپتاختا تېزلەتمىسى",
+    "Speed up your Files experience with these quick shortcuts." : "بۇ تېز سۈرئەتلىك قىسقا يوللار بىلەن ھۆججەت تەجرىبىڭىزنى تېزلىتىڭ.",
+    "Open the actions menu for a file" : "ھۆججەت ئۈچۈن ھەرىكەت تىزىملىكىنى ئېچىڭ",
+    "Rename a file" : "بىر ھۆججەتنىڭ نامىنى ئۆزگەرت",
+    "Delete a file" : "بىر ھۆججەتنى ئۆچۈر",
+    "Favorite or remove a file from favorites" : "ھۆججەتنى ياقتۇرۇشلارغا قوشۇش ياكى ياقتۇرۇشلاردىن ئۆچۈرۈش",
+    "Manage tags for a file" : "ھۆججەتنىڭ بەلگىلىرىنى باشقۇرۇش",
+    "Deselect all files" : "ھەممە ھۆججەتنى تاللىما",
+    "Select or deselect a file" : "بىر ھۆججەتنى تاللا ياكى تاللىما",
+    "Select a range of files" : "بىر دائىردىكى ھۆججەتنى تاللا",
+    "Navigate to the parent folder" : "باش قىسقۇچقا بار",
+    "Navigate to the file above" : "ئالدىدىكى قىسقۇچقا بار",
+    "Navigate to the file below" : "كىيىنكى ھۆججەتكە بار",
+    "Navigate to the file on the left (in grid mode)" : "سول تەرەپتىكى ھۆججەتكە يۆتكىلىڭ (تور شەكلىدە)",
+    "Navigate to the file on the right (in grid mode)" : "ئوڭ تەرەپتىكى ھۆججەتكە يۆتكىلىڭ (تور شەكلىدە)",
+    "Toggle the grid view" : "تور كۆرۈنۈشىنى ئالماشتۇر",
+    "Open the sidebar for a file" : "ھۆججەتنىڭ بانبالدىقىنى ئاچ",
+    "You" : "سەن",
+    "Shared multiple times with different people" : "ئوخشىمىغان كىشىلەر بىلەن كۆپ قېتىم ئورتاقلاشتى",
+    "Unable to change the favorite state of the file" : "بۇ ھۆججەتنىڭ ياقتۇردىغان ھالىنىنى ئۆزگەتكىلى بولمىدى",
+    "Error while loading the file data" : "ھۆججەت سانلىق مەلۇماتلىرىنى يۈكلەۋاتقاندا خاتالىق",
+    "Tags" : "بەلگەلەر",
+    "Save as …" : "سۈپىتىدە ساقلا ...",
+    "Converting files …" : "ھۆججەتنى ئايلاندۇرۋاتىدۇ ...",
+    "Converting file …" : "ھۆججەتنى ئايلاندۇرۋاتىدۇ ...",
     "Deletion cancelled" : "ئۆچۈرۈش ئەمەلدىن قالدۇرۇلدى",
     "Edit locally" : "يەرلىكتە تەھرىرلەڭ",
     "Moving \"{source}\" to \"{destination}\" …" : "\"{source}\" نى \"{destination}\" غا يۆتكەش…",
     "Copying \"{source}\" to \"{destination}\" …" : "\"{source}\" نى \"{destination}\" غا كۆچۈرۈش…",
     "Move cancelled" : "يۆتكەش ئەمەلدىن قالدۇرۇلدى",
-    "Cancelled move or copy of \"{filename}\"." : "«{filename} ئىسمى}» نىڭ يۆتكىلىشى ياكى كۆپەيتىلگەن نۇسخىسى.",
+    "Cancelled move or copy of \"{filename}\"." : "«{filename}» نىڭ يۆتكىلىشى ياكى كۆپەيتىلگەن نۇسخىسى.",
     "Cancelled move or copy operation" : "يۆتكەش ياكى كۆچۈرۈش مەشغۇلاتى ئەمەلدىن قالدۇرۇلدى",
     "Open details" : "تەپسىلاتلارنى ئېچىڭ",
     "Photos and images" : "رەسىم ۋە رەسىم",
     "New folder creation cancelled" : "يېڭى ھۆججەت قىسقۇچ قۇرۇش ئەمەلدىن قالدۇرۇلدى",
     "This directory is unavailable, please check the logs or contact the administrator" : "بۇ مۇندەرىجىنى ئىشلەتكىلى بولمايدۇ ، خاتىرىلەرنى تەكشۈرۈپ بېقىڭ ياكى باشقۇرغۇچى بىلەن ئالاقىلىشىڭ",
-    "All folders" : "بارلىق ھۆججەت قىسقۇچلار"
+    "All folders" : "بارلىق ھۆججەت قىسقۇچلار",
+    "Search everywhere …" : "ھەممە يەردىن ئىزدە ...",
+    "Search here …" : "بۇ يەردە ئىزدە ...",
+    "Preparing …" : "تەييارلىنۋاتىدۇ ..."
 },
 "nplurals=2; plural=(n != 1);");
