@@ -6,7 +6,6 @@ OC.L10N.register(
     "Deleted files and folders in the trash bin (may expire during export if you are low on storage space)" : "Các tệp và thư mục đã xóa trong thùng rác (có thể hết hạn trong quá trình xuất nếu bạn sắp hết dung lượng lưu trữ)",
     "Restore" : "Khôi phục",
     "Cancel" : "Hủy bỏ",
-    "Deletion cancelled" : "Thao tác xóa bị hủy",
     "Deleted" : "Đã xóa",
     "A long time ago" : "Một khoảng thời gian trước",
     "Unknown" : "Không xác định",
@@ -14,6 +13,7 @@ OC.L10N.register(
     "You" : "You",
     "List of files that have been deleted." : "Danh sách các tập tin đã bị xóa.",
     "No deleted files" : "Không có tập tin bị xóa",
-    "Files and folders you have deleted will show up here" : "Các tập tin và thư mục bạn đã xóa sẽ hiển thị ở đây"
+    "Files and folders you have deleted will show up here" : "Các tập tin và thư mục bạn đã xóa sẽ hiển thị ở đây",
+    "Deletion cancelled" : "Thao tác xóa bị hủy"
 },
 "nplurals=1; plural=0;");
