@@ -133,6 +133,10 @@ class RelatedService {
 	): array {
 		$this->logger->debug('retrieving related to item ' . $providerId . '.' . $itemId);
 
+		if ($providerId && !$this->appManager->isInstalled($providerId)) {
+			return [];
+		}
+
 		try {
 			// we generate a related resource for current item, including a full
 			// list of recipients and virtual group
@@ -589,7 +593,7 @@ class RelatedService {
 			}
 		}
 
-		throw new RelatedResourceProviderNotFound();
+		throw new RelatedResourceProviderNotFound("Failed to find provider {$relatedProviderId}");
 	}
 
 	/**
