@@ -1,25 +1,12 @@
 OC.L10N.register(
     "settings",
     {
-    "Private" : "Priváu",
-    "Only visible to people matched via phone number integration through Talk on mobile" : "Namás ye visible pa les persones que concasen pela integración del númberu de teléfonu pente Talk en móviles",
-    "Local" : "Llocal",
-    "Only visible to people on this instance and guests" : "Namás ye visible pa les persones d'esta instancia y los convidaos",
-    "Federated" : "Federada",
-    "Only synchronize to trusted servers" : "Namás sincronizar con sirvidores d'enfotu",
-    "Published" : "Espublizóse",
-    "Synchronize to trusted servers and the global and public address book" : "Sincroniza con sirvidores d'enfotu y la llibreta de direiciones global y pública",
-    "Verify" : "Verificar",
-    "Verifying …" : "Verificando…",
     "Unable to change password" : "Nun ye posible camudar la contraseña",
     "Very weak password" : "La contraseña ye mui poco segura",
     "Weak password" : "La contraseña ye poco segura",
     "So-so password" : "La contraseña ye normal",
     "Good password" : "La contraseña ye segura",
     "Strong password" : "La contraseña ye mui segura",
-    "Groups" : "Grupos",
-    "Group list is empty" : "La llista de grupos ta balera",
-    "Unable to retrieve the group list" : "Nun ye posible recuperar la llista de grupos",
     "{actor} added you to group {group}" : "{actor} metióte nel grupu «{group}»",
     "You added {user} to group {group}" : "Metiesti a {user} nel grupu «{group}»",
     "{actor} added {user} to group {group}" : "{actor} metió a {user} nel grupu «{group}»",
@@ -123,6 +110,8 @@ OC.L10N.register(
     "Background jobs" : "Trabayos en segundu planu",
     "Unlimited" : "Ensin llende",
     "Verifying" : "Verificando",
+    "Verifying …" : "Verificando…",
+    "Verify" : "Verificar",
     "App directories owner" : "Propietariu de los direutorios d'aplicación",
     "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:\n%s" : "Dalgunos direutorios d'aplicación son propiedá d'otru usuariu y non del usuariu del sirvidor web. Esto pue pasar si dalgunes aplicaciones d'instalaron manualmente. Comprueba los permisos de los direutorios d'aplicación siguientes:\n%s",
     "App directories have the correct owner \"%s\"" : "Los direutorios d'aplicación tienen el propietariu correutu «%s»",
@@ -234,6 +223,7 @@ OC.L10N.register(
     "No apps found for your version" : "Nun s'atopó nenguna aplicación pa esta versión",
     "_Update_::_Update all_" : ["Anovar","Anovar too"],
     "Failed to create group" : "Nun se pue crear el grupu",
+    "Groups" : "Grupos",
     "Creating group…" : "Creando'l grupu…",
     "Create group" : "Crear el grupu",
     "Group name" : "Nome del grupu",
@@ -346,23 +336,23 @@ OC.L10N.register(
     "Set as profile picture" : "Afitar como semeya del perfil",
     "You are a member of the following groups:" : "Yes miembru de los grupos siguientes:",
     "Your full name" : "Nome completu",
+    "Unable to update primary email address" : "Nun ye posible desaniciar la direición de corréu electrónicu primaria",
+    "Unable to delete additional email address" : "Nun ye posible desaniciar la direición de corréu electrónicu adicional",
+    "No email address set" : "Nun s'afitó nenguna direición de corréu electrónicu",
     "Remove primary email" : "Quitar la direición de corréu electrónicu",
     "Delete email" : "Desaniciar la direición de corréu electrónicu",
     "This address is not confirmed" : "Esta direición nun ta confirmada",
     "Set as primary email" : "Afitar como direición de corréu electrónicu primaria",
     "Unable to delete primary email address" : "Nun ye posible desaniciar la direición de corréu electrónicu primaria",
-    "Unable to update primary email address" : "Nun ye posible desaniciar la direición de corréu electrónicu primaria",
     "Unable to add additional email address" : "Nun ye posible amestar la direición de corréu electrónicu adicional",
     "Unable to update additional email address" : "Nun ye posible amestar la direición de corréu electrónicu adicional",
-    "Unable to delete additional email address" : "Nun ye posible desaniciar la direición de corréu electrónicu adicional",
-    "No email address set" : "Nun s'afitó nenguna direición de corréu electrónicu",
+    "No language set" : "Nun s'afitó nenguna llingua",
     "Unable to update language" : "Nun ye posible anovar la llingua",
     "Languages" : "Llingües",
     "Help translate" : "Ayudar a traducir",
-    "No language set" : "Nun s'afitó nenguna llingua",
+    "No locale set" : "Nun s'afitó nenguna locale",
     "Unable to update locale" : "Nun ye posible anovar la locale",
     "Locales" : "Locales",
-    "No locale set" : "Nun s'afitó nenguna locale",
     "Your city" : "Ciudá",
     "Your organisation" : "Organización",
     "Your phone number" : "Númberu de teléfonu",
@@ -383,12 +373,12 @@ OC.L10N.register(
     "Change" : "Camudar",
     "Delete" : "Desaniciar",
     "Reshare" : "Volver compartir",
+    "School" : "Escuela",
     "Default language" : "Llingua predeterminada",
     "Common languages" : "Llingües habituales",
     "Other languages" : "Otres llingües",
     "Password change is disabled because the master key is disabled" : "El cambéu de contraseña ta desactiváu porque la clave maestra ta desactivada",
     "No accounts" : "Nun hai nenguna cuenta",
-    "Loading accounts …" : "Cargando les cuentes…",
     "Manager" : "Xestor",
     "Set line manager" : "Afitar el xestor de llinies",
     "New account" : "Cuenta nueva",
@@ -418,7 +408,6 @@ OC.L10N.register(
     "Password was successfully changed" : "La contraseña camudó correutamente",
     "Email was successfully changed" : "La direición de corréu electrónicu camudó correutamente",
     "Welcome mail sent!" : "¡Unvióse'l mensaxe d'acoyida!",
-    "Loading account …" : "Cargando la cuenta…",
     "Change display name" : "Camudar el nome visible",
     "Set new password" : "Afitar una contraseña nueva",
     "You do not have permissions to see the details of this account" : "Nun tienes permisu pa ver los detalles d'esta cuenta",
@@ -442,19 +431,23 @@ OC.L10N.register(
     "Passwordless authentication requires a secure connection." : "L'autenticación ensin contraseña rique una conexón segura.",
     "Add WebAuthn device" : "Amestar preséu WebAuthn",
     "Please authorize your WebAuthn device." : "Autoriza'l preséu WebAuthn.",
-    "Adding your device …" : "Amestando'l preséu…",
     "Unnamed device" : "Preséu ensin nome",
     "Passwordless Authentication" : "Autenticación ensin contraseña",
     "Set up your account for passwordless authentication following the FIDO2 standard." : "Configura una cuenta pa l'autenticación ensin contraseña siguiendo l'estándar FIDO2.",
     "No devices configured." : "Nun se configuró nengún preséu.",
     "The following devices are configured for your account:" : "Configuráronse los preseos siguientes pa la cuenta:",
     "Your browser does not support WebAuthn." : "El restolador nun ye compatible con WebAuthn.",
+    "Security & setup warnings" : "Alvertencies de seguranza y de configuración",
+    "Try again" : "Retentar",
+    "There are some errors regarding your setup." : "Hai dalgunos errores en rellación a la configuración.",
+    "There are some warnings regarding your setup." : "Hai dalgunes alvertencies en rellación a la configuración.",
     "You need to enable the File sharing App." : "Tienes d'activar l'aplicación de compartir ficheros.",
     "App Store" : "Tienda d'aplicaciones",
     "Loading app list" : "Cargando la llista d'aplicaciones",
     "Loading categories" : "Cargando les categoríes",
     "Developer documentation ↗" : "Documentación pa desendolcadores ↗",
     "Version {version}, {license}-licensed" : "Versión {version}, con llicencia {license}",
+    "Apply" : "Aplicar",
     "Admins" : "Alministradores",
     "Account group: {group}" : "Grupu de cuentes: {group}",
     "Account management" : "Xestión de cuentes",
@@ -474,6 +467,14 @@ OC.L10N.register(
     "Website" : "Sitiu web",
     "Profile visibility" : "Visibilidá del perfil",
     "Locale" : "Locale",
+    "Private" : "Priváu",
+    "Only visible to people matched via phone number integration through Talk on mobile" : "Namás ye visible pa les persones que concasen pela integración del númberu de teléfonu pente Talk en móviles",
+    "Local" : "Llocal",
+    "Only visible to people on this instance and guests" : "Namás ye visible pa les persones d'esta instancia y los convidaos",
+    "Federated" : "Federada",
+    "Only synchronize to trusted servers" : "Namás sincronizar con sirvidores d'enfotu",
+    "Published" : "Espublizóse",
+    "Synchronize to trusted servers and the global and public address book" : "Sincroniza con sirvidores d'enfotu y la llibreta de direiciones global y pública",
     "Discover" : "Descubrir",
     "Your apps" : "Les to aplicaciones",
     "Active apps" : "Aplicaciones actives",
@@ -521,21 +522,17 @@ OC.L10N.register(
     "Authentication required" : "L'autenticación ye obligatoria",
     "SMTP Password" : "Contraseña de SMTP",
     "Save" : "Guardar",
-    "Security & setup warnings" : "Alvertencies de seguranza y de configuración",
-    "There are some errors regarding your setup." : "Hai dalgunos errores en rellación a la configuración.",
-    "There are some warnings regarding your setup." : "Hai dalgunes alvertencies en rellación a la configuración.",
     "Reasons to use Nextcloud in your organization" : "Razones pa usar Nextcloud na to organzación",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desendolcáu pola {communityopen}comunidá de Nextcloud{linkclose}, el {githubopen}códigu fonte{linkclose} llicénciase baxo l'{licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Da un préstame a la nuesa páxina de Facebook",
     "Follow us on Mastodon" : "Síguinos en Mastodon",
     "Check out our blog" : "Revisa'l nuesu blogue",
     "Subscribe to our newsletter" : "Soscríbite al nuesu boletín",
+    "Group list is empty" : "La llista de grupos ta balera",
+    "Unable to retrieve the group list" : "Nun ye posible recuperar la llista de grupos",
     "Logged in account must be a subadmin" : "La cuenta qu'anició la sesión ha ser un soalministrador",
-    "File locking" : "Bloquéu de ficheros",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "El bloquéu de ficheros transaicional ta desactiváu y esto quiciabes produza problemes con condiciones de carrera. Activa «filelocking.enabled» nel ficheru config.php pa evitar estos problemes.",
-    "The PHP memory limit is below the recommended value of %s." : "La llende de memoria de PHP ye inferior al valor aconseyáu de %s.",
-    "Your biography" : "Biografía",
-    "You are using <strong>{usage}</strong>" : "Tas usando <strong>{usage}</strong>",
-    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Tas usando <strong>{usage}</strong> de <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)"
+    "Loading accounts …" : "Cargando les cuentes…",
+    "Loading account …" : "Cargando la cuenta…",
+    "Adding your device …" : "Amestando'l preséu…"
 },
 "nplurals=2; plural=(n != 1);");
