@@ -1,18 +1,12 @@
 OC.L10N.register(
     "settings",
     {
-    "Private" : "Privado",
-    "Local" : "Local",
-    "Federated" : "Federado",
-    "Verify" : "Verificar",
-    "Verifying …" : "Verificando ...",
     "Unable to change password" : "No fue posible cambiar la contraseña",
     "Very weak password" : "Contraseña muy débil",
     "Weak password" : "Contraseña débil",
     "So-so password" : "Contraseña aceptable",
     "Good password" : "Buena contraseña",
     "Strong password" : "Contraseña fuerte",
-    "Groups" : "Grupos",
     "{actor} changed your password" : "{actor} ha cambiado tu contraseña",
     "You changed your password" : "Cambiaste tu contraseña",
     "Your password was reset by an administrator" : "Tu contraseña ha sido restablecida por un adminsitrador",
@@ -74,6 +68,8 @@ OC.L10N.register(
     "Background jobs" : "Trabajos en segundo plano",
     "Unlimited" : "Ilimitado",
     "Verifying" : "Verificando",
+    "Verifying …" : "Verificando ...",
+    "Verify" : "Verificar",
     "Disabled" : "Deshabilitado",
     "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "La función de PHP \"set_time_limit\" no está disponible. Esto podría generar que la ejecución de scripts se detenga, rompiendo su instalación. Se recomienda ámpliamente habilitar esta función. ",
     "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP no parece estar configurado correctamente para consultar las variables de ambiente. La prueba con getenv(\"PATH\") sólo regresa una respuesta vacía.",
@@ -99,6 +95,7 @@ OC.L10N.register(
     "Level" : "Nivel",
     "Actions" : "Acciones",
     "No apps found for your version" : "No se encontraron aplicaciones para tu versión",
+    "Groups" : "Grupos",
     "Group name" : "Nombre del grupo",
     "Loading" : "Cargando",
     "Type" : "Tipo",
@@ -115,8 +112,6 @@ OC.L10N.register(
     "All" : "Todos",
     "No results" : "No hay resultados",
     "Update to {version}" : "Actualizar a {version}",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión mínima de Nextcloud asignada. Esto será un error en el futuro.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión máxima de Nextcloud asignada. Esto será un error en el futuro.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicación no puede ser instalada porque las siguientes dependencias no están satisfechas:",
     "Categories" : "Categorías",
     "Resources" : "Recursos",
@@ -127,9 +122,9 @@ OC.L10N.register(
     "Rate" : "Calificar",
     "Changelog" : "Bitácora de cambios",
     "Google Chrome for Android" : "Google Chrome para Android",
+    "{productName} Android app" : "{productName} aplicación Android",
     "This session" : "Esta sesión",
     "Allow filesystem access" : "Permitir acceso al sistema de archivos",
-    "Rename" : "Renombrar",
     "Revoke" : "Revocar",
     "Device" : "Dispositivo",
     "Last activity" : "Última actividad",
@@ -154,17 +149,14 @@ OC.L10N.register(
     "Submit" : "Enviar",
     "Current password" : "Contraseña actual",
     "New password" : "Nueva contraseña",
-    "Change password" : "Cambiar contraseña",
     "Picture provided by original account" : "Imagen proporcionada por la cuenta original ",
     "No email address set" : "No se ha establecido la dirección de correo electrónico",
     "Help translate" : "Ayuda a traducir",
     "Your phone number" : "Su número telefónico",
     "Your website" : "Tu sitio web",
-    "Add" : "Agregar",
-    "Create" : "Crear",
+    "Add" : "Guardar",
     "Change" : "Cambiar",
     "Delete" : "Borrar",
-    "Display name" : "Nombre a desplegar",
     "Email" : "Correo electrónico",
     "Quota" : "Cuota",
     "Language" : "Idioma",
@@ -175,13 +167,16 @@ OC.L10N.register(
     "Account actions" : "Acciones de la cuenta",
     "{size} used" : "{size} usado",
     "Delete account" : "Borrar cuenta",
-    "Done" : "Terminado",
     "Edit" : "Editar",
     "Show last login" : "Mostrar último inicio de sesión",
     "Send email" : "Enviar correo electrónico",
     "Default quota" : "Cuota predeterminada",
     "Unnamed device" : "Dispositivo sin nombre",
+    "Security & setup warnings" : "Advertencias de seguridad y configuración",
+    "Try again" : "Reintentar",
+    "All checks passed." : "Pasaron todas las verificaciones. ",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Como administrador, puedes hacer ajustes finos al comportamiento de compartir. Por favor consulta la documentación para más información. ",
+    "Apply" : "Aplicar",
     "Admins" : "Administradores",
     "Sending…" : "Enviando...",
     "Email sent" : "Correo electrónico enviado",
@@ -191,6 +186,9 @@ OC.L10N.register(
     "Full name" : "Nombre completo",
     "Phone number" : "Número de teléfono",
     "Website" : "Sitio web",
+    "Private" : "Privado",
+    "Local" : "Local",
+    "Federated" : "Federado",
     "Your apps" : "Tus aplicaciones",
     "Disabled apps" : "Aplicaciones deshabilitadas",
     "Updates" : "Actualizaciones",
@@ -214,11 +212,11 @@ OC.L10N.register(
     "Credentials" : "Credenciales",
     "SMTP Password" : "Contraseña SMTP",
     "Save" : "Guardar",
-    "Security & setup warnings" : "Advertencias de seguridad y configuración",
-    "All checks passed." : "Pasaron todas las verificaciones. ",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desarrollado por la  {communityopen}comunidad Nextcloud {linkclose}, el {githubopen}código fuente {linkclose} está licenciado bajo  {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Da un Like a nuestra página de Facebook",
     "Check out our blog" : "Visita nuestro blog",
-    "Subscribe to our newsletter" : "Suscribete a nuestro boletín"
+    "Subscribe to our newsletter" : "Suscribete a nuestro boletín",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión mínima de Nextcloud asignada. Esto será un error en el futuro.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión máxima de Nextcloud asignada. Esto será un error en el futuro."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
