@@ -1,22 +1,12 @@
 OC.L10N.register(
     "settings",
     {
-    "Private" : "פרטי",
-    "Local" : "מקומ",
-    "Federated" : "Federated",
-    "Only synchronize to trusted servers" : "לסנכרן מול שרתים מהימנים בלבד",
-    "Synchronize to trusted servers and the global and public address book" : "לסנכרן מול שרתים מהימנים וספר הכתובות הגלובלי והציבורי",
-    "Verify" : "אימות",
-    "Verifying …" : "מתבצע אימות…",
     "Unable to change password" : "לא ניתן לשנות את הססמה",
     "Very weak password" : "סיסמא מאוד חלשה",
     "Weak password" : "סיסמא חלשה",
     "So-so password" : "סיסמא ככה-ככה",
     "Good password" : "סיסמא טובה",
     "Strong password" : "סיסמא חזקה",
-    "Groups" : "קבוצות",
-    "Group list is empty" : "רשימת הקבוצות ריקה",
-    "Unable to retrieve the group list" : "לא ניתן לקבל את רשימת הקבוצות",
     "{actor} added you to group {group}" : "נוספת לקבוצה {group} על ידי {actor}",
     "You added {user} to group {group}" : "הוספת את {user} לקבוצה {group}",
     "{actor} added {user} to group {group}" : "ההוספה של {user} לקבוצה {group} נעשתה על ידי {actor}",
@@ -102,6 +92,8 @@ OC.L10N.register(
     "Background jobs" : "משימות רקע",
     "Unlimited" : "ללא הגבלה",
     "Verifying" : "מתבצע אימות",
+    "Verifying …" : "מתבצע אימות…",
+    "Verify" : "אימות",
     "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "במסד הנתונים חסרים כמה עמודות אופציונליות. בשל העובדה שהוספת עמודות בטבלאות גדולות עשויה להימשך זמן מה, הן לא נוספו אוטומטית כאשר הן יכולות להיות אופציונליות. על ידי הפעלת \"occ db: add-missing-column\", ניתן להוסיף את העמודות החסרות האלה באופן ידני בזמן שהמופע ממשיך לפעול. לאחר הוספת העמודות, חלק מהתכונות עשויות לשפר את ההיענות או את השימושיות.",
     "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "במסד הנתונים חסרים כמה מפתחות ראשיים. בשל העובדה שהוספת מפתחות ראשיים לטבלאות גדולות עשויה להימשך זמן מה, הם לא נוספו אוטומטית. על ידי הפעלת \"occ db: add-missing-primary-keys\", ניתן להוסיף מפתחות הראשיים החסרים האלה באופן ידני, בזמן שהמופע ממשיך לפעול.",
     "Disabled" : "מושבת",
@@ -150,6 +142,7 @@ OC.L10N.register(
     "Results from other categories" : "תוצאות מקטגוריות אחרות",
     "No apps found for your version" : "לא נמצאו יישומים לגרסה שלך",
     "_%n app has an update available_::_%n apps have an update available_" : ["לאחד היישומונים יש עדכון זמין","ל־%n יישומונים יש עדכון זמין","ל־%n יישומונים יש עדכון זמין"],
+    "Groups" : "קבוצות",
     "Group name" : "שם קבוצה",
     "Loading groups…" : "הקבוצות נטענות…",
     "Loading" : "בטעינה",
@@ -169,8 +162,6 @@ OC.L10N.register(
     "Limit app usage to groups" : "הגבלת השימוש ביישומון לקבוצות",
     "No results" : "אין תוצאות",
     "Update to {version}" : "עדכון ל־{version}",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "ליישומון זה לא מוקצית גרסת Nextcloud מזערית. מצב כזה עשוי להוביל לשגיאה בעתיד.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "ליישומון זה לא מוקצית גרסת Nextcloud מרבית. מצב כזה עשוי להוביל לשגיאה בעתיד.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "לא ניתן להתקין את יישום זה כיוון שייחסי התלות הבאים לא התקיימו:",
     "Categories" : "קטגוריות",
     "Resources" : "משאבים",
@@ -221,15 +212,18 @@ OC.L10N.register(
     "Picture provided by original account" : "תמונה סופקה על ידי חשבון מקור",
     "You are a member of the following groups:" : "הקבוצות הבאות כוללות אותך:",
     "No email address set" : "לא נקבעה כתובת דואר אלקטרוני",
+    "No language set" : "לא הוגדרה שפה",
     "Languages" : "שפות",
     "Help translate" : "עזרה בתרגום",
-    "No language set" : "לא הוגדרה שפה",
     "Week starts on {firstDayOfWeek}" : "השבוע מתחיל ב{firstDayOfWeek}",
     "Your phone number" : "מספר הטלפון שלך",
+    "Timezone" : "אזור זמן",
     "Add" : "הוספה",
+    "Create" : "יצירה",
     "Change" : "שינוי",
     "Delete" : "מחיקה",
     "Reshare" : "שיתוף מחדש",
+    "School" : "בית ספר",
     "Default language" : "שפת בררת מחדל",
     "Common languages" : "שפות נפוצות",
     "Password change is disabled because the master key is disabled" : "החלפת ססמה מושבתת כיוון שהמפתח הראשי מושבת",
@@ -245,7 +239,6 @@ OC.L10N.register(
     "{size} used" : "{size} בשימוש",
     "Delete account" : "מחיקת חשבון",
     "Resend welcome email" : "שליחת הודעת קבלת פנים בדוא״ל מחדש",
-    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "במקרה של אובדן מכשיר או עזיבה של הארגון, מנגנון זה יכול להשמיד את נתוני ה־Nextcloud מכל המכשירים שמשויכים אל {userid}. יעבוד רק אם כל המכשירים מחוברים לאינטרנט.",
     "Remote wipe of devices" : "השמדת נתונים מרוחקת במכשירים",
     "Wipe {userid}'s devices" : "השמדת נתוני המכשירים של {userid}",
     "Fully delete {userid}'s account including all their personal files, app data, etc." : "למחוק לחלוטין את החשבון של {userid} לרבות כל הקבצים האישיים, נתוני היישומונים וכו׳.",
@@ -264,14 +257,20 @@ OC.L10N.register(
     "Passwordless authentication requires a secure connection." : "אימות ללא ססמה דורש חיבור מוצפן.",
     "Add WebAuthn device" : "הוספת התקן WebAuthn",
     "Please authorize your WebAuthn device." : "נא לייפות את כוחו של התקן ה־WebAuthn שלך.",
-    "Adding your device …" : "הוספת ההתקן שלך…",
     "Unnamed device" : "התקן ללא שם",
     "Passwordless Authentication" : "אימות ללא ססמה",
     "Set up your account for passwordless authentication following the FIDO2 standard." : "הגדרת החשבון שלך לאימות ללא ססמה לפי תקן FIDO2.",
     "No devices configured." : "לא הוגדרו התקנים.",
     "The following devices are configured for your account:" : "ההתקנים הבאים הוגדרו לחשבון שלך:",
     "Your browser does not support WebAuthn." : "הדפדפן שלך אינו תומך ב־WebAuthn.",
+    "Security & setup warnings" : "הזהרות אבטחה והתקנה",
+    "Try again" : "ניסיון חוזר",
+    "All checks passed." : "כל הבדיקות עברו",
+    "There are some errors regarding your setup." : "ישנן מגוון שגיאות על ההגדרות שלך.",
+    "There are some warnings regarding your setup." : "ישנן מגוון אזהרות על ההגדרות שלך.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "כמנהל יש לך אפשרות לכוונן את התנהגות השיתוף. נא לעיין בתיעוד לפרטים נוספים.",
+    "Version {version}" : "גרסה {version}",
+    "Apply" : "החלה",
     "Admins" : "מנהלים",
     "Sending…" : "בשליחה…",
     "Email sent" : "הודעת הדואר האלקטרוני נשלחה",
@@ -282,6 +281,11 @@ OC.L10N.register(
     "Phone number" : "מספר טלפון",
     "Website" : "אתר",
     "Locale" : "הגדרות אזוריות",
+    "Private" : "פרטי",
+    "Local" : "מקומ",
+    "Federated" : "Federated",
+    "Only synchronize to trusted servers" : "לסנכרן מול שרתים מהימנים בלבד",
+    "Synchronize to trusted servers and the global and public address book" : "לסנכרן מול שרתים מהימנים וספר הכתובות הגלובלי והציבורי",
     "Your apps" : "היישומונים שלך",
     "Active apps" : "יישומונים פעילים",
     "Disabled apps" : "יישומונים מושבתים",
@@ -291,7 +295,6 @@ OC.L10N.register(
     "Hide" : "הסתרה",
     "Download and enable" : "להוריד ולהפעיל",
     "Disable" : "ניטרול",
-    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "היישומון הזה לא מסומן כנתמך בגרסת ה־Nextcloud. עדיין יתאפשר לך להמשיך ולהתקין את היישומון. נא לשים לב שיכול להיות שהיישומון לא יעבוד כצפוי.",
     "Unknown" : "לא ידוע",
     "Never" : "מעולם לא",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "היישומון הופעל אך יש לעדכן אותו. ההפניה לעמוד העדכון תחל בעוד 5 שניות.",
@@ -319,14 +322,6 @@ OC.L10N.register(
     "Credentials" : "פרטי גישה",
     "SMTP Password" : "סיסמת SMTP",
     "Save" : "שמור",
-    "Security & setup warnings" : "הזהרות אבטחה והתקנה",
-    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "למטרות אבטחה וביצועים מיטביים עבור המערכת שלך חשוב שהכול יוגדר כראוי. כדי לסייע לך בכך אנו עורכים בדיקות אוטומטיות. נא לעיין בתיעוד המקושר לקבלת מידע נוסף.",
-    "All checks passed." : "כל הבדיקות עברו",
-    "There are some errors regarding your setup." : "ישנן מגוון שגיאות על ההגדרות שלך.",
-    "There are some warnings regarding your setup." : "ישנן מגוון אזהרות על ההגדרות שלך.",
-    "Checking for system and security issues." : "נבדקות תקלות מערכת ואבטחה.",
-    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "נא לעיין היטב ב<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">מדריכי ההתקנה ↖️</a> ולחפש אם מופיעות שגיאות או אזהרות ב<a href=\"%2$s\">יומן</a>.",
-    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "בדיקת האבטחה של ה־Nextcloud שלך באמצעות <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">סריקת האבטחה שלנו ↖️</a>.",
     "Reasons to use Nextcloud in your organization" : "סיבות להשתמש ב־Nextcloud בארגון שלך",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "בפיתוח על ידי {communityopen}קהילת Nextcloud{linkclose}, {githubopen}קוד המקור{linkclose} זמין ברישיון {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "לייק לעמוד הפייסבוק שלנו",
@@ -335,7 +330,16 @@ OC.L10N.register(
     "Subscribe to our newsletter" : "הרשמה לרשימת הדיוור שלנו",
     "Use a second factor besides your password to increase security for your account." : "ניתן להשתמש בגורם נוסף מלבד הססמה שלך כדי להגביר את אבטחת החשבון שלך.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "אם משמשים אותך יישומי צד־שלישי להתחברות אל Nextcloud, נא לוודא יצירת והגדרת ססמה ליישומון לכל אחד מהם בטרם הפעלת אימות דו־שלבי.",
-    "Set default expiration date for shares" : "הגדרת תאריך תפוגה כבררת מחדל לשיתופים",
-    "You are using <strong>{usage}</strong>" : "הניצולת שלך היא <strong>{usage}</strong>"
+    "Group list is empty" : "רשימת הקבוצות ריקה",
+    "Unable to retrieve the group list" : "לא ניתן לקבל את רשימת הקבוצות",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "ליישומון זה לא מוקצית גרסת Nextcloud מזערית. מצב כזה עשוי להוביל לשגיאה בעתיד.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "ליישומון זה לא מוקצית גרסת Nextcloud מרבית. מצב כזה עשוי להוביל לשגיאה בעתיד.",
+    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "במקרה של אובדן מכשיר או עזיבה של הארגון, מנגנון זה יכול להשמיד את נתוני ה־Nextcloud מכל המכשירים שמשויכים אל {userid}. יעבוד רק אם כל המכשירים מחוברים לאינטרנט.",
+    "Adding your device …" : "הוספת ההתקן שלך…",
+    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "היישומון הזה לא מסומן כנתמך בגרסת ה־Nextcloud. עדיין יתאפשר לך להמשיך ולהתקין את היישומון. נא לשים לב שיכול להיות שהיישומון לא יעבוד כצפוי.",
+    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "למטרות אבטחה וביצועים מיטביים עבור המערכת שלך חשוב שהכול יוגדר כראוי. כדי לסייע לך בכך אנו עורכים בדיקות אוטומטיות. נא לעיין בתיעוד המקושר לקבלת מידע נוסף.",
+    "Checking for system and security issues." : "נבדקות תקלות מערכת ואבטחה.",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "נא לעיין היטב ב<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">מדריכי ההתקנה ↖️</a> ולחפש אם מופיעות שגיאות או אזהרות ב<a href=\"%2$s\">יומן</a>.",
+    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "בדיקת האבטחה של ה־Nextcloud שלך באמצעות <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">סריקת האבטחה שלנו ↖️</a>."
 },
 "nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
