@@ -1,25 +1,12 @@
 OC.L10N.register(
     "settings",
     {
-    "Private" : "Pribadi",
-    "Only visible to people matched via phone number integration through Talk on mobile" : "Hanya dapat dilihat oleh orang yang cocok melalui integrasi nomor telepon melalui Talk di ponsel",
-    "Local" : "Lokal",
-    "Only visible to people on this instance and guests" : "Hanya dapat dilihat oleh orang di instance ini dan tamu",
-    "Federated" : "Federated",
-    "Only synchronize to trusted servers" : "Hanya sinkronkan ke server tepercaya",
-    "Published" : "Diterbitkan",
-    "Synchronize to trusted servers and the global and public address book" : "Sinkronkran ke server tepercaya dan buku alamat global dan publik",
-    "Verify" : "Verifikasi",
-    "Verifying …" : "Sedang memferivikasi …",
     "Unable to change password" : "Tidak dapat mengubah kata sandi",
     "Very weak password" : "Kata sandi sangat lemah",
     "Weak password" : "Kata sandi lemah",
     "So-so password" : "Kata sandi lumayan",
     "Good password" : "Kata sandi baik",
     "Strong password" : "Kata sandi kuat",
-    "Groups" : "Grup",
-    "Group list is empty" : "Daftar grup kosong",
-    "Unable to retrieve the group list" : "Tidak dapat mengambil daftar grup",
     "{actor} added you to group {group}" : "{actor} menambahkanmu ke grup {group}",
     "You added {user} to group {group}" : "Anda menambahkan {user} ke grup {group}",
     "{actor} added {user} to group {group}" : "{actor} menambahkan {user} kedalam grup {group}",
@@ -35,9 +22,9 @@ OC.L10N.register(
     "You changed your password" : "Anda mengganti kata sandi",
     "Your password was reset by an administrator" : "Kata sandi Anda telah diatur ulang oleh administrator",
     "Your password was reset" : "Kata sandi Anda telah disetel ulang",
-    "{actor} changed your email address" : "{actor} mengubah alamat surel Anda",
-    "You changed your email address" : "Anda mengubah alamat surel sendiri",
-    "Your email address was changed by an administrator" : "Alamat surel Anda telah diubah oleh administrator",
+    "{actor} changed your email address" : "{actor} mengubah alamat email Anda",
+    "You changed your email address" : "Anda mengubah alamat email sendiri",
+    "Your email address was changed by an administrator" : "Alamat email Anda telah diubah oleh administrator",
     "You deleted app password \"{token}\"" : "Anda menghapus kata sandi aplikasi \"{token}\"",
     "You renamed app password \"{token}\" to \"{newToken}\"" : "Anda mengubah kata sandi aplikasi \"{token}\" ke \"{newToken}\"",
     "You granted filesystem access to app password \"{token}\"" : "Anda mengijinkan mengakses berkas sistem ke kata sandi aplikasi \"{token}\"",
@@ -47,7 +34,7 @@ OC.L10N.register(
     "A login attempt using two-factor authentication failed (%1$s)" : "Upaya masuk menggunakan autentikasi dua-faktor gagal (%1$s)",
     "Remote wipe was started on %1$s" : "Pembersihan secara remote telah dimulai di %1$s",
     "Remote wipe has finished on %1$s" : "Pembersihan secara remote telah selesai di %1$s",
-    "Your <strong>password</strong> or <strong>email</strong> was modified" : "<strong>Kata sandi</strong> atau <strong>surel</strong> Anda telah diubah",
+    "Your <strong>password</strong> or <strong>email</strong> was modified" : "<strong>Kata sandi</strong> atau <strong>email</strong> Anda telah diubah",
     "Settings" : "Setelan",
     "Could not remove app." : "Tidak dapat hapus aplikasi.",
     "Could not update app." : "Tidak dapat perbarui aplikasi.",
@@ -60,15 +47,15 @@ OC.L10N.register(
     "Administrator documentation" : "Dokumentasi administrator",
     "User documentation" : "Dokumentasi pengguna",
     "Invalid SMTP password." : "Kata sandi SMTP tidak valid.",
-    "Email setting test" : "Uji pengaturan surel",
+    "Email setting test" : "Uji pengaturan email",
     "Well done, %s!" : "Bagus, %s!",
-    "If you received this email, the email configuration seems to be correct." : "Kalau Anda menerima surel ini, konfigurasi surel sepertinya benar.",
-    "Email could not be sent. Check your mail server log" : "Surel tidak dapat dikirim. Periksa log server mail Anda",
-    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Terjadi masalah saat mengirim surel. Mohon periksa kembali pengaturan Anda. (Kesalahan: %s)",
-    "Invalid mail address" : "Alamat surel salah",
+    "If you received this email, the email configuration seems to be correct." : "Jika Anda menerima email ini, konfigurasi email sepertinya benar.",
+    "Email could not be sent. Check your mail server log" : "Email tidak dapat dikirim. Periksa log server mail Anda",
+    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Terjadi masalah saat mengirim email. Mohon periksa kembali pengaturan Anda. (Kesalahan: %s)",
+    "Invalid mail address" : "Alamat email salah",
     "Settings saved" : "Pengaturan disimpan",
     "Unable to change full name" : "Tidak dapat mengubah nama lengkap",
-    "Unable to change email address" : "Tidak dapat mengubah alamat surel",
+    "Unable to change email address" : "Tidak dapat mengubah alamat email",
     "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Untuk memverifikasi akun Twitter Anda, posting tweet berikut ini ke Twitter (pastikan untuk posting tanpa ada jeda baris):",
     "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Untuk memverifikasi Situs Anda, simpan konten berikut ini ke web-root Anda di '.well-known/CloudIdVerificationCode.txt' (pastikan dalam satu baris):",
     "%1$s changed your password on %2$s." : "%1$s mengganti kata sandi Anda di %2$s",
@@ -78,10 +65,10 @@ OC.L10N.register(
     "Password changed for %s" : "Kata sandi telah diubah untuk %s",
     "If you did not request this, please contact an administrator." : "Jika Anda tidak merasa meminta ini, mohon hubungi administrator.",
     "Your email address on %s was changed." : "Alamat emailmu di %s telah diubah.",
-    "Your email address on %s was changed by an administrator." : "Alamat surel Anda di %s telah diubah oleh administrator",
-    "Email address for %1$s changed on %2$s" : "Alamat surel untuk %1$s telah diubah di %2$s",
-    "Email address changed for %s" : "Alamat surel telah diubah untuk %s",
-    "The new email address is %s" : "Alamat surel barunya yaitu %s",
+    "Your email address on %s was changed by an administrator." : "Alamat email Anda di %s telah diubah oleh administrator",
+    "Email address for %1$s changed on %2$s" : "Alamat email untuk %1$s telah diubah di %2$s",
+    "Email address changed for %s" : "Alamat email telah diubah untuk %s",
+    "The new email address is %s" : "Alamat email barunya yaitu %s",
     "Your %s account was created" : "Akun %s Anda telah dibuat",
     "Welcome aboard" : "Selamat datang",
     "Welcome aboard %s" : "Selamat bergabung %s",
@@ -94,19 +81,22 @@ OC.L10N.register(
     "Administration" : "Administrasi",
     "Users" : "Pengguna",
     "Additional settings" : "Setelan tambahan",
+    "Assistant" : "Asisten",
     "Administration privileges" : "Hak administrator",
     "Groupware" : "Peralatan Grup",
     "Overview" : "Ringkasan",
     "Basic settings" : "Setelan dasar",
     "Sharing" : "Berbagi",
+    "Availability" : "Ketersediaan",
     "Calendar" : "Kalender",
     "Personal info" : "Info pribadi",
     "Mobile & desktop" : "Mobil & desktop",
-    "Email server" : "Server surel",
-    "Security & setup warnings" : "Peringatan Keamanan & Pengaturan",
+    "Email server" : "Server email",
     "Background jobs" : "Pekerjaan latar belakang",
     "Unlimited" : "Tak terbatas",
     "Verifying" : "Memverifikasi",
+    "Verifying …" : "Sedang memferivikasi …",
+    "Verify" : "Verifikasi",
     "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Pangkalan data kehilangan beberapa kolom opsional. Berdasarkan fakta bahwa menambahkannya pada tabel yang besar membutuhkan waktu cukup lama, maka ini tidak dilakukan otomatis. Eksekusi \"occ db: add-missing-columns\", untuk menambahkan kolom secara manual sementara instance tetap berjalan. Setelah itu dilakukan, maka beberapa fitur dapat meningkatkan daya tanggap atau kegunaan.",
     "Disabled" : "Dinonaktifkan",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "Format enkripsi sisi server lama diaktifkan. Kami menyarankan untuk menonaktifkan ini.",
@@ -118,8 +108,9 @@ OC.L10N.register(
     "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Konfigurasi baca-saja telah diaktifkan. Hal ini mencegah penyetelan beberapa konfigurasi via antarmuka web. Pada setiap proses pembaruan berikutnya, secara manual berkas tersebut perlu dibuat agar dapat ditulis.",
     "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Database Anda tidak dijalankan dengan isolasi transaksi level \"READ COMMITED\". Ini dapat menyebabkan masalah saat banyak tindakan dilakukan secara paralel.",
     "Profile information" : "Informasi profil",
-    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Gambar profil, nama lengkap, surel, nomor telepon, alamat, situs web, Twitter, organisasi, peran, judul, biografi, dan apakah profilmu diaktifkan",
+    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Gambar profil, nama lengkap, email, nomor telepon, alamat, situs web, Twitter, organisasi, peran, judul, biografi, dan apakah profilmu diaktifkan",
     "Nextcloud settings" : "Pengaturan Nextcloud",
+    "Enable" : "Aktifkan",
     "None" : "Tidak ada",
     "Allow apps to use the Share API" : "Izinkan aplikasi untuk menggunakan API Pembagian",
     "Allow resharing" : "Izinkan pembagian ulang",
@@ -134,30 +125,40 @@ OC.L10N.register(
     "Limit to groups" : "Batasi ke grup",
     "Excluded groups" : "Grup yang dikecualikan",
     "Save changes" : "Simpan perubahan",
+    "Default" : "Default",
     "Update to {update}" : "Perbarui ke {update}",
     "Remove" : "Hapus",
-    "Disable" : "Nonaktifkan",
     "Featured" : "Unggulan",
     "This app is supported via your current Nextcloud subscription." : "Aplikasi ini didukung dengan langganan Nextcloud Anda saat ini.",
     "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Aplikasi unggulan dikembangkan oleh dan dalam komunitas. Mereka menawarkan fungsionalitas sentral dan mereka siap dipakai untuk produksi.",
+    "Disable all" : "Matikan semua",
     "All apps are up-to-date." : "Semua aplikasi terkini.",
+    "Icon" : "Ikon",
     "Name" : "Nama",
     "Version" : "Versi",
     "Actions" : "Tindakan",
     "Results from other categories" : "Hasil dari kategori lainnya",
     "No apps found for your version" : "Aplikasi tidak ditemukan untuk versi ini",
-    "Disable all" : "Matikan semua",
     "_%n app has an update available_::_%n apps have an update available_" : ["Ada pembaruan tersedia untuk %naplikasi"],
     "_Update_::_Update all_" : ["Perbarui semua"],
+    "Groups" : "Grup",
+    "Group name" : "Nama grup",
     "Loading" : "Memuat",
+    "Type" : "tipe",
+    "Display Name" : "Nama Tampilan",
+    "Learn more" : "Pelajari lebih lanjut",
+    "Confirm" : "Konfirmasi",
+    "Cancel" : "Batal",
     "Description" : "Deskrisi",
-    "Details" : "Detil",
+    "View in store" : "Lihat di toko",
+    "Visit website" : "Kunjungi laman web",
+    "Admin documentation" : "Dokumentasi admin",
+    "Developer documentation" : "Dokumentasi pengembang",
+    "Details" : "Detail",
     "All" : "Semua",
     "Limit app usage to groups" : "Batas pemakaian aplikasi untuk grup",
     "No results" : "Tidak ada hasil",
     "Update to {version}" : "Perbarui ke {version}",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Aplikasi ini tidak mempunyai versi minimum Nextcloud yang ditetapkan. Di masa depan nanti ini akan menjadi kesalahan.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Aplikasi ini tidak mempunyai versi maksimum Nextcloud yang ditetapkan. Di masa depan nanti ini akan menjadi kesalahan.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Apl ini tidak dapat diinstal karena ketergantungan berikut belum terpenuhi:",
     "Author" : "Penulis",
     "Categories" : "Kategori",
@@ -167,110 +168,119 @@ OC.L10N.register(
     "Report a bug" : "Laporkan kerusakan",
     "Request feature" : "Minta fitur",
     "Ask questions or discuss" : "Tanyakan atau berdiskusi",
-    "View in store" : "Lihat di toko",
-    "Visit website" : "Kunjungi laman web",
-    "Admin documentation" : "Dokumentasi admin",
-    "Developer documentation" : "Dokumentasi pengembang",
     "Changelog" : "Log pembaruan",
+    "Google Chrome for Android" : "Google Chrome untuk Android",
+    "{productName} Android app" : "{productName} Aplikasi Android",
+    "This session" : "Sesi ini",
     "Marked for remote wipe" : "Tandai untuk penghapusan remote",
     "Device settings" : "Pengaturan perangkat",
     "Allow filesystem access" : "Ijinkan akses berkas sistem",
     "Rename" : "Ubah nama",
     "Revoke" : "Cabut ijin",
     "Wipe device" : "Hapus perangkat",
-    "Google Chrome for Android" : "Google Chrome untuk Android",
-    "This session" : "Sesi ini",
     "Device" : "Perangkat",
     "Last activity" : "Aktivitas terakhir",
     "Devices & sessions" : "Perangkat & sesi",
     "Web, desktop and mobile clients currently logged in to your account." : "Klien web, desktop dan mobile yang sedang login di akun Anda.",
+    "Error while creating device token" : "Terjadi kesalahan saat membuat token perangkat",
     "App name" : "Nama aplikasi",
     "Create new app password" : "Buat kata sandi aplikasi baru",
-    "Error while creating device token" : "Terjadi kesalahan saat membuat token perangkat",
+    "Could not copy app password. Please copy it manually." : "Tidak dapat menyalin kata sandi aplikasi. Mohon salin secara manual.",
     "Login" : "Masuk",
     "Password" : "Kata sandi",
     "Show QR code for mobile apps" : "Tampilkan kode QR untuk aplikasi mobile",
-    "Could not copy app password. Please copy it manually." : "Tidak dapat menyalin kata sandi aplikasi. Mohon salin secara manual.",
     "Last job ran {relativeTime}." : "Tugas terakhir dijalankan {relativeTime}.",
     "AJAX" : "AJAX",
     "Webcron" : "Webcron",
     "Cron (Recommended)" : "Cron (Direkomendasikan)",
-    "Profile" : "Profil",
-    "Enable" : "Aktifkan",
     "Unable to update profile default setting" : "Tidak dapat memperbarui pengaturan bawaan profil",
+    "Profile" : "Profil",
     "Server-side encryption" : "Enkripsi sisi-server",
     "Enable server-side encryption" : "Aktifkan enkripsi sisi-server",
+    "No encryption module loaded, please enable an encryption module in the app menu." : "Tidak ada modul enkripsi yang dimuat, mohon aktifkan modul enkripsi di menu aplikasi.",
+    "Select default encryption module:" : "Pilih modul enkripsi baku:",
+    "Enable encryption" : "Aktifkan enkripsi",
     "Please read carefully before activating server-side encryption:" : "Bacalah dengan seksama sebelum mengaktifkan enkripsi sisi server:",
     "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Setelah enkripsi diaktifkan, semua berkas yang diunggah pada server mulai saat ini akan dienkripsi saat singgah pada server. Penonaktifan enkripsi hanya mungkin berhasil jika modul enkripsi yang aktif mendukung fungsi ini dan semua prasyarat (misalnya pengaturan kunci pemulihan) sudah terpenuhi.",
     "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Enkripsi saja tidak dapat menjamin keamanan sistem. Silakan lihat dokumentasi untuk informasi lebih lanjut dalam bagaimana aplikasi enkripsi bekerja, dan kasus pendukung.",
     "Be aware that encryption always increases the file size." : "Ingat bahwa enkripsi selalu menambah ukuran berkas.",
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Alangkah baiknya untuk membuat cadangan data secara rutin, dalam kasus enkripsi, pastikan untuk mencadangkan kunci enkripsi bersama dengan data Anda.",
     "This is the final warning: Do you really want to enable encryption?" : "Ini adalah peringatan terakhir: Apakah Anda yakin ingin mengaktifkan enkripsi?",
-    "No encryption module loaded, please enable an encryption module in the app menu." : "Tidak ada modul enkripsi yang dimuat, mohon aktifkan modul enkripsi di menu aplikasi.",
-    "Select default encryption module:" : "Pilih modul enkripsi baku:",
-    "Cancel" : "Batal",
-    "Confirm" : "Konfirmasi",
+    "Submit" : "Kirim",
     "Rename group" : "Ganti nama grup",
-    "Remove group" : "Hapus grup",
     "Current password" : "Kata sandi saat ini",
     "New password" : "Kata sandi baru",
-    "Change password" : "Ubah kata sandi",
+    "Change password" : "Ubah sandi",
+    "Choose your profile picture" : "Pilih gambar profilmu",
+    "Error removing profile picture" : "Kesalahan terjadi ketika mencoba hapus gambar profil",
     "Your profile picture" : "Gambar profilmu",
     "Upload profile picture" : "Unggah gambar profil",
     "Remove profile picture" : "Hapus gambar profil",
     "Picture provided by original account" : "Gambar disediakan oleh akun asli",
-    "Choose your profile picture" : "Pilih gambar profilmu",
-    "Error removing profile picture" : "Kesalahan terjadi ketika mencoba hapus gambar profil",
-    "Your biography" : "Biografi Anda",
     "You are a member of the following groups:" : "Anda adalah seorang anggota dari grup berikut ini:",
     "Your full name" : "Nama lengkap Anda",
-    "Primary email for password reset and notifications" : "Surel utama untuk pengaturan ulang kata sandi dan pemberitahuan",
-    "Remove primary email" : "Hapus surel utama",
-    "Delete email" : "Hapus surel",
-    "No email address set" : "Alamat surel tidak diatur",
-    "Help translate" : "Bantu menerjemahkan",
+    "No email address set" : "Alamat email tidak diatur",
+    "Remove primary email" : "Hapus email utama",
+    "Delete email" : "Hapus email",
+    "Primary email for password reset and notifications" : "Email utama untuk pengaturan ulang kata sandi dan pemberitahuan",
     "No language set" : "Tidak ada bahasa yang disetel",
-    "Your phone number" : "Nomor telefon Anda",
+    "Help translate" : "Bantu menerjemahkan",
+    "Week starts on {firstDayOfWeek}" : "Minggu dimulai di hari {firstDayOfWeek}",
+    "Your phone number" : "Nomor telepon Anda",
     "Edit your Profile visibility" : "Ubah visibilitas Profil Anda",
-    "Add" : "Masukkan",
+    "Add" : "Tambah",
     "Create" : "Buat",
     "Change" : "Ubah",
     "Delete" : "Hapus",
     "Default language" : "Bahasa bawaan",
     "Common languages" : "Bahasa umum",
     "Password change is disabled because the master key is disabled" : "Pengaturan kata sandi dinonaktifkan karena kunci master dinonaktifkan",
-    "Display name" : "Nama tampilan",
-    "Email" : "Surel",
+    "Email" : "Email",
     "Quota" : "Kuota",
     "Language" : "Bahasa",
+    "Total rows summary" : "Ringkasan total baris",
     "Avatar" : "Avatar",
+    "Account name" : "Nama akun",
     "Group admin for" : "Grup admin untuk",
     "Storage location" : "Lokasi penyimpanan",
     "Last login" : "Log masuk terakhir",
     "{size} used" : "{size} digunakan",
-    "Resend welcome email" : "Kirim ulang surel selamat datang",
+    "Resend welcome email" : "Kirim ulang email ucapan selamat datang",
     "Welcome mail sent!" : "Surat selamat datang terkirim!",
     "Done" : "Selesai",
     "Edit" : "Sunting",
     "Show storage path" : "Tampilkan jalur penyimpanan",
     "Show last login" : "Tampilkan yang terakhir masuk",
-    "Send email" : "Kirim surel",
+    "Send email" : "Kirim email",
     "Default quota" : "Kuota standar",
     "Select default quota" : "Pilih kuota bawaan",
     "Passwordless authentication requires a secure connection." : "Otentikasi tanpa kata sandi membutuhkan koneksi aman.",
     "Passwordless Authentication" : "Otentikasi Tanpa Kata Sandi",
     "No devices configured." : "Tidak ada perangkat yang dikonfigurasi.",
+    "Security & setup warnings" : "Peringatan Keamanan & Pengaturan",
+    "Try again" : "Coba lagi",
+    "All checks passed." : "Semua pemeriksaan lulus.",
+    "There are some errors regarding your setup." : "Terdapat beberapa galat terkait dengan setup Anda.",
+    "There are some warnings regarding your setup." : "Terdapat beberapa peringatan terkait dengan setup Anda.",
+    "Apply" : "Terapkan",
     "Admins" : "Admin",
-    "Group name" : "Nama grup",
     "Sending…" : "Mengirim…",
-    "Email sent" : "Surel terkirim",
+    "Email sent" : "Email terkirim",
     "Location" : "Lokasi",
     "Profile picture" : "Foto profil",
     "About" : "Tentang.",
     "Full name" : "Nama lengkap",
-    "Phone number" : "Nomor telefon",
+    "Phone number" : "Nomor telepon",
     "Website" : "Situs",
     "Profile visibility" : "Visibilitas profil",
+    "Private" : "Pribadi",
+    "Only visible to people matched via phone number integration through Talk on mobile" : "Hanya dapat dilihat oleh orang yang cocok melalui integrasi nomor telepon melalui Talk di ponsel",
+    "Local" : "Lokal",
+    "Only visible to people on this instance and guests" : "Hanya dapat dilihat oleh orang di instance ini dan tamu",
+    "Federated" : "Federated",
+    "Only synchronize to trusted servers" : "Hanya sinkronkan ke server tepercaya",
+    "Published" : "Diterbitkan",
+    "Synchronize to trusted servers and the global and public address book" : "Sinkronkran ke server tepercaya dan buku alamat global dan publik",
     "Your apps" : "Aplikasi Anda",
     "Active apps" : "Aplikasi aktif",
     "Disabled apps" : "Matikan Aplikasi",
@@ -279,7 +289,8 @@ OC.L10N.register(
     "Featured apps" : "Aplikasi yang difiturkan",
     "Hide" : "Sembunyikan",
     "Download and enable" : "Unduh dan hidupkan",
-    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Aplikasi ini tidak ditandai sebagai versi Nextcloud Anda yang kompatibel. Jika Anda tetap ingin melanjutkannya, Anda tetap dapat memasang aplikasi. Catatan bahwa aplikasinya mungkin tidak akan berjalan seperti yang diharapkan.",
+    "Disable" : "Nonaktifkan",
+    "Unknown" : "Tidak diketahui",
     "Never" : "Tidak pernah",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aplikasi diaktifkan namun butuh diperbarui. Anda akan dialihkan ke halaman pembaruan dalam 5 detik.",
     "Do you really want to wipe your data from this device?" : "Yakin ingin menghapus data Anda dari perangkat ini?",
@@ -297,7 +308,7 @@ OC.L10N.register(
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Sangat penting untuk mengatur server ini untuk dapat mengirim surat, seperti melakukan reset kata sandi dan notifikasi.",
     "Send mode" : "Modus kirim",
     "Encryption" : "Enkripsi",
-    "Sendmail mode" : "Mode kirim surel",
+    "Sendmail mode" : "Mode kirim email",
     "From address" : "Dari alamat",
     "Server address" : "Alamat server",
     "Port" : "Port",
@@ -306,43 +317,20 @@ OC.L10N.register(
     "Credentials" : "Kredensial",
     "SMTP Password" : "Kata sandi SMTP",
     "Save" : "Simpan",
-    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Sangat penting sekali untuk semuanya diatur secara benar demi keamanan dan performa instansi Anda. Untuk membantu Anda dengan hal itu kami melakukan cek otomatis. Mohon melihat tautan dokumentasi untuk lebih lanjut.",
-    "All checks passed." : "Semua pemeriksaan lulus.",
-    "There are some errors regarding your setup." : "Terdapat beberapa galat terkait dengan setup Anda.",
-    "There are some warnings regarding your setup." : "Terdapat beberapa peringatan terkait dengan setup Anda.",
-    "Checking for system and security issues." : "Mengecek isu sistem dan keamanan",
-    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Mohon cek kembali Petunjuk pemasangan ↗, dan cek semua galat atau peringatan di <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">log<a href=\"%2$s\">.",
-    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Cek keamanan Nextcloud Anda dengan <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">pemindaian keamanan kami ↗</a>.",
-    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Dikembangkan oleh {commmunityopen}komunitas Nextcloud{linkclose}, {githubopen}sumber kode{linkclose} dilisensikan dibawah {licenseopen}AGPL{linkclose}.",
+    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Dikembangkan oleh {communityopen}komunitas Nextcloud{linkclose}, {githubopen}sumber kode{linkclose} dilisensikan dibawah {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Sukai kami di halaman Facebook",
-    "Follow us on Twitter" : "Ikuti kami di Twitter",
     "Follow us on Mastodon" : "Ikuti kami di Mastodon",
     "Check out our blog" : "Cek blog kami",
     "Subscribe to our newsletter" : "Berlangganan surat berita kami",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Rilis komunitas Nextcloud ini tidak didukung dan pemberitahuan instan tidak tersedia.",
-    "No user supplied" : "Tidak ada pengguna yang diberikan",
-    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Berikan kata sandi pemulihan admin; Jika tidak, semua data pengguna akan hilang.",
-    "You need to set your user email before being able to send test emails. Go to %s for that." : "Anda harus pilih alamat surel pengguna sebelum bisa mengirim surel percobaan. Pergilah ke %s untuk itu.",
-    "Invalid user" : "Pengguna tidak sah",
-    "Your username is: %s" : "Nama pengguna Anda: %s",
-    "Logged in user must be a subadmin" : "Masuk ke dalam pengguna harus sebagai seorang subadmin",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Pangkalan data kehilangan beberapa indeks. Berdasarkan fakta bahwa menambahkan indeks pada tabel yang besar membutuhkan waktu cukup lama, maka ini tidak dilakukan otomatis. Eksekusi \"occ db: add-missing-indexes\", untuk menambahkan indeks secara manual sementara instance tetap berjalan. Setelah itu dilakukan, maka kueri akan jauh lebih cepat.",
-    "Exclude groups from sharing" : "Tidak termasuk grup untuk berbagi",
-    "These groups will still be able to receive shares, but not to initiate them." : "Grup ini akan tetap dapat menerima berbagi, tatapi tidak dapat membagikan.",
-    "{license}-licensed" : "{license}-dilisensikan",
-    "Username" : "Nama pengguna",
-    "Enable or disable profile by default for new users." : "Aktifkan atau nonaktifkan profil secara default untuk pengguna baru.",
-    "New user" : "Pengguna baru",
-    "User backend" : "Backend pengguna",
-    "You do not have permissions to see the details of this user" : "Anda tidak memiliki ijin untuk melihat detil pengguna ini",
-    "Set user as admin for" : "Atur pengguna sebagai admin untuk",
-    "Select user quota" : "Pilih kuota pengguna",
-    "Delete user" : "Hapus pengguna",
-    "Disable user" : "Nonaktifkan pengguna",
-    "Enable user" : "Aktifkan pengguna",
-    "Show user backend" : "Tampilkan pengguna backend",
-    "Active users" : "Pengguna aktif",
-    "Disabled users" : "Nonaktifkan pengguna",
-    "SMTP Username" : "Nama pengguna SMTP"
+    "Group list is empty" : "Daftar grup kosong",
+    "Unable to retrieve the group list" : "Tidak dapat mengambil daftar grup",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Aplikasi ini tidak mempunyai versi minimum Nextcloud yang ditetapkan. Di masa depan nanti ini akan menjadi kesalahan.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Aplikasi ini tidak mempunyai versi maksimum Nextcloud yang ditetapkan. Di masa depan nanti ini akan menjadi kesalahan.",
+    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Aplikasi ini tidak ditandai sebagai versi Nextcloud Anda yang kompatibel. Jika Anda tetap ingin melanjutkannya, Anda tetap dapat memasang aplikasi. Catatan bahwa aplikasinya mungkin tidak akan berjalan seperti yang diharapkan.",
+    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Sangat penting sekali untuk semuanya diatur secara benar demi keamanan dan performa instansi Anda. Untuk membantu Anda dengan hal itu kami melakukan cek otomatis. Mohon melihat tautan dokumentasi untuk lebih lanjut.",
+    "Checking for system and security issues." : "Mengecek isu sistem dan keamanan",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Mohon cek kembali Petunjuk pemasangan ↗, dan cek semua galat atau peringatan di <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">log<a href=\"%2$s\">.",
+    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Cek keamanan Nextcloud Anda dengan <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">pemindaian keamanan kami ↗</a>."
 },
 "nplurals=1; plural=0;");
