@@ -1,25 +1,12 @@
 OC.L10N.register(
     "settings",
     {
-    "Private" : "Einka",
-    "Only visible to people matched via phone number integration through Talk on mobile" : "Einungis sýnilegt fólki sem samsvarar samþættum símanúmerum í gegnum Talk-forritið á farsímum",
-    "Local" : "Staðvært",
-    "Only visible to people on this instance and guests" : "Einungis sýnilegt staðværum notendum og gestum",
-    "Federated" : "Deilt milli þjóna (skýjasambandssameign)",
-    "Only synchronize to trusted servers" : "Aðeins samstilla við treysta þjóna",
-    "Published" : "Útgefið",
-    "Synchronize to trusted servers and the global and public address book" : "Samstilla við treysta þjóna og víðværar og opinberar vistfangaskrár",
-    "Verify" : "Sannreyna",
-    "Verifying …" : "Sannreyni …",
     "Unable to change password" : "Ekki tókst að breyta lykilorði",
     "Very weak password" : "Mjög veikt lykilorð",
     "Weak password" : "Veikt lykilorð",
     "So-so password" : "Svo-svo lykilorð",
     "Good password" : "Gott lykilorð",
     "Strong password" : "Sterkt lykilorð",
-    "Groups" : "Hópar",
-    "Group list is empty" : "Listi yfir hópa er tómur",
-    "Unable to retrieve the group list" : "Tókst ekki að ná í lista yfir hópinn",
     "{actor} added you to group {group}" : "{actor} bætti þér við hópinn {group}",
     "You added {user} to group {group}" : "Þú bættir {user} við hópinn {group}",
     "{actor} added {user} to group {group}" : "{actor} bætti {user} við hópinn {group}",
@@ -109,7 +96,7 @@ OC.L10N.register(
     "Administration" : "Stjórnun",
     "Users" : "Notendur",
     "Additional settings" : "Valfrjálsar stillingar",
-    "Artificial Intelligence" : "Gervigreind",
+    "Assistant" : "Meðhjálpari",
     "Administration privileges" : "Kerfisstjórnunarheimildir",
     "Groupware" : "Hópvinnukerfi",
     "Overview" : "Yfirlit",
@@ -119,6 +106,7 @@ OC.L10N.register(
     "Calendar" : "Dagatal",
     "Personal info" : "Persónulegar upplýsingar",
     "Mobile & desktop" : "Farsímar og borðtölvur",
+    "Artificial Intelligence" : "Gervigreind",
     "Email server" : "Póstþjónn",
     "Mail Providers" : "Þjónustuveitur",
     "Send emails using" : "Senda tölvupósta með",
@@ -128,6 +116,8 @@ OC.L10N.register(
     "Background jobs" : "Verk í bakgrunni",
     "Unlimited" : "ótakmörkuðu",
     "Verifying" : "Sannreyni",
+    "Verifying …" : "Sannreyni …",
+    "Verify" : "Sannreyna",
     "Allowed admin IP ranges" : "Leyfð svið IP-vistfanga stjórnenda",
     "Admin IP filtering is correctly configured." : "Síun IP-vistfanga stjórnenda er rétt stillt.",
     "App directories owner" : "Eigandi forritamappa",
@@ -205,7 +195,6 @@ OC.L10N.register(
     "Profile information" : "Persónuupplýsingar",
     "Nextcloud settings" : "Stillingar Nextcloud",
     "AI tasks can be implemented by different apps. Here you can set which app should be used for which task." : "AI-gervigreind verka getur verið framkvæmd af mismunandi forritum. Hér geturðu stillt hvaða forrit ætti að nota fyrir hvaða verk.",
-    "Task:" : "Verk:",
     "Enable" : "Virkja",
     "Machine translation" : "Vélræn þýðing",
     "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Vélþýðingar geta verið framkvæmdar af mismunandi forritum. Hér geturðu skilgreint forgangsröðun þeirra vélþýðingarforrita sem eru uppsett í augnablikinu.",
@@ -213,6 +202,7 @@ OC.L10N.register(
     "Image generation can be implemented by different apps. Here you can set which app should be used." : "Gerð mynda getur verið framkvæmd af mismunandi forritum. Hér geturðu stillt hvaða forrit ætti að nota.",
     "Text processing" : "Textavinnsla",
     "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Textavinnsla verka getur verið framkvæmd af mismunandi forritum. Hér geturðu stillt hvaða forrit ætti að nota fyrir hvaða verk.",
+    "Task:" : "Verk:",
     "Unable to modify setting" : "Ekki gekk að breyta stillingu",
     "None" : "Ekkert",
     "Changed disclaimer text" : "Breyttur texti fyrirvara",
@@ -247,7 +237,6 @@ OC.L10N.register(
     "Privacy settings for sharing" : "Stillingar á friðhelgi deilingar",
     "Allow account name autocompletion in share dialog and allow access to the system address book" : "Leyfa sjálfklárun notandanafns í deilingarglugga og heimila aðgang að nafnaskrá kerfisins",
     "Restrict account name autocompletion and system address book access to users within the same groups" : "Takmarka sjálfklárun á heiti notendaaðganga og aðgang að kerfisnafnaskrá við notendur innan sömu hópa",
-    "Restrict account name autocompletion to users based on phone number integration" : "Leyfa sjálfklárun á heiti notendaaðganga á notendum byggt á samþættingu símanúmera",
     "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Birta fyrirvara á opinberu innsendingasíðunni (birtist einungis þegar listi yfir skrár er falinn)",
     "Disclaimer text" : "Texti fyrirvara",
     "This text will be shown on the public link upload page when the file list is hidden." : "Þessi texti birtist á opinberu upphleðslusíðunni þegar listi yfir skrár er falinn.",
@@ -263,6 +252,7 @@ OC.L10N.register(
     "Excluded groups" : "Útilokaðir hópar",
     "When groups are selected/excluded, they use the following logic to determine if an account has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If an account is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Þegar hópar eru valdir/útilokaðir, styðjast þeir við eftirfarandi röksemdafærslu til að ákvarða hvort notandaaðgangur sé með þvingaða/virka tveggja-þrepa auðkenningu: tveggja-þrepa auðkenning er virk fyrir alla nema meðlimi útilokaðra hópa. Ef hópar eru valdir, er tveggja-þrepa auðkenning virk fyrir alla meðlimi þessara hópa. Ef notandi er bæði í völdum og í útilokuðum hópum, ræður valið og því er tveggja-þrepa auðkenning virk.",
     "Save changes" : "Vista breytingar",
+    "Default" : "Sjálfgefið",
     "Show details for {appName} app" : "Birta ítarlegri upplýsingar fyrir {appName} forritið",
     "Update to {update}" : "Uppfæra í {update}",
     "Remove" : "Fjarlægja",
@@ -283,6 +273,7 @@ OC.L10N.register(
     "_%n app has an update available_::_%n apps have an update available_" : ["%n forrit er með tiltæka uppfærslu","%n forrit eru með tiltæka uppfærslu"],
     "_Update_::_Update all_" : ["Uppfæra","Uppfæra allt"],
     "Failed to create group" : "Mistókst að búa til hóp",
+    "Groups" : "Hópar",
     "Creating group…" : "Bý til hóp …",
     "Create group" : "Búa til hóp",
     "Group name" : "Heiti hóps",
@@ -332,8 +323,6 @@ OC.L10N.register(
     "No results" : "Engar niðurstöður",
     "Update to {version}" : "Uppfæra í {version}",
     "Delete data on remove" : "Eyða gögnum við fjarlægingu",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Þetta vorrit er ekki með tiltekna neina lágmarksútgáfu Nextcloud. Þetta mun gefa villu í framtíðinni.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Þetta vorrit er ekki með tiltekna neina hámarksútgáfu Nextcloud. Þetta mun gefa villu í framtíðinni.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Ekki var hægt að setja upp forritið þar sem eftirfarandi kerfiskröfur eru ekki uppfylltar:",
     "Latest updated" : "Síðast uppfært",
     "Author" : "Höfundur",
@@ -399,6 +388,7 @@ OC.L10N.register(
     "Unable to update profile default setting" : "Tókst ekki að uppfæra sjálfgefna stillingu notandasniðs",
     "Profile" : "Notandasnið",
     "Enable or disable profile by default for new accounts." : "Virkja eða gera notandasnið óvirkt sjálfgefið fyrir nýja notendaaðganga.",
+    "Password confirmation is required" : "Þörf á staðfestingu lykilorðs",
     "Failed to save setting" : "Mistókst að vista stillingu",
     "Unable to update server side encryption config" : " Get ekki uppfært uppsetningu fyrir dulritun á þjóni",
     "Server-side encryption" : "Dulritun á þjóni",
@@ -414,15 +404,11 @@ OC.L10N.register(
     "Be aware that encryption always increases the file size." : "Hafðu í huga að dulritun eykur alltaf skráastærð.",
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Það er góður siður að taka regluleg öryggisafrit af gögnunum þínum; ef um dulrituð gögn er að ræða, gakktu úr skugga um að einnig sé tekið öryggisafrit af dulritunarlyklum ásamt gögnunum.",
     "This is the final warning: Do you really want to enable encryption?" : "Þetta er lokaaðvörun: Viltu örugglega virkja dulritun?",
-    "Failed to remove group \"{group}\"" : "Mistókst að fjarlægja hópinn \"{group}\"",
     "Please confirm the group removal" : "Staðfestu fjarlægingu hópsins",
-    "You are about to remove the group \"{group}\". The accounts will NOT be deleted." : "Þú er í þann mund að fara að fjarlægja hópinn \"{group}\". Notendaaðgöngunum verður EKKI eytt.",
     "Submit" : "Senda inn",
     "Rename group" : "Endurnefna hóp",
-    "Remove group" : "Fjarlægja hóp",
     "Current password" : "Núverandi lykilorð",
     "New password" : "Nýtt lykilorð",
-    "Change password" : "Breyta lykilorði",
     "Choose your profile picture" : "Veldu auðkennismynd fyrir þig",
     "Please select a valid png or jpg file" : "Veldu gilda PNG eða JPG-skrá",
     "Error setting profile picture" : "Villa kom upp við að setja auðkennismyndina",
@@ -444,6 +430,9 @@ OC.L10N.register(
     "You are using {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})" : "Þú ert að nota {s}{usage}{/s} af {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})",
     "You are a member of the following groups:" : "Þú ert meðlimur eftirfarandi hópa:",
     "Your full name" : "Fullt nafn þitt",
+    "Unable to update primary email address" : "Get ekki uppfært aðaltölvupóstfang",
+    "Unable to delete additional email address" : "Get ekki eytt aukatölvupóstfangi",
+    "No email address set" : "Ekkert tölvupóstfang sett",
     "Email options" : "Tölvupóststillingar",
     "Options for additional email address {index}" : "Valkostir fyrir aukalegt tölvupóstfang {index}",
     "Remove primary email" : "Fjarlægja aðaltölvupóstfang",
@@ -453,25 +442,22 @@ OC.L10N.register(
     "Set as primary email" : "Gera að aðaltölvupóstfangi",
     "Additional email address {index}" : "Aukalegt tölvupóstfang {index}",
     "Unable to delete primary email address" : "Get ekki eytt aðaltölvupóstfangi",
-    "Unable to update primary email address" : "Get ekki uppfært aðaltölvupóstfang",
     "Unable to add additional email address" : "Get ekki bætt við aukatölvupóstfangi",
     "Unable to update additional email address" : "Get ekki uppfært aukatölvupóstfang",
-    "Unable to delete additional email address" : "Get ekki eytt aukatölvupóstfangi",
     "Primary email for password reset and notifications" : "Aðallykilorð fyrir tilkynningar og endurstillingu lykilorðs",
-    "No email address set" : "Ekkert tölvupóstfang sett",
     "Your handle" : "Auðkennið þitt",
     "Derived from your locale ({weekDayName})" : "Ákvarðað af staðfærslu kerfisins ({weekDayName})",
     "Unable to update first day of week" : "Mistókst að uppfæra fyrsta dag viku",
     "Day to use as the first day of week" : "Dagurinn sem á að nota sem fyrsta dag vikunnar",
     "Your headline" : "Fyrirsögnin þín",
+    "No language set" : "Ekkert tungumál skilgreint",
     "Unable to update language" : "Tókst ekki að uppfæra tungumál",
     "Languages" : "Tungumál",
     "Help translate" : "Hjálpa við þýðingu",
-    "No language set" : "Ekkert tungumál skilgreint",
+    "No locale set" : "Engin staðfærsla tilgreind",
     "Unable to update locale" : "Tókst ekki að uppfæra staðfærslu",
     "Locales" : "Staðfærslur",
     "Week starts on {firstDayOfWeek}" : "Vika byrjar á {firstDayOfWeek}",
-    "No locale set" : "Engin staðfærsla tilgreind",
     "Your city" : "Borg/sveitarfélag",
     "Your organisation" : "Fyrirtækið þitt",
     "Your phone number" : "Símanúmerið þitt",
@@ -484,6 +470,7 @@ OC.L10N.register(
     "he/him" : "hann",
     "they/them" : "hán/þau",
     "Your role" : "Hlutverk þitt",
+    "Timezone" : "Tímabelti",
     "Your X (formerly Twitter) handle" : "X (fyrrum Twitter) notandanafnið þitt",
     "Your website" : "Vefsvæðið þitt",
     "Invalid value" : "Ógilt gildi",
@@ -498,12 +485,12 @@ OC.L10N.register(
     "Change" : "Breyta",
     "Delete" : "Eyða",
     "Reshare" : "Endurdeila",
+    "School" : "Skóli",
     "Default language" : "Sjálfgefið tungumál",
     "Common languages" : "Algeng tungumál",
     "Other languages" : "Önnur tungumál",
     "Password change is disabled because the master key is disabled" : "Lykilorðabreyting er óvirk vegna þess að aðallykill er óvirkur",
     "No accounts" : "Engir aðgangar",
-    "Loading accounts …" : "Hleð inn notendaaðgöngum...",
     "List of accounts. This list is not fully rendered for performance reasons. The accounts will be rendered as you navigate through the list." : "Listi yfir notendaaðganga. Til að halda sem bestum afköstum er þessi listi ekki myndgerður að fullu. Notendaaðgangar munu birtast eftir því sem farið er í gegnum listann.",
     "Manager" : "Stjórnandi",
     "Set line manager" : "Settu línustjórnanda",
@@ -519,7 +506,6 @@ OC.L10N.register(
     "Member of the following groups" : "Meðlimur eftirfarandi hópa",
     "Set account groups" : "Setja hópa notandaaðgangs",
     "Admin of the following groups" : "Stjórnandi eftirfarandi hópa",
-    "Set account as admin for …" : "Setja notandaaðganginn sem stjórnanda fyrir …",
     "Quota" : "Kvóti",
     "Set account quota" : "Settu kvóta notandaaðgangs",
     "Language" : "Tungumál",
@@ -541,7 +527,6 @@ OC.L10N.register(
     "Disable account" : "Gera notandaaðgang óvirkan",
     "Enable account" : "Virkja notandaaðgang",
     "Resend welcome email" : "Endursenda kveðjupóst",
-    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Týnist tæki eða hætti einhver hjá fyrirtæki/stofnun, þá getur þetta hreinsað fjartengt út öll Nextcloud-gögn af öllum tækjum sem tengd eru {userid}. Virkar bara ef tækin eru tengd internetinu.",
     "Remote wipe of devices" : "Fjartengd útþurrkun af tækjum",
     "Wipe {userid}'s devices" : "Þurrka út af tækjum {userid}",
     "Wiped {userid}'s devices" : "Þurrkaði út af tækjum {userid}",
@@ -552,7 +537,6 @@ OC.L10N.register(
     "Password was successfully changed" : "Það tókst að breyta lykilorðinu",
     "Email was successfully changed" : "Það tókst að breyta tölvupóstfanginu",
     "Welcome mail sent!" : "Kveðjupóstur sendur!",
-    "Loading account …" : "Hleð inn notandaaðgangi …",
     "Change display name" : "Breyta birtingarnafni",
     "Set new password" : "Stilla nýtt lykilorð",
     "You do not have permissions to see the details of this account" : "Þú hefur ekki réttindi til að skoða ítarupplýsingar um þennan notandaaðgang",
@@ -584,13 +568,17 @@ OC.L10N.register(
     "Passwordless authentication requires a secure connection." : "Lykilorðalaus auðkenning krefst öruggrar tengingar.",
     "Add WebAuthn device" : "Bæta við WebAuthn-tæki",
     "Please authorize your WebAuthn device." : "Auðkenndu WebAuthn-tækið þitt.",
-    "Adding your device …" : "Bæti við tækinu þínu …",
     "Unnamed device" : "Nafnlaust tæki",
     "Passwordless Authentication" : "Lykilorðalaus auðkenning",
     "Set up your account for passwordless authentication following the FIDO2 standard." : "Settu aðganginn þinn upp fyrir lykilorðalausa auðkenningu byggða á FIDO2-staðlinum.",
     "No devices configured." : "Engin tæki skilgreind.",
     "The following devices are configured for your account:" : "Eftirfarandi tæki eru uppsett fyrir notandaaðganginn þinn:",
     "Your browser does not support WebAuthn." : "Vafrinn þinn styður ekki WebAuthn.",
+    "Security & setup warnings" : "Öryggi og aðvaranir vegna uppsetningar",
+    "Try again" : "Reyndu aftur",
+    "All checks passed." : "Stóðst allar prófanir.",
+    "There are some errors regarding your setup." : "Það komu upp villur varðandi uppsetninguna þína.",
+    "There are some warnings regarding your setup." : "Það komu upp viðvaranir varðandi uppsetninguna þína.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Sem stjórnandi geturðu fínstillt hegðun við deilingu. Endilega kíktu á hjálparskjölin til að sjá ítarlegri upplýsingar.",
     "You need to enable the File sharing App." : "Þú verður að virkja skráardeilingarforritið.",
     "App Store" : "Forritasafn",
@@ -599,6 +587,7 @@ OC.L10N.register(
     "Developer documentation ↗" : "Hjálparskjöl þróunaraðila↗",
     "Version {version}, {license}-licensed" : "Útgáfa {version}, {license}-notkunarleyfi",
     "Version {version}" : "Útgáfa {version}",
+    "Apply" : "Virkja",
     "All accounts" : "Allir aðgangar",
     "Admins" : "Kerfisstjórar",
     "Account group: {group}" : "Hópur notendaaðganga: {group}",
@@ -618,12 +607,21 @@ OC.L10N.register(
     "Pronouns" : "Fornöfn",
     "Role" : "Role",
     "X (formerly Twitter)" : "X (fyrrum Twitter)",
+    "Bluesky" : "Bluesky",
     "Website" : "Vefsvæði",
     "Profile visibility" : "Sýnileiki notandasniðs",
     "Locale" : "Staðfærsla",
     "First day of week" : "Fyrsti dagur viku",
+    "Private" : "Einka",
+    "Only visible to people matched via phone number integration through Talk on mobile" : "Einungis sýnilegt fólki sem samsvarar samþættum símanúmerum í gegnum Talk-forritið á farsímum",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Er ekki tiltækt þar sem þessi eiginleiki er nauðsynlegur fyrir kjarnavirkni á borð við skráadeilingu og boð í dagatölum",
+    "Local" : "Staðvært",
+    "Only visible to people on this instance and guests" : "Einungis sýnilegt staðværum notendum og gestum",
+    "Federated" : "Deilt milli þjóna (skýjasambandssameign)",
+    "Only synchronize to trusted servers" : "Aðeins samstilla við treysta þjóna",
     "Not available as federation has been disabled for your account, contact your system administration if you have any questions" : "Er ekki tiltækt þar sem skýjasamband (federation) hefur verið gert óvirkt fyrir aðganginn þinn, hafðu samband við kerfisstjórann þinn ef þú ert með einhverjar spurningar",
+    "Published" : "Útgefið",
+    "Synchronize to trusted servers and the global and public address book" : "Samstilla við treysta þjóna og víðværar og opinberar vistfangaskrár",
     "Not available as publishing account specific data to the lookup server is not allowed, contact your system administration if you have any questions" : "Er ekki tiltækt þar sem ekki er leyfilegt að miðla sértækum gögnum notenda yfir á uppflettingaþjóninn, hafðu samband við kerfisstjórann þinn ef þú ert með einhverjar spurningar",
     "Your apps" : "Forritin þín",
     "Active apps" : "Virk forrit",
@@ -635,14 +633,11 @@ OC.L10N.register(
     "Show to everyone" : "Birta öllum",
     "Show to logged in accounts only" : "Birta einungis hjá innskráðum notendaaðgöngum",
     "Hide" : "Fela",
-    "{progress}% Deploying …" : "{progress}% Sett í gang …",
-    "{progress}% Initializing …" : "{progress}% Frumstilling …",
     "Health checking" : "Ástandsskoðun",
     "Download and enable" : "Sækja og virkja",
     "Disable" : "Gera óvirkt",
     "Allow untested app" : "Leyfa óprófuð forrit",
     "The app will be downloaded from the App Store" : "Forritið verður sótt úr forritabúðinni",
-    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Þetta forrit er merkt sem ekki samhæft við þína útgáfu af Nextcloud. Ef þú heldur áfram er mögulegt að þú getir samt sett forritið upp. En athugaðu þá að ekki er víst að forritið virki eins og skyldi.",
     "Unknown" : "Óþekkt",
     "Never" : "Aldrei",
     "An error occurred during the request. Unable to proceed." : "Villa kom upp við beiðnina. Get ekki haldið áfram.",
@@ -678,14 +673,6 @@ OC.L10N.register(
     "SMTP Password" : "SMTP-lykilorð",
     "Save" : "Vista",
     "Test and verify email settings" : "Prófa og staðfesta tölvupóststillingar",
-    "Security & setup warnings" : "Öryggi og aðvaranir vegna uppsetningar",
-    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Það er mikilvægt fyrir öryggi og afköst uppsetningarinnar þinnar að allt sé rétt stillt. Til að hjálpa við að svo sé, eru gerðar ýmsar sjálfvirkar prófanir. Skoðaðu hjálparskjölin til að sjá ítarlegar upplýsingar.",
-    "All checks passed." : "Stóðst allar prófanir.",
-    "There are some errors regarding your setup." : "Það komu upp villur varðandi uppsetninguna þína.",
-    "There are some warnings regarding your setup." : "Það komu upp viðvaranir varðandi uppsetninguna þína.",
-    "Checking for system and security issues." : "Athuga með kerfis- og öryggisvandamál.",
-    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Yfirfarðu vandlega <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">uppsetningarleiðbeiningarnar ↗</a>, og athugaðu hvort nokkrar villumeldingar eða aðvaranir séu í <a href=\"%2$s\">annálnum</a>.",
-    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Athugaðu öryggi Nextcloud-skýsins með <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">öryggisskönnun okkar ↗</a>.",
     "Reasons to use Nextcloud in your organization" : "Ástæður til að nota Nextcloud á vinnustaðnum þínum",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Þróað af {communityopen}Nextcloud samfélaginu{linkclose}, {githubopen}grunnkóðinn{linkclose} er gefinn út með {licenseopen}AGPL{linkclose} notkunarleyfinu.",
     "Like our Facebook page" : "Líkaðu við Facebook-síðuna okkar",
@@ -696,39 +683,22 @@ OC.L10N.register(
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Þessi samfélagsútgáfa Nextcloud kemur ekki með neinni opinberri aðstoð og rauntímatilkynningar eru ekki til taks.",
     "Use a second factor besides your password to increase security for your account." : "Notaðu annað þrep til viðbótar lykilorðinu þínu til að auka öryggi notandaaðgangsins þíns.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Ef þú notaðir utanaðkomandi forrit til að tengjast við Nextcloud, skaltu ganga úr skugga um að þú útbúir lykilorð fyrir hvert slíkt forrit áður en þú virkjar 2FA tveggja-þrepa auðkenningu.",
+    "Group list is empty" : "Listi yfir hópa er tómur",
+    "Unable to retrieve the group list" : "Tókst ekki að ná í lista yfir hópinn",
     "Logged in account must be a subadmin" : "Innskráður aðgangur verður að vera undirstjórnandi (subadmin)",
-    "Missing optional index \"%s\" in table \"%s\"." : "Vantar valkvæða vísinn \"s\" í töflunni \"%s\".",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Gagnagrunninn vantar nokkra atriðavísa (indexes). Vegna þess að það að bæta atriðavísum við stórar töflur getur tekið töluverðan tíma, þá var þeim ekki bætt við sjálfvirkt. Með því að keyra \"occ db:add-missing-indices\" væri hægt að bæta inn þessum atriðavísum sem vantar, á meðan kerfið er í gangi. Um leið og búið er að bæta inn þessum atriðavísum, munu fyrirspurnir í þessar töflur verða miklu hraðvirkari.",
-    "File locking" : "Skráalæsing",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "Færslulæsing skráa (transactional file locking) er óvirk, þetta gæti leitt til vandamála út frá forgangsskilyrðum (race conditions). Virkjaðu 'filelocking.enabled' í config.php til að forðast slík vandamál.",
-    "The PHP memory limit is below the recommended value of %s." : "Minnismörk PHP eru lægri en gildið sem mælt er með; %s.",
-    "Speech-To-Text" : "Tal-í-texta",
-    "Speech-To-Text can be implemented by different apps. Here you can set which app should be used." : "Tal-í-texta getur verið framkvæmt af mismunandi forritum. Hér geturðu stillt hvaða forrit ætti að nota.",
-    "Set default expiration date for shares" : "Setja sjálfgefinn gildistíma fyrir sameignir",
-    "Allow username autocompletion in share dialog and allow access to the system address book" : "Leyfa sjálfklárun notandanafns í deilingarglugga og heimila aðgang að nafnaskrá kerfisins",
-    "Your biography" : "Æviágrip þitt",
-    "You are using <strong>{usage}</strong>" : "Þú ert að nota <strong>{usage}</strong>",
-    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Þú ert að nota <strong>{usage}</strong> af <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
-    "Set user manager" : "Settu stjórnanda notenda",
-    "Username will be autogenerated" : "Notandanafn verður útbúið sjálfvirkt",
-    "Username (required)" : "Notandanafn (nauðsynlegt)",
-    "New user" : "Nýr notandi",
-    "Groups (required)" : "Hópar (nauðsynlegt)",
-    "Set user groups" : "Setja notendahópa",
-    "Administered groups" : "Stýrðir hópar",
-    "Set user as admin for …" : "Setja notanda sem stjórnanda fyrir …",
-    "Set user quota" : "Settu kvóta notandans",
-    "Add new user" : "Bæta við nýjum notanda",
-    "_{userCount} user …_::_{userCount} users …_" : ["{userCount} notandi …","{userCount} notendur …"],
-    "_{userCount} user_::_{userCount} users_" : ["{userCount} notandi","{userCount} notendur"],
-    "Loading users …" : "Hleð inn notendum …",
-    "Username" : "Notandanafn",
-    "User backend" : "Bakendi notanda",
-    "User actions" : "Aðgerðir notanda",
-    "Add user to group" : "Bæta notanda í hóp",
-    "Server error while trying to add WebAuthn device" : "Villa á þjóni við að bæta við WebAuthn-tæki",
-    "Name your device" : "Gefðu tækinu þínu nafn",
-    "Active accounts" : "Virkir aðgangar",
-    "Follow us on Twitter" : "Fylgstu með okkur á Twitter"
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Þetta vorrit er ekki með tiltekna neina lágmarksútgáfu Nextcloud. Þetta mun gefa villu í framtíðinni.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Þetta vorrit er ekki með tiltekna neina hámarksútgáfu Nextcloud. Þetta mun gefa villu í framtíðinni.",
+    "Loading accounts …" : "Hleð inn notendaaðgöngum...",
+    "Set account as admin for …" : "Setja notandaaðganginn sem stjórnanda fyrir …",
+    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Týnist tæki eða hætti einhver hjá fyrirtæki/stofnun, þá getur þetta hreinsað fjartengt út öll Nextcloud-gögn af öllum tækjum sem tengd eru {userid}. Virkar bara ef tækin eru tengd internetinu.",
+    "Loading account …" : "Hleð inn notandaaðgangi …",
+    "Adding your device …" : "Bæti við tækinu þínu …",
+    "{progress}% Deploying …" : "{progress}% Sett í gang …",
+    "{progress}% Initializing …" : "{progress}% Frumstilling …",
+    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Þetta forrit er merkt sem ekki samhæft við þína útgáfu af Nextcloud. Ef þú heldur áfram er mögulegt að þú getir samt sett forritið upp. En athugaðu þá að ekki er víst að forritið virki eins og skyldi.",
+    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Það er mikilvægt fyrir öryggi og afköst uppsetningarinnar þinnar að allt sé rétt stillt. Til að hjálpa við að svo sé, eru gerðar ýmsar sjálfvirkar prófanir. Skoðaðu hjálparskjölin til að sjá ítarlegar upplýsingar.",
+    "Checking for system and security issues." : "Athuga með kerfis- og öryggisvandamál.",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Yfirfarðu vandlega <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">uppsetningarleiðbeiningarnar ↗</a>, og athugaðu hvort nokkrar villumeldingar eða aðvaranir séu í <a href=\"%2$s\">annálnum</a>.",
+    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Athugaðu öryggi Nextcloud-skýsins með <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">öryggisskönnun okkar ↗</a>."
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
