@@ -56,7 +56,6 @@ OC.L10N.register(
     "Failed to delete tag" : "فشل حذف الوسم",
     "Create or edit tags" : "إنشاء أو تعديل الوسوم ",
     "Search for a tag to edit" : "البحث عن وسم لتعديله",
-    "Collaborative tags …" : "وسوم تعاونية...",
     "No tags to select" : "لا توجد أي وسوم للاختيار منها",
     "Tag name" : "اسم الوسم",
     "Tag level" : "مستوى الوسم",
@@ -64,7 +63,6 @@ OC.L10N.register(
     "Update" : "تحديث",
     "Delete" : "حذف ",
     "Reset" : "إعادة تعيين",
-    "Loading …" : "التحميل جارٍ …",
     "_{tag1} will be set and {tag2} will be removed from 1 file._::_{tag1} will be set and {tag2} will be removed from {count} files._" : ["{tag1} سوف يتم تعيينها؛ بينما {tag2} سوف تتم إزالتها عن {count} ملف.","{tag1} سوف يتم تعيينها؛ بينما {tag2} ستتم إزالتها عن 1 ملف.","{tag1} سوف يتم تعيينها؛ بينما {tag2} سوف تتم إزالتها عن {count} ملف.","{tag1} سوف يتم تعيينها؛ بينما {tag2} سوف تتم إزالتها عن {count} ملفات.","{tag1} سوف يتم تعيينها؛ بينما {tag2} ستتم إزالتها عن {count} ملف.","{tag1} سوف يتم تعيينها؛ بينما {tag2} ستتم إزالتها عن {count} ملف.."],
     "_{tag} will be set to 1 file._::_{tag} will be set to {count} files._" : ["{tag} سيتم تعيينها لـ {count} ملف.","{tag} سيتم تعيينها لـ 1 ملف.","{tag} سيتم تعيينها لـ {count} ملف.","{tag} سيتم تعيينها لـ {count} ملفات.","{tag} سيتم تعيينها لـ {count} ملف.","{tag} سيتم تعيينها لـ {count} ملف."],
     "_{tag} will be removed from 1 file._::_{tag} will be removed from {count} files._" : ["{tag} ستتم إزالتها عن {count} ملف.","{tag} ستتم إزالتها عن 1 ملف.","{tag} ستتم إزالتها عن {count} ملف.","{tag} ستتم إزالتها عن {count} ملفات.","{tag} ستتم إزالتها عن {count} ملف.","{tag} ستتم إزالتها عن {count} ملف."],
@@ -74,22 +72,18 @@ OC.L10N.register(
     "{displayName} (restricted)" : "{displayName} (محضور)",
     "Only admins can create new tags" : "المشرفون وحدهم يمكنهم إنشاء وسوم جديدة",
     "Failed to apply tags changes" : "تعذّر تطبيق التغييرات في الوسوم",
-    "File tags modification canceled" : "تمّ إلغاء تعديل وسوم الملف",
     "Manage tags" : "إدارة الوسوم",
     "Applying tags changes…" : "يتم تطبيق التغييرات في الوسوم...",
     "Search or create tag" : "إنشاء أو بحث عن وسم",
     "Search tag" : "البحث عن وسم",
     "Change tag color" : "تغيير لون الوسم",
     "Create new tag" : "إنشاء وسم جديد",
-    "Select or create tags to apply to all selected files" : "إختيار أو إنشاء وسوم لتطبيقها على جميع الملفات المحددة",
-    "Select tags to apply to all selected files" : "إختَر وسوماً لإضافتها لجميع الملفات المُحدَّدة",
     "Cancel" : "إلغاء",
-    "Apply changes" : "تطبيق التغييرات",
-    "Failed to load tags" : "فشل في تحميل الوسوم",
+    "Apply" : "حفظ",
     "Failed to load selected tags" : "فشل في تحميل الوسوم المنتقاة",
+    "Failed to load tags" : "فشل في تحميل الوسوم",
     "Failed to select tag" : "فشل في اختيار وسم",
     "System admin disabled tag creation. You can only use existing ones." : "مشرف النظام قام بمنع إنشاء وُسُوم جديدة. يمكنك فقط الاختيار من بين الوُسُوم الموجودة.",
-    "Loading collaborative tags …" : "تحميل الوسوم التعاونية ...",
     "Search or create collaborative tags" : "إنشاء أو البحث عن وسم تعاوني",
     "No tags to select, type to create a new tag" : "لا توجد أي وسوم؛ أكتب لإنشاء وسم جديد",
     "Unable to update setting" : "تعذّر تحديث الإعدادات",
@@ -99,6 +93,7 @@ OC.L10N.register(
     "If enabled, only administrators can create and edit tags. Accounts can still assign and remove them from files." : "عند تمكنيها، يمكن للمشرفين فقط إنشاء وتعديل الوسوم. باقي الحسابات مايزال بإمكانها إسنادها إلى وإزالتها عن الملفات. ",
     "Restrict tag creation and editing to administrators" : "تقييد إنشاء وتعديل الوسوم على المشرفين",
     "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "الوسوم التعاونية متاحة لكل المستخدمين. الوسوم المقيدة restricted يمكن للمستخدمين رؤيتها لكن لا يمكنهم إسنادها. الوسوم المخفية invisible للاستعمال الداخلي فقط حيث لا يستطيع المستخدمون رؤيتها و لا إسنادها.",
+    "Add tags" : "إضافة سِمَاتٍ",
     "Assigned collaborative tags" : "الوسوم التعاونية المُسندَة",
     "Open in Files" : "إفتَح في \"الملفات\"",
     "List of tags and their associated files and folders." : "قائمة بالوسوم والملفات والمجلدات الموسومة بها.",
@@ -110,6 +105,13 @@ OC.L10N.register(
     "A tag with the same name already exists" : "توجد سمة بنفس الاسم مسبقاً",
     "Failed to load tags for file" : "تعذّر تحميل وسوم الملف",
     "Failed to set tag for file" : "تعذّر وضع وسم على الملف",
-    "Failed to delete tag for file" : "تعذّر حذف وسم من على ملف"
+    "Failed to delete tag for file" : "تعذّر حذف وسم من على ملف",
+    "Collaborative tags …" : "وسوم تعاونية...",
+    "Loading …" : "التحميل جارٍ …",
+    "File tags modification canceled" : "تمّ إلغاء تعديل وسوم الملف",
+    "Select or create tags to apply to all selected files" : "إختيار أو إنشاء وسوم لتطبيقها على جميع الملفات المحددة",
+    "Select tags to apply to all selected files" : "إختَر وسوماً لإضافتها لجميع الملفات المُحدَّدة",
+    "Apply changes" : "تطبيق التغييرات",
+    "Loading collaborative tags …" : "تحميل الوسوم التعاونية ..."
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
