@@ -56,7 +56,7 @@ OC.L10N.register(
     "Failed to delete tag" : "Failed to delete tag",
     "Create or edit tags" : "Create or edit tags",
     "Search for a tag to edit" : "Search for a tag to edit",
-    "Collaborative tags …" : "Collaborative tags …",
+    "Collaborative tags …" : "Collaborative tags …",
     "No tags to select" : "No tags to select",
     "Tag name" : "Tag name",
     "Tag level" : "Tag level",
@@ -64,7 +64,7 @@ OC.L10N.register(
     "Update" : "Update",
     "Delete" : "Delete",
     "Reset" : "Reset",
-    "Loading …" : "Loading …",
+    "Loading …" : "Loading …",
     "_{tag1} will be set and {tag2} will be removed from 1 file._::_{tag1} will be set and {tag2} will be removed from {count} files._" : ["{tag1} will be set and {tag2} will be removed from 1 file.","{tag1} will be set and {tag2} will be removed from {count} files."],
     "_{tag} will be set to 1 file._::_{tag} will be set to {count} files._" : ["{tag} will be set to 1 file.","{tag} will be set to {count} files."],
     "_{tag} will be removed from 1 file._::_{tag} will be removed from {count} files._" : ["{tag} will be removed from 1 file.","{tag} will be removed from {count} files."],
@@ -74,22 +74,20 @@ OC.L10N.register(
     "{displayName} (restricted)" : "{displayName} (restricted)",
     "Only admins can create new tags" : "Only admins can create new tags",
     "Failed to apply tags changes" : "Failed to apply tags changes",
-    "File tags modification canceled" : "File tags modification cancelled",
     "Manage tags" : "Manage tags",
     "Applying tags changes…" : "Applying tags changes…",
     "Search or create tag" : "Search or create tag",
     "Search tag" : "Search tag",
     "Change tag color" : "Change tag colour",
     "Create new tag" : "Create new tag",
-    "Select or create tags to apply to all selected files" : "Select or create tags to apply to all selected files",
-    "Select tags to apply to all selected files" : "Select tags to apply to all selected files",
+    "Choose tags for the selected files" : "Choose tags for the selected files",
     "Cancel" : "Cancel",
-    "Apply changes" : "Apply changes",
-    "Failed to load tags" : "Failed to load tags",
+    "Apply" : "Apply",
     "Failed to load selected tags" : "Failed to load selected tags",
+    "Failed to load tags" : "Failed to load tags",
     "Failed to select tag" : "Failed to select tag",
     "System admin disabled tag creation. You can only use existing ones." : "System admin disabled tag creation. You can only use existing ones.",
-    "Loading collaborative tags …" : "Loading collaborative tags …",
+    "Loading collaborative tags …" : "Loading collaborative tags …",
     "Search or create collaborative tags" : "Search or create collaborative tags",
     "No tags to select, type to create a new tag" : "No tags to select, type to create a new tag",
     "Unable to update setting" : "Unable to update setting",
@@ -99,6 +97,7 @@ OC.L10N.register(
     "If enabled, only administrators can create and edit tags. Accounts can still assign and remove them from files." : "If enabled, only administrators can create and edit tags. Accounts can still assign and remove them from files.",
     "Restrict tag creation and editing to administrators" : "Restrict tag creation and editing to administrators",
     "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them.",
+    "Add tags" : "Add tags",
     "Assigned collaborative tags" : "Assigned collaborative tags",
     "Open in Files" : "Open in Files",
     "List of tags and their associated files and folders." : "List of tags and their associated files and folders.",
@@ -110,6 +109,13 @@ OC.L10N.register(
     "A tag with the same name already exists" : "A tag with the same name already exists",
     "Failed to load tags for file" : "Failed to load tags for file",
     "Failed to set tag for file" : "Failed to set tag for file",
-    "Failed to delete tag for file" : "Failed to delete tag for file"
+    "Failed to delete tag for file" : "Failed to delete tag for file",
+    "Collaborative tags …" : "Collaborative tags …",
+    "Loading …" : "Loading …",
+    "File tags modification canceled" : "File tags modification cancelled",
+    "Select or create tags to apply to all selected files" : "Select or create tags to apply to all selected files",
+    "Select tags to apply to all selected files" : "Select tags to apply to all selected files",
+    "Apply changes" : "Apply changes",
+    "Loading collaborative tags …" : "Loading collaborative tags …"
 },
 "nplurals=2; plural=(n != 1);");
