@@ -9,6 +9,7 @@ declare(strict_types = 1);
 
 namespace OCA\TwoFactorTOTP\Service;
 
+use OCA\TwoFactorTOTP\Db\TotpSecret;
 use OCA\TwoFactorTOTP\Exception\NoTotpSecretFoundException;
 use OCA\TwoFactorTOTP\Exception\TotpSecretAlreadySet;
 use OCP\AppFramework\Db\DoesNotExistException;
@@ -33,6 +34,11 @@ interface ITotp {
 	 */
 	public function createSecret(IUser $user): string;
 
+	/**
+	 * @throws NoTotpSecretFoundException
+	 */
+	public function getSecret(IUser $user): TotpSecret;
+
 	/**
 	 * Enable OTP for the given user. The secret has to be generated
 	 * beforehand, using ITotp::createSecret
@@ -47,5 +53,5 @@ interface ITotp {
 
 	public function deleteSecret(IUser $user, bool $byAdmin = false): void;
 
-	public function validateSecret(IUser $user, string $key): bool;
+	public function validateSecret(TotpSecret $secret, string $key): bool;
 }
