@@ -83,11 +83,13 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Актуализирането беше неуспешно. Моля отнесете този проблем към <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\"> Nextcloud общността</a>.",
     "Continue to {productName}" : "Продължаване към {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Актуализацията беше успешна. Пренасочване към {productName} след %n секунди.","Актуализацията беше успешна. Пренасочване към {productName} след %n секунди."],
+    "Done" : "Завършено",
     "Apps" : "Приложения",
     "More apps" : "Още приложения",
     "_{count} notification_::_{count} notifications_" : ["{count} известие","{count} известия"],
     "No" : "Не",
     "Yes" : "Да",
+    "Grant access" : "Разреши достъпa",
     "Invalid remote URL." : "невалиден отдалечен URL(адрес)",
     "Failed to add the public link to your Nextcloud" : "Неуспешно добавяне на публичната връзка към вашия Nextcloud",
     "Create share" : "Създаване на споделяне",
@@ -114,7 +116,6 @@ OC.L10N.register(
     "Log in" : "Вписване",
     "Log in to {productName}" : "Вписване в {productName}",
     "This account is disabled" : "Профилът е неактивен",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Открихме множество невалидни опити за влизане от вашия IP. Следователно следващото ви влизане се ограничава за 30 секунди.",
     "Account name or email" : "Име на профил или имейл",
     "Account name" : "Име на профил",
     "Server side authentication failed!" : "Неуспешно удостоверяването от страна на сървъра!",
@@ -148,6 +149,11 @@ OC.L10N.register(
     "Cannot install this app" : "Това приложение не може да се инсталира",
     "Skip" : "Пропускане",
     "Install recommended apps" : "Инсталиране на препоръчаните приложения ",
+    "Online" : "На линия /онлайн/",
+    "Away" : "Винаги",
+    "Busy" : "Зает",
+    "Do not disturb" : "Не безпокой",
+    "Invisible" : "Невидим",
     "Settings menu" : "Настройки",
     "Search contacts" : "Търсене в контакти",
     "Reset search" : "Ново търсене",
@@ -165,8 +171,14 @@ OC.L10N.register(
     "Forgot password?" : "Забравена парола?",
     "Back" : "Назад",
     "Login form is disabled." : "Формулярът за вход е деактивиран",
-    "More actions" : "Повече действия",
+    "Connect to your account" : "Свързване към вашия профил",
     "Security warning" : "Предупреждение за сигурност",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Ако не се опитвате да настроите ново устройство или приложение, някой се опитва да ви подмами, за да му предоставите достъп до вашите данни. В този случай не продължавайте и вместо това се свържете със системния си администратор.",
+    "Account connected" : "Профилът е свързан",
+    "Your client should now be connected!" : "Клиентът ви вече трябва да е свързан!",
+    "You can close this window." : "Можеш да затвориш този прозорец.",
+    "Account access" : "Достъп до профил",
+    "More actions" : "Повече действия",
     "Storage & database" : "Хранилища и бази данни",
     "Data folder" : "Директория за данни",
     "Install and activate additional PHP modules to choose other database types." : "Инсталирайте и активирайте допълнителни PHP модули, за да изберете други видове бази данни.",
@@ -189,8 +201,11 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Вашият браузър не се поддържа. Моля, преминете към по-нова версия или към версия, която се поддържа.",
     "Continue with this unsupported browser" : "Продължете с този неподдържан браузър",
     "Supported versions" : "Поддържани версии",
+    "Choose {file}" : "Изберете {file}",
     "Choose" : "Избор",
+    "Copy to {target}" : "Копиране в {target}",
     "Copy" : "Копирай",
+    "Move to {target}" : "Преместване на {target}",
     "Move" : "Премести",
     "OK" : "Добре",
     "read-only" : "Само за четене",
@@ -206,6 +221,9 @@ OC.L10N.register(
     "({count} selected)" : "({count} избрани)",
     "Error loading file exists template" : "Грешка при зареждането на шаблона за вече съществуващ файл",
     "Saving …" : "Запазване ...",
+    "Groups" : "Групи",
+    "Group list is empty" : "Списъкът с групи е празен",
+    "Unable to retrieve the group list" : "Не може да се извлече списъкът с групи",
     "seconds ago" : "преди секунди",
     "Connection to server lost" : "Няма връзка със сървъра",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Проблем при зареждането на страницата, презареждане след %n секунда","Проблем при зареждането на страницата, презареждане след %n секунди"],
@@ -252,16 +270,6 @@ OC.L10N.register(
     "Skip to navigation of app" : "Преминаване към навигация на приложението",
     "Go to %s" : "Отидете на %s",
     "Get your own free account" : "Вземете свой собствен безплатен профил",
-    "Connect to your account" : "Свързване към вашия профил",
-    "Please log in before granting %1$s access to your %2$s account." : "Необходимо е да се впишете, преди да дадете достъп на %1$s до вашия %2$s профил.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Ако не се опитвате да настроите ново устройство или приложение, някой се опитва да ви подмами, за да му предоставите достъп до вашите данни. В този случай не продължавайте и вместо това се свържете със системния си администратор.",
-    "Grant access" : "Разреши достъпa",
-    "Account access" : "Достъп до профил",
-    "Currently logged in as %1$s (%2$s)." : "В момента сте влезли като %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Ще разрешите на %1$s да ползва вашия %2$s профил.",
-    "Account connected" : "Профилът е свързан",
-    "Your client should now be connected!" : "Клиентът ви вече трябва да е свързан!",
-    "You can close this window." : "Можеш да затвориш този прозорец.",
     "Previous" : "Предишен ",
     "This share is password-protected" : "Тази зона е защитена с парола.",
     "The password is wrong or expired. Please try again or request a new one." : "Паролата е грешна или е изтекла. Моля, опитайте отново или поискайте нова.",
@@ -313,6 +321,7 @@ OC.L10N.register(
     "Direct link copied to clipboard" : "Директният адрес е копиран в клипборда",
     "Searching …" : "Търсене ...",
     "Logging in …" : "Вписване ...",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Открихме множество невалидни опити за влизане от вашия IP. Следователно следващото ви влизане се ограничава за 30 секунди.",
     "Loading apps …" : "Зареждане на приложения ...",
     "Installing apps …" : "Инсталиране на приложения ...",
     "Loading your contacts …" : "Зареждане на контактите ...",
@@ -330,7 +339,6 @@ OC.L10N.register(
     "Error fetching contact actions" : "Грешка при извличането на действия за контакт",
     "Non-existing tag #{tag}" : "Несъществуващ етикет #{tag}",
     "Restricted" : "Ограничен",
-    "Invisible" : "Невидим",
     "Delete" : "Изтрий",
     "Rename" : "Преименувай",
     "Collaborative tags" : "Съвместни етикети",
@@ -344,6 +352,9 @@ OC.L10N.register(
     "Configure the database" : "Конфигуриране на базата данни",
     "Only %s is available." : "Само %s е наличен.",
     "Database account" : "Профил за база данни",
-    "Installing …" : "В процес на инсталиране…"
+    "Installing …" : "В процес на инсталиране…",
+    "Please log in before granting %1$s access to your %2$s account." : "Необходимо е да се впишете, преди да дадете достъп на %1$s до вашия %2$s профил.",
+    "Currently logged in as %1$s (%2$s)." : "В момента сте влезли като %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Ще разрешите на %1$s да ползва вашия %2$s профил."
 },
 "nplurals=2; plural=(n != 1);");
