@@ -18,15 +18,15 @@ OC.L10N.register(
     "Unknown filetype" : "Nekonata dosiertipo",
     "An error occurred. Please contact your admin." : "Eraro okazis. Bonvolu kontakti vian administranton.",
     "Invalid image" : "Nevalida bildo",
-    "No temporary profile picture available, try again" : "Neniu provizora profilbildo disponeblas, bv. reprovi",
-    "No crop data provided" : "Neniu stucdatumo provizita",
-    "No valid crop data provided" : "Neniu valida stucdatumo provizita",
-    "Crop is not square" : "Stuca elekto ne estas kvadrata",
     "State token does not match" : "Stata ĵetono ne kongruas",
     "Invalid app password" : "Nevalida aplikaĵo-pasvorto",
     "Could not complete login" : "Ensaluto ne eblis",
+    "State token missing" : "Mankas ĵetono pri stato",
     "Your login token is invalid or has expired" : "Via ensaluta ĵetono ne validas aŭ senvalidiĝis",
+    "Please use original client" : "Bonvolu uzi la originan klienton",
+    "This community release of Nextcloud is unsupported and push notifications are limited." : "Tiu ĉi komunuma eldonaĵo de Nextcloud ne havas subtenon, kaj puŝajn atentigojn estas limigitaj.",
     "Login" : "Login",
+    "Unsupported email length (>255)" : "Nevalida longeco de retadreso (>255)",
     "Password reset is disabled" : "Pasvorta restarigo malebligita",
     "Could not reset password because the token is expired" : "Ne eblis restarigi pasvorton, ĉar la ĵetono senvalidiĝis",
     "Could not reset password because the token is invalid" : "Ne eblis restarigi pasvorton, ĉar la ĵetono ne validas",
@@ -36,9 +36,13 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Alklaku la jenan butonon por restarigi vian pasvorton. Si vi ne petis restarigon de via pasvorto, simple ignoru tiun ĉi retmesaĝon.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Alklaku la jenan ligilon por restarigi vian pasvorton. Si vi ne petis restarigon de via pasvorto, simple ignoru tiun ĉi retmesaĝon.",
     "Reset your password" : "Restarigi vian pasvorton ",
+    "The given provider is not available" : "La provizanto menciita ne estas disponebla",
     "Task not found" : "Tasko ne trovita",
     "Internal error" : "Interna eraro",
     "Not found" : "Ne trovita",
+    "Node is locked" : "Nodo estas ŝlosita",
+    "Bad request" : "Malbona peto",
+    "Requested task type does not exist" : "Petita task-tipo ne ekzistas",
     "Image not found" : "Bildo ne trovita",
     "Unable to translate" : "Ne eblas traduki",
     "[%d / %d]: %s" : "[%d / %d]: %s",
@@ -67,34 +71,26 @@ OC.L10N.register(
     "The following apps have been disabled: %s" : "La jenaj aplikaĵoj estis malŝatitaj: %s",
     "Already up to date" : "Jam aktuala",
     "Unknown" : "Nekonata",
-    "Error occurred while checking server setup" : "Eraro dum kontrolo de servila agordo",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Por pliaj detaloj, vidu la {linkstart}dokumentaron ↗{linkend}.",
-    "unknown text" : "nekonata teksto",
-    "Hello world!" : "Saluton, mondo!",
-    "sunny" : "suna",
-    "Hello {name}, the weather is {weather}" : "Saluton {name}, la vetero estas {weather}",
-    "Hello {name}" : "Saluton {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Jen via serĉ-rezultoj<script>alert(1)</script></strong>",
-    "new" : "nova",
-    "_download %n file_::_download %n files_" : ["elŝuti %n dosieron","elŝuti %n dosierojn"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Ĝisdatigo estas farata; forirado de la paĝo povas kelkfoje interrompi la agon.",
     "Update to {version}" : "Ĝisdatigi al {version}",
     "An error occurred." : "Eraro okazis.",
     "Please reload the page." : "Bonvolu reŝargi la paĝon.",
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "La ĝisdatigo malsukcesis. Por pli da informoj, <a href=\"{url}\">vidu la forumafisôn</a> pri tio.",
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "La ĝisdatigo malsukcesis. Bonvolu raporti tiun problemon al la <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud-komunumo</a>.",
+    "Done" : "Farita",
     "Applications menu" : "Aplikaĵa menuo",
     "Apps" : "Aplikaĵoj",
     "More apps" : "Pli da aplikaĵoj",
     "_{count} notification_::_{count} notifications_" : ["{count} sciigoj","{count} sciigoj"],
     "No" : "Ne",
     "Yes" : "Jes",
+    "App password" : "Aplikaĵa pasvorto",
+    "Grant access" : "Doni alirpermeson",
     "Failed to add the public link to your Nextcloud" : "Ne eblis aldoni la publikan ligilon al via Nextcloud",
     "Custom date range" : "Propra data periodo",
     "Pick start date" : "Elekti komencan daton",
     "Pick end date" : "Elekti finan daton",
     "Search in date range" : "Serĉi en data periodo",
-    "Searching …" : "Serĉado ...",
     "Start typing to search" : "Ektajpu por serĉi",
     "No matching results" : "Neniuj kongruaj rezultoj",
     "Today" : "Hodiaŭ",
@@ -108,9 +104,7 @@ OC.L10N.register(
     "Filter in current view" : "Filtrilo en ĉi vido",
     "Search in" : "Serĉi en",
     "Log in" : "Ensaluti",
-    "Logging in …" : "Ensaluti...",
     "Log in to {productName}" : "Saluti al {productName}",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Ni eltrovis plurajn nevalidajn provojn ensaluti el via IP-adreso. Do, oni prokrastis vian sekvantan ensaluton dum ĝis 30 sekundoj.",
     "Account name or email" : "Kontonomo aŭ retpoŝta adreso",
     "Server side authentication failed!" : "Ĉeservila aŭtentigo malsukcesis!",
     "Please contact your administrator." : "Bonvolu kontakti vian administranton.",
@@ -129,18 +123,15 @@ OC.L10N.register(
     "I know what I'm doing" : "Mi scias, kion mi faras",
     "Resetting password" : "Restarigo de la pasvorto",
     "Recommended apps" : "Rekomendataj aplikaĵoj",
-    "Loading apps …" : "Ŝargado de aplikaĵoj...",
     "App download or installation failed" : "Elŝuto aŭ instalado de la aplikaĵo malsukcesis",
     "Cannot install this app" : "La instalado de tiu aplikaĵo ne eblas",
     "Skip" : "Preterpasi",
-    "Installing apps …" : "Instalado de aplikaĵoj...",
     "Install recommended apps" : "Instali rekomendatajn aplikaĵojn",
+    "Busy" : "Okupita",
+    "Invisible" : "Nevidebla",
     "Avatar of {displayName}" : "Avataro de {displayName}",
     "Settings menu" : "Menuo de agordo",
-    "Loading your contacts …" : "Ŝargo de viaj kontaktoj...",
-    "Looking for {term} …" : "Serĉo de {term}…",
     "Reset search" : "Restarigi serĉon",
-    "Search contacts …" : "Serĉi kontaktojn…",
     "Could not load your contacts" : "Ne eblis ŝargi viajn kontaktojn",
     "No contacts found" : "Neniu kontakto troviĝis",
     "Install the Contacts app" : "Instali la Kontakto-aplikaĵon",
@@ -148,8 +139,14 @@ OC.L10N.register(
     "No results for {query}" : "Neniu rezulto pri {query}",
     "Forgot password?" : "Ĉu vi forgesis vian pasvorton?",
     "Back" : "Antaŭen",
-    "More actions" : "Pliaj agoj",
+    "Connect to your account" : "Konekti al via konto",
     "Security warning" : "Sekureca averto",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Se vi ne provas agordi novan aparaton aŭ apon, iu provas trompi vin por doni al ili aliron al viaj datumoj. En ĉi tiu kazo ne procedu kaj anstataŭe kontaktu vian sisteman administranton.",
+    "Account connected" : "Konto konektita",
+    "Your client should now be connected!" : "Via kliento estas konektita!",
+    "You can close this window." : "Vi povas fermi tiun ĉi fenestron.",
+    "Account access" : "Aliro al konto",
+    "More actions" : "Pliaj agoj",
     "Storage & database" : "Konservejo kaj datumbazo",
     "Data folder" : "Datuma dosierujo",
     "Install and activate additional PHP modules to choose other database types." : "Instalu kaj aktivigu pliajn PHP-modulojn por elekti aliajn datumbazajn specojn..",
@@ -164,7 +161,6 @@ OC.L10N.register(
     "Database tablespace" : "Datumbaza tabelospaco",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Bv. entajpi la pordan numeron kune kun la gastiga nomo (ekzemple: localhost:5432).",
     "Database host" : "Datumbaza gastigo",
-    "Installing …" : "Instalante…",
     "Install" : "Instali",
     "Need help?" : "Ĉu necesas helpo?",
     "See the documentation" : "Vidi la dokumentaron",
@@ -191,7 +187,9 @@ OC.L10N.register(
     "(all selected)" : "(ĉiuj elektitaj)",
     "({count} selected)" : "({count} elektitaj)",
     "Error loading file exists template" : "Eraris ŝargo de ŝablono pri ekzistanta dosiero",
-    "Saving …" : "Konservado...",
+    "Groups" : "Grupoj",
+    "Group list is empty" : "Gruplisto malplenas",
+    "Unable to retrieve the group list" : "Ne eblas ricevi grupliston",
     "seconds ago" : "sekundoj antaŭe",
     "Connection to server lost" : "Konekto al servilo perdita",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problemo dum ŝargo de paĝo, reŝargo en %n sekundo","Problemo dum ŝargo de paĝo, reŝargo en %n sekundoj"],
@@ -206,16 +204,7 @@ OC.L10N.register(
     "Type to search for existing projects" : "Entajpi por serĉi jam ekzistantajn projektojn",
     "New in" : "Nova en",
     "View changelog" : "Vidi ŝanĝoprotokolon",
-    "No action available" : "Neniu ago disponebla",
-    "Error fetching contact actions" : "Eraro dum serĉo de kontakt-agoj",
     "Close \"{dialogTitle}\" dialog" : "Fermi la dialogon \"{dialogTitle}\"",
-    "Non-existing tag #{tag}" : "Ne ekzistas etikedo #{tag}",
-    "Restricted" : "Limigita",
-    "Invisible" : "Nevidebla",
-    "Delete" : "Forigi",
-    "Rename" : "Alinomi",
-    "Collaborative tags" : "Kunlaboraj etikedoj",
-    "No tags found" : "Neniu etikedo troviĝis ",
     "Personal" : "Persona",
     "Accounts" : "Kontoj",
     "Admin" : "Administranto",
@@ -247,17 +236,6 @@ OC.L10N.register(
     "Skip to navigation of app" : "Iru al la aplikaĵa navigado",
     "Go to %s" : "Iri al %s",
     "Get your own free account" : "Ekhavu vian propran senpagan konton",
-    "Connect to your account" : "Konekti al via konto",
-    "Please log in before granting %1$s access to your %2$s account." : "Bv. unue ensaluti por doni al %1$s aliron al via konto %2$s.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Se vi ne provas agordi novan aparaton aŭ apon, iu provas trompi vin por doni al ili aliron al viaj datumoj. En ĉi tiu kazo ne procedu kaj anstataŭe kontaktu vian sisteman administranton.",
-    "App password" : "Aplikaĵa pasvorto",
-    "Grant access" : "Doni alirpermeson",
-    "Account access" : "Aliro al konto",
-    "Currently logged in as %1$s (%2$s)." : "Aktuale salutinta kiel %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Vi tuj donos permeson al %1$s aliri al via konto %2$s.",
-    "Account connected" : "Konto konektita",
-    "Your client should now be connected!" : "Via kliento estas konektita!",
-    "You can close this window." : "Vi povas fermi tiun ĉi fenestron.",
     "Previous" : "Antaŭa",
     "This share is password-protected" : "Tiu kunhavigo estas protektata per pasvorto",
     "The password is wrong or expired. Please try again or request a new one." : "La pasvorto estas malĝusta aŭ eksvalidiĝis. Bonvolu provi denove aŭ peti novan.",
@@ -294,20 +272,48 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "La servilo %s estas nun en reĝimo de prizorgado, tio eble daŭros longatempe.",
     "This page will refresh itself when the instance is available again." : "Tiu ĉi paĝo aktualiĝos mem, kiam la servilo redisponeblos.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktu vian administranton, se tiu ĉi mesaĝo daŭras aŭ aperas neatendite.",
-    "Edit Profile" : "Modifi profilon",
+    "Error occurred while checking server setup" : "Eraro dum kontrolo de servila agordo",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Por pliaj detaloj, vidu la {linkstart}dokumentaron ↗{linkend}.",
+    "unknown text" : "nekonata teksto",
+    "Hello world!" : "Saluton, mondo!",
+    "sunny" : "suna",
+    "Hello {name}, the weather is {weather}" : "Saluton {name}, la vetero estas {weather}",
+    "Hello {name}" : "Saluton {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Jen via serĉ-rezultoj<script>alert(1)</script></strong>",
+    "new" : "nova",
+    "_download %n file_::_download %n files_" : ["elŝuti %n dosieron","elŝuti %n dosierojn"],
+    "Searching …" : "Serĉado ...",
+    "Logging in …" : "Ensaluti...",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Ni eltrovis plurajn nevalidajn provojn ensaluti el via IP-adreso. Do, oni prokrastis vian sekvantan ensaluton dum ĝis 30 sekundoj.",
+    "Loading apps …" : "Ŝargado de aplikaĵoj...",
+    "Installing apps …" : "Instalado de aplikaĵoj...",
+    "Loading your contacts …" : "Ŝargo de viaj kontaktoj...",
+    "Looking for {term} …" : "Serĉo de {term}…",
+    "Search contacts …" : "Serĉi kontaktojn…",
+    "Saving …" : "Konservado...",
     "Very weak password" : "Tre malforta pasvorto",
     "Weak password" : "Malforta pasvorto",
     "So-so password" : "Mezbona pasvorto",
     "Good password" : "Bona pasvorto",
     "Strong password" : "Forta pasvorto",
-    "Profile not found" : "Profilo ne troviĝis",
-    "The profile does not exist." : "La profilo ne ekzistas.",
+    "No action available" : "Neniu ago disponebla",
+    "Error fetching contact actions" : "Eraro dum serĉo de kontakt-agoj",
+    "Non-existing tag #{tag}" : "Ne ekzistas etikedo #{tag}",
+    "Restricted" : "Limigita",
+    "Delete" : "Forigi",
+    "Rename" : "Alinomi",
+    "Collaborative tags" : "Kunlaboraj etikedoj",
+    "No tags found" : "Neniu etikedo troviĝis ",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Via datumdosierujo kaj dosieroj estas probable elireblaj el la interreto, ĉar la dosiero „.htaccess“ ne funkcias.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Por pli da informoj pri kielo agordi vian retservilon, bv. vidi la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaron</a>.",
     "Show password" : "Montri pasvorton",
     "Toggle password visibility" : "Ŝanĝi videblecon de pasvorto",
     "Configure the database" : "Agordi la datumbazon",
     "Only %s is available." : "Nur %s disponeblas.",
-    "Database account" : "Datumbaza konto"
+    "Database account" : "Datumbaza konto",
+    "Installing …" : "Instalante…",
+    "Please log in before granting %1$s access to your %2$s account." : "Bv. unue ensaluti por doni al %1$s aliron al via konto %2$s.",
+    "Currently logged in as %1$s (%2$s)." : "Aktuale salutinta kiel %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Vi tuj donos permeson al %1$s aliri al via konto %2$s."
 },
 "nplurals=2; plural=(n != 1);");
