@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "סוג קובץ לא מוכר",
     "An error occurred. Please contact your admin." : "אירעה שגיאה. יש ליצור קשר עם המנהל שלך.",
     "Invalid image" : "תמונה לא חוקית",
-    "No temporary profile picture available, try again" : "לא קיימת תמונת פרופיל זמנית, יש לנסות שוב",
-    "No crop data provided" : "לא סופק מידע קיטום",
-    "No valid crop data provided" : "לא סופק מידע קיטום חוקי",
-    "Crop is not square" : "הקיטום אינו מרובע",
     "State token does not match" : "קוד אימות מצב אינו תואם",
     "Invalid app password" : "ססמת היישומון שגויה",
     "Could not complete login" : "לא ניתן להשלים את הכניסה",
@@ -60,27 +56,20 @@ OC.L10N.register(
     "The following apps have been disabled: %s" : "היישומים הבאים הושבתו: %s",
     "Already up to date" : "כבר עדכני",
     "Unknown" : "לא ידוע",
-    "unknown text" : "מלל לא מוכר",
-    "Hello world!" : "שלום עולם!",
-    "sunny" : "שמשי",
-    "Hello {name}, the weather is {weather}" : "שלום {name}, מזג האוויר הנו {weather}",
-    "Hello {name}" : "שלום {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>אלו תוצאות החיפוש שלך<script>alert(1)</script></strong>",
-    "new" : "חדש",
-    "_download %n file_::_download %n files_" : ["התקבל קובץ %n","התקבלו %n קבצים","התקבלו %n קבצים"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "העדכון מתבצע, יציאה מהעמוד הזה עשויה להפריע לתהליך בסביבות מסוימות.",
     "Update to {version}" : "עדכון ל־{version}",
     "An error occurred." : "אירעה שגיאה.",
     "Please reload the page." : "יש להעלות מחדש דף זה.",
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "העדכון לא בוצע בהצלחה. למידע נוסף <a href=\"{url}\">ניתן לבדוק בהודעת הפורום שלנו</a> המכסה נושא זו.",
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "העדכון לא הצליח. נא לדווח על התקלה הזאת ל<a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">קהילת Nextcloud</a>.",
+    "Done" : "הסתיים",
     "Apps" : "יישומים",
     "More apps" : "יישומים נוספים",
     "No" : "לא",
     "Yes" : "כן",
+    "Grant access" : "הענקת גישה",
     "Failed to add the public link to your Nextcloud" : "אירע כשל בהוספת קישור ציבורי ל־Nextcloud שלך",
     "Create share" : "צור שיתוף",
-    "Searching …" : "מתבצע חיפוש…",
     "Start typing to search" : "להתחלת החיפוש יש להקליד",
     "Today" : "היום",
     "Last year" : "שנה שעברה",
@@ -88,8 +77,6 @@ OC.L10N.register(
     "Date" : "תאריך",
     "Load more results" : "לטעון עוד תוצאות",
     "Log in" : "כניסה",
-    "Logging in …" : "מתבצעת כניסה…",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "זיהינו מספר ניסיונות כניסה שגויים מכתובת ה־IP שלך. לכן, ניסיון הכניסה הבא יתאפשר עבורך רק בעוד 30 שניות.",
     "Account name or email" : "שם משתמש או דואר אלקטרוני",
     "Server side authentication failed!" : "אימות לצד שרת נכשל!",
     "Please contact your administrator." : "יש ליצור קשר עם המנהל.",
@@ -111,16 +98,17 @@ OC.L10N.register(
     "Keep your colleagues and friends in one place without leaking their private info." : "עמיתים לעבודה וחברים מרוכזים במקום אחד מבלי זליגה של הפרטים האישיים שלהם.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "יישומון דוא״ל פשוט שמשתלב בצורה נחמדה עם הקבצים, אנשי הקשר והיומן.",
     "Recommended apps" : "יישומונים מומלצים",
-    "Loading apps …" : "היישומונים נטענים…",
     "App download or installation failed" : "הורדת או התקנת היישומון נכשלה",
     "Skip" : "דלג",
-    "Installing apps …" : "היישומונים מותקנים…",
     "Install recommended apps" : "התקנת יישומונים מומלצים",
+    "Online" : "מקוון",
+    "Away" : "לא פה",
+    "Busy" : "עסוק",
+    "Mute all notifications" : "השתקת כל ההתראות",
+    "Invisible" : "נסתרת",
+    "Appear offline" : "להופיע במצב בלתי מקוון",
     "Settings menu" : "תפריט הגדרות",
-    "Loading your contacts …" : "אנשי הקשר שלך נטענים…",
-    "Looking for {term} …" : "מתבצע חיפוש אחר {term}…",
     "Reset search" : "איפוס החיפוש",
-    "Search contacts …" : "חיפוש אנשי קשר…",
     "Could not load your contacts" : "לא ניתן לטעון את אנשי הקשר שלך",
     "No contacts found" : "לא נמצאו אנשי קשר",
     "Install the Contacts app" : "התקנת יישומון אנשי הקשר",
@@ -129,11 +117,16 @@ OC.L10N.register(
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["נא להקליד לפחות תו אחד כדי לחפש","נא להקליד לפחות {minSearchLength} תווים כדי לחפש","נא להקליד לפחות {minSearchLength} תווים כדי לחפש","נא להקליד לפחות {minSearchLength} תווים כדי לחפש"],
     "An error occurred while searching for {type}" : "אירעה שגיאה בחיפוש אחר {type}",
     "Search for {name} only" : "חפש ל-{name} בלבד",
-    "Loading more results …" : "נטענות תוצאות נוספות…",
     "Forgot password?" : "שכחת ססמה?",
     "Back" : "חזרה",
-    "More actions" : "פעולות נוספות",
+    "Connect to your account" : "התחברות לחשבון שלך",
     "Security warning" : "אזהרת אבטחה",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "אם אינך מנסה להגדיר מכשיר חדש או אפליקציה חדשה, מישהו מנסה לרמות אותך להעניק לו גישה לנתונים שלך. במקרה הזה, אל תמשיך, ובמקום זאת פנה למנהל המערכת שלך.",
+    "Account connected" : "חשבון מחובר",
+    "Your client should now be connected!" : "הלקוח שלך אמור להיות מחובר עכשיו!",
+    "You can close this window." : "ניתן לסגור את החלון הזה.",
+    "Account access" : "גישה לחשבון",
+    "More actions" : "פעולות נוספות",
     "Storage & database" : "אחסון ומסד נתונים",
     "Data folder" : "תיקיית נתונים",
     "Install and activate additional PHP modules to choose other database types." : "לבחירת סוגים אחרים של מסדי נתונים יש להתקין ולהפעיל מודולי PHP נוספים.",
@@ -151,7 +144,6 @@ OC.L10N.register(
     "Install" : "התקנה",
     "Need help?" : "עזרה נזקקת?",
     "See the documentation" : "יש לצפות במסמכי התיעוד",
-    "Search {types} …" : "חפש {types} ...",
     "Choose" : "בחירה",
     "Copy" : "העתקה",
     "Move" : "העברה",
@@ -168,7 +160,10 @@ OC.L10N.register(
     "(all selected)" : "(הכול נבחר)",
     "({count} selected)" : "({count} נבחרו)",
     "Error loading file exists template" : "שגיאה בטעינת קובץ תבנית קיימים",
-    "Saving …" : "מתבצעת שמירה…",
+    "Saving …" : "מתבצע שמירה…",
+    "Groups" : "קבוצות",
+    "Group list is empty" : "רשימת הקבוצות ריקה",
+    "Unable to retrieve the group list" : "לא ניתן לקבל את רשימת הקבוצות",
     "seconds ago" : "לפני מספר שניות",
     "Connection to server lost" : "החיבור לשרת אבד",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["תקלה בטעינת העמוד, יתבצע רענון בעוד שנייה","תקלה בטעינת העמוד, יתבצע רענון בעוד %n שניות","תקלה בטעינת העמוד, יתבצע רענון בעוד %n שניות","תקלה בטעינת העמוד, יתבצע רענון בעוד %n שניות"],
@@ -183,15 +178,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "לחיפוש במיזמים הקיימים יש להקליד",
     "New in" : "חדש ב־",
     "View changelog" : "הצגת יומן שינויים",
-    "No action available" : "אין פעולה זמינה",
-    "Error fetching contact actions" : "שגיאה בקבלת פעולות אנשי הקשר",
-    "Non-existing tag #{tag}" : "תגית לא קיימת #{tag}",
-    "Restricted" : "מוגבלת",
-    "Invisible" : "נסתרת",
-    "Delete" : "מחיקה",
-    "Rename" : "שינוי שם",
-    "Collaborative tags" : "תגיות שיתופיות",
-    "No tags found" : "לא נמצאו תגים",
     "Personal" : "אישי",
     "Accounts" : "Accounts",
     "Admin" : "מנהל",
@@ -222,15 +208,6 @@ OC.L10N.register(
     "Skip to navigation of app" : "דילוג לניווט של היישומון",
     "Go to %s" : "מעבר אל %s",
     "Get your own free account" : "קבלת חשבון משלך בחינם",
-    "Connect to your account" : "התחברות לחשבון שלך",
-    "Please log in before granting %1$s access to your %2$s account." : "נא להיכנס בטרם הענקת גישה לחשבון שלך ב־%2$s לטובת %1$s.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "אם אינך מנסה להגדיר מכשיר חדש או אפליקציה חדשה, מישהו מנסה לרמות אותך להעניק לו גישה לנתונים שלך. במקרה הזה, אל תמשיך, ובמקום זאת פנה למנהל המערכת שלך.",
-    "Grant access" : "הענקת גישה",
-    "Account access" : "גישה לחשבון",
-    "You are about to grant %1$s access to your %2$s account." : "פעולה זו תעניק ל־%1$s גישה לחשבון ה־%2$s שלך.",
-    "Account connected" : "חשבון מחובר",
-    "Your client should now be connected!" : "הלקוח שלך אמור להיות מחובר עכשיו!",
-    "You can close this window." : "ניתן לסגור את החלון הזה.",
     "Previous" : "הקודם",
     "This share is password-protected" : "שיתוף זה מוגן בססמה",
     "Email address" : "כתובת דוא״ל",
@@ -266,16 +243,44 @@ OC.L10N.register(
     "This page will refresh itself when the instance is available again." : "עמוד זה ירענן את עצמו כאשר העותק ישוב להיות זמין.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "יש ליצור קשר עם מנהל המערכת אם הודעה שו נמשכת או מופיעה באופן בלתי צפוי. ",
     "Error occurred while checking server setup" : "שגיאה אירעה בזמן בדיקת התקנת השרת",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "צ'אטים, שיחות וידאו, שיתוף מסך, פגישות מקוונות ועידת אינטרנט - בדפדפן ובאפליקציות סלולריות.",
+    "unknown text" : "מלל לא מוכר",
+    "Hello world!" : "שלום עולם!",
+    "sunny" : "שמשי",
+    "Hello {name}, the weather is {weather}" : "שלום {name}, מזג האוויר הנו {weather}",
+    "Hello {name}" : "שלום {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>אלו תוצאות החיפוש שלך<script>alert(1)</script></strong>",
+    "new" : "חדש",
+    "_download %n file_::_download %n files_" : ["התקבל קובץ %n","התקבלו %n קבצים","התקבלו %n קבצים"],
+    "Searching …" : "מתבצע חיפוש…",
+    "Logging in …" : "מתבצעת כניסה…",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "זיהינו מספר ניסיונות כניסה שגויים מכתובת ה־IP שלך. לכן, ניסיון הכניסה הבא יתאפשר עבורך רק בעוד 30 שניות.",
+    "Loading apps …" : "היישומונים נטענים…",
+    "Installing apps …" : "היישומונים מותקנים…",
+    "Loading your contacts …" : "אנשי הקשר שלך נטענים…",
+    "Looking for {term} …" : "מתבצע חיפוש אחר {term}…",
+    "Search contacts …" : "חיפוש אנשי קשר…",
+    "Loading more results …" : "נטענות תוצאות נוספות…",
+    "Search {types} …" : "חפש {types} ...",
+    "Saving …" : "מתבצעת שמירה…",
     "Very weak password" : "ססמה מאוד חלשה",
     "Weak password" : "ססמה חלשה",
     "So-so password" : "ססמה בינונית",
     "Good password" : "ססמה טובה",
     "Strong password" : "ססמה חזקה",
+    "No action available" : "אין פעולה זמינה",
+    "Error fetching contact actions" : "שגיאה בקבלת פעולות אנשי הקשר",
+    "Non-existing tag #{tag}" : "תגית לא קיימת #{tag}",
+    "Restricted" : "מוגבלת",
+    "Delete" : "מחיקה",
+    "Rename" : "שינוי שם",
+    "Collaborative tags" : "תגיות שיתופיות",
+    "No tags found" : "לא נמצאו תגים",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "תיקיות וקובצי הנתונים שלך כנראה נגישים מהאינטרנט מכיוון שקובץ ה־‎.htaccess לא עובד.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "למידע בנוגע להגדרת השרת שלך כראוי, נא לעיין ב<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">תיעוד</a>.",
     "Show password" : "הצגת ססמה",
     "Configure the database" : "הגדרת מסד הנתונים",
-    "Only %s is available." : "רק %s זמין."
+    "Only %s is available." : "רק %s זמין.",
+    "Please log in before granting %1$s access to your %2$s account." : "נא להיכנס בטרם הענקת גישה לחשבון שלך ב־%2$s לטובת %1$s.",
+    "You are about to grant %1$s access to your %2$s account." : "פעולה זו תעניק ל־%1$s גישה לחשבון ה־%2$s שלך."
 },
 "nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
