@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "Nežinomas failo tipas",
     "An error occurred. Please contact your admin." : "Įvyko klaida. Susisiekite su savo administratoriumi.",
     "Invalid image" : "Netinkamas paveikslas",
-    "No temporary profile picture available, try again" : "Nėra laikinojo profilio paveikslėlio, bandykite dar kartą",
-    "No crop data provided" : "Nenurodyti apkirpimo duomenys",
-    "No valid crop data provided" : "Pateikti neteisingi apkirpimo duomenys",
-    "Crop is not square" : "Apkirpimo plotas nėra kvadratas",
     "State token does not match" : "Išorinės sistemos leidimai nesutampa su turimais.",
     "Invalid app password" : "Neteisingas programėlės slaptažodis",
     "Could not complete login" : "Nepavyko užbaigti prisijungimo",
@@ -44,14 +40,14 @@ OC.L10N.register(
     "Image not found" : "Paveikslėlis nerastas",
     "Could not detect language" : "Nepavyko aptikti kalbos",
     "Unable to translate" : "Nepavyko išversti",
-    "Nextcloud Server" : "Nextcloud serveris",
-    "Learn more ↗" : "Sužinokite daugiau ↗",
-    "Preparing update" : "Ruošiamas atnaujinimas",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Pataisymo žingsnis:",
     "Repair info:" : "Pataisymo informacija:",
     "Repair warning:" : "Taisymo įspėjimas:",
     "Repair error:" : "Taisymo klaida:",
+    "Nextcloud Server" : "Nextcloud serveris",
+    "Learn more ↗" : "Sužinokite daugiau ↗",
+    "Preparing update" : "Ruošiamas atnaujinimas",
     "Turned on maintenance mode" : "Įjungta techninės priežiūros veiksena",
     "Turned off maintenance mode" : "Išjungta techninės priežiūros veiksena",
     "Maintenance mode is kept active" : "Techninės priežiūros veiksena yra aktyvi",
@@ -67,16 +63,8 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (nesuderinama)",
     "The following apps have been disabled: %s" : "Šios programėlės buvo išjungtos: %s",
     "Already up to date" : "Naudojama naujausia versija",
-    "Error occurred while checking server setup" : "Tikrinant serverio sąranką, įvyko klaida",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Išsamesnei informacijai, žiūrėkite {linkstart}dokumentaciją ↗{linkend}.",
-    "unknown text" : "nežinomas tekstas",
-    "Hello world!" : "Sveikas, pasauli!",
-    "sunny" : "saulėta",
-    "Hello {name}, the weather is {weather}" : "Sveiki {name}, šiandien yra {weather}",
-    "Hello {name}" : "Sveiki, {name},",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Paieškos rezultatai:<script>alert(1)</script></strong>",
-    "new" : "naujas",
-    "_download %n file_::_download %n files_" : ["atsisiųsti %n failą","atsisiųsti %n failus","atsisiųsti %n failų","atsisiųsti %n failą"],
+    "Unknown" : "Nežinoma",
+    "PNG image" : "PNG paveikslas",
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Vykdomas atnaujinimas, palikus šį puslapį atvertą, kai kuriose aplinkose šis procesas gali būti nutrauktas.",
     "Update to {version}" : "Atnaujinti į versiją {version}",
     "An error occurred." : "Įvyko klaida.",
@@ -85,18 +73,18 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Atnaujinimas buvo nesėkmingas. Prašome pranešti apie šią problemą <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud bendruomenei</a>.",
     "Continue to {productName}" : "Tęsti {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Atnaujinimas sėkmingas. Nukreipiama į  {productName} per %n sek.","Atnaujinimas sėkmingas. Nukreipiama į {productName} per %n sek.","Atnaujinimas sėkmingas. Nukreipiama į  {productName} per %n seconds.","Atnaujinimas sėkmingas. Nukreipiama į {productName} per %n sekundes."],
+    "Done" : "Atlikta",
     "Applications menu" : "Programų meniu",
     "Apps" : "Programėlės",
     "More apps" : "Daugiau programėlių",
     "_{count} notification_::_{count} notifications_" : ["{count} pranešimas","{count} pranešimai","{count} pranešimų","{count} pranešimas"],
     "No" : "Ne",
     "Yes" : "Taip",
+    "Grant access" : "Suteikti prieigą",
     "Failed to add the public link to your Nextcloud" : "Nepavyko pridėti viešosios nuorodos į jūsų Nextcloud",
     "Create share" : "Sukurti viešinį",
-    "Direct link copied to clipboard" : "Tiesioginė nuoroda nukopijuota į iškarpinę",
     "Please copy the link manually:" : "Nukopijuokite nuorodą rankiniu būdu:",
     "Clear search" : "Išvalyti paiešką",
-    "Searching …" : "Ieškoma…",
     "Start typing to search" : "Rašykite norėdami atlikti paiešką",
     "Today" : "Šiandien",
     "Last 7 days" : "Paskutinės 7 dienos",
@@ -106,11 +94,9 @@ OC.L10N.register(
     "Results" : "Rezultatai",
     "Load more results" : "Įkelti daugiau rezultatų",
     "Log in" : "Prisijungti",
-    "Logging in …" : "Prisijungiama …",
     "Log in to {productName}" : "Prisijunkite prie {productName}",
     "Wrong login or password." : "Neteisingas prisijungimas ar slaptažodis.",
     "This account is disabled" : "Ši paskyra yra išjungta",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Dėl daugkartinių nesėkmingų bandymų prisijungti iš jūsų IP adreso, prisijungimai bus uždelsti iki 30 sekundžių.",
     "Account name or email" : "Paskyros vardas ar el. paštas",
     "Account name" : "Paskyros pavadinimas",
     "Server side authentication failed!" : "Autentikacija serveryje nepavyko!",
@@ -118,6 +104,7 @@ OC.L10N.register(
     "An internal error occurred." : "Įvyko vidinė klaida.",
     "Please try again or contact your administrator." : "Pabandykite dar kartą arba susisiekite su savo administratoriumi.",
     "Password" : "Slaptažodis",
+    "Remember me" : "Prisiminti mane",
     "Log in with a device" : "Prisijungti naudojant įrenginį",
     "Login or email" : "Prisijungimas ar el. paštas",
     "Your account is not setup for passwordless login." : "Jūsų paskyra nėra nustatyta prisijungimui be slaptažodžio.",
@@ -134,19 +121,20 @@ OC.L10N.register(
     "Keep your colleagues and friends in one place without leaking their private info." : "Saugokite savo kolegas bei draugus vienoje vietoje, neatskleisdami jų asmeninės informacjios.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Paprasta el. pašto programėlė, tvarkingai integruota su failais, adresatais ir kalendoriumi.",
     "Recommended apps" : "Rekomenduojamos programėlės",
-    "Loading apps …" : "Įkeliamos programėlės…",
     "App download or installation failed" : "Programėlės atsisiuntimas ar įdiegimas patyrė nesėkmę",
     "Cannot install this app because it is not compatible" : "Nepavyksta įdiegti šios programėlės, nes ji yra nesuderinama",
     "Cannot install this app" : "Nepavyksta įdiegti šios programėlės",
     "Skip" : "Praleisti",
-    "Installing apps …" : "Įdiegiamos programėlės…",
     "Install recommended apps" : "Įdiegti rekomenduojamas programėles",
+    "Away" : "Atsitraukęs",
+    "Busy" : "Užimtas laikas",
+    "Do not disturb" : "Netrukdyti",
+    "Mute all notifications" : "Išjungti visus pranešimus",
+    "Invisible" : "Nematomas",
+    "Appear offline" : "Atrodyti atsijungusiu",
     "Settings menu" : "Nustatymų meniu",
-    "Loading your contacts …" : "Įkeliami jūsų adresatai…",
-    "Looking for {term} …" : "Ieškoma {term} ...",
     "Search contacts" : "Ieškoti adresatų",
     "Reset search" : "Atstatyti paiešką",
-    "Search contacts …" : "Ieškoti adresatų…",
     "Could not load your contacts" : "Nepavyko įkelti jūsų adresatų",
     "No contacts found" : "Adresatų nerasta",
     "Show all contacts" : "Rodyti visus adresatus",
@@ -156,11 +144,16 @@ OC.L10N.register(
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių","Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių","Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių","Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių"],
     "An error occurred while searching for {type}" : "Ieškant {type}, įvyko klaida",
     "Search for {name} only" : "Ieškoti tik {name}",
-    "Loading more results …" : "Įkeliama daugiau rezultatų…",
     "Forgot password?" : "Pamiršote slaptažodį?",
     "Back" : "Atgal",
-    "More actions" : "Daugiau veiksmų",
+    "Connect to your account" : "Prisijunkite prie paskyros",
     "Security warning" : "Saugumo įspėjimas",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Jeigu nebandote nusistatyti naujo įrenginio ar programėlės, tuomet kažkas bando jus apgauti, kad suteiktumėte jam prieigą prie savo duomenų. Tokiu atveju netęskite ir, vietoj to, susisiekite su savo sistemos administratoriumi.",
+    "Account connected" : "Paskyra prijungta",
+    "Your client should now be connected!" : "Dabar, jūsų kliento programa turėtų būti prijungta!",
+    "You can close this window." : "Galite užverti šį langą.",
+    "Account access" : "Paskyros prieiga",
+    "More actions" : "Daugiau veiksmų",
     "Storage & database" : "Saugykla ir duomenų bazė",
     "Data folder" : "Duomenų aplankas",
     "Install and activate additional PHP modules to choose other database types." : "Įdiekite ir aktyvuokite papildomus PHP modulius, kad pasirinktumėte kitus duomenų bazės tipus.",
@@ -174,7 +167,6 @@ OC.L10N.register(
     "Database name" : "Duomenų bazės pavadinimas",
     "Database tablespace" : "Duomenų bazės loginis saugojimas",
     "Database host" : "Duomenų bazės serveris",
-    "Installing …" : "Įdiegiama…",
     "Install" : "Įdiegti",
     "Need help?" : "Reikia pagalbos?",
     "See the documentation" : "Žiūrėkite dokumentaciją",
@@ -182,7 +174,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Jūsų naršyklė yra nepalaikoma. Atnaujinkite į naujesnę versiją arba naudokite palaikomą naršyklę.",
     "Continue with this unsupported browser" : "Tęsti naudojant šią nepalaikomą naršyklę",
     "Supported versions" : "Palaikomos versijos",
-    "Search {types} …" : "Ieškoti {types}…",
+    "Choose {file}" : "Pasirinkti{file}",
     "Choose" : "Pasirinkti",
     "Copy to {target}" : "Kopijuoti į {target}",
     "Copy" : "Kopijuoti",
@@ -201,7 +193,10 @@ OC.L10N.register(
     "(all selected)" : "(visi pažymėti)",
     "({count} selected)" : "({count} pažymėtų)",
     "Error loading file exists template" : "Klaida įkeliant saugykloje esančių rinkmenų ruošinį",
-    "Saving …" : "Įrašoma…",
+    "Saving …" : "Įrašoma…",
+    "Groups" : "Grupės",
+    "Group list is empty" : "Grupės sąrašas yra tuščias",
+    "Unable to retrieve the group list" : "Nepavyko nuskaityti grupių sąrašo",
     "seconds ago" : "prieš keletą sekundžių",
     "Connection to server lost" : "Ryšys su serveriu nutrūko",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundės","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundžių","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundžių","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundės"],
@@ -216,22 +211,13 @@ OC.L10N.register(
     "Type to search for existing projects" : "Rašykite norėdami ieškoti esamų projektų",
     "New in" : "Nauja",
     "View changelog" : "Rodyti keitinių žurnalą",
-    "No action available" : "Jokie veiksmai negalimi",
-    "Error fetching contact actions" : "Klaida gaunant veiksmus darbui su adresatais",
-    "Non-existing tag #{tag}" : "Neegzistuojanti žymė #{tag}",
-    "Restricted" : "Apribota",
-    "Invisible" : "Nematomas",
-    "Delete" : "Ištrinti",
-    "Rename" : "Pervadinti",
-    "Collaborative tags" : "Bendradarbiavimo žymės",
-    "No tags found" : "Nerasta jokių žymių",
     "Personal" : "Asmeniniai",
     "Accounts" : "Paskyros",
     "Admin" : "Administravimas",
     "Help" : "Pagalba",
     "Access forbidden" : "Prieiga uždrausta",
-    "Page not found" : "Puslapis nerastas",
     "Back to %s" : "Atgal į %s",
+    "Page not found" : "Puslapis nerastas",
     "Too many requests" : "Per daug užklausų",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Iš jūsų tinklo buvo per daug užklausų. Bandykite dar kartą vėliau arba, jeigu tai klaida, susisiekite su savo administratoriumi.",
     "Error" : "Klaida",
@@ -255,16 +241,6 @@ OC.L10N.register(
     "Skip to navigation of app" : "Pereiti į programėlės naršymą",
     "Go to %s" : "Pereiti į %s",
     "Get your own free account" : "Gaukite nemokamą asmeninę paskyrą",
-    "Connect to your account" : "Prisijunkite prie paskyros",
-    "Please log in before granting %1$s access to your %2$s account." : "Prieš suteikdami %1$s prieigą prie savo %2$s paskyros, prisijunkite.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Jeigu nebandote nusistatyti naujo įrenginio ar programėlės, tuomet kažkas bando jus apgauti, kad suteiktumėte jam prieigą prie savo duomenų. Tokiu atveju netęskite ir, vietoj to, susisiekite su savo sistemos administratoriumi.",
-    "Grant access" : "Suteikti prieigą",
-    "Account access" : "Paskyros prieiga",
-    "Currently logged in as %1$s (%2$s)." : "Šiuo metu prisijungta kaip %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Ketinate suteikti %1$s prieigą prie savo %2$s paskyros.",
-    "Account connected" : "Paskyra prijungta",
-    "Your client should now be connected!" : "Dabar, jūsų kliento programa turėtų būti prijungta!",
-    "You can close this window." : "Galite užverti šį langą.",
     "Previous" : "Ankstesnis",
     "This share is password-protected" : "Šis viešinys yra apsaugotas slaptažodžiu",
     "Email address" : "El. pašto adresas",
@@ -297,24 +273,51 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Šis %s egzempliorius šiuo metu yra techninės priežiūros veiksenoje, kas savo ruožtu gali šiek tiek užtrukti.",
     "This page will refresh itself when the instance is available again." : "Šis puslapis bus įkeltas iš naujo, kai egzempliorius bus ir vėl prieinamas.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Susisiekite su savo sistemos administratoriumi, jei šis pranešimas nedingsta arba, jei jis pasirodė netikėtai.",
-    "You have not added any info yet" : "Jūs kol kas nesate pridėję jokios informacijos",
-    "{user} has not added any info yet" : "Naudotojas {user} kol kas nėra pridėjęs jokios informacijos",
-    "Edit Profile" : "Taisyti profilį",
-    "The headline and about sections will show up here" : "Čia bus rodoma santrauka apie jus bei kita su jumis susijusi informacija",
-    "Error loading message template: {error}" : "Klaida įkeliant žinutės ruošinį: {error}",
+    "Error occurred while checking server setup" : "Tikrinant serverio sąranką, įvyko klaida",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Išsamesnei informacijai, žiūrėkite {linkstart}dokumentaciją ↗{linkend}.",
+    "unknown text" : "nežinomas tekstas",
+    "Hello world!" : "Sveikas, pasauli!",
+    "sunny" : "saulėta",
+    "Hello {name}, the weather is {weather}" : "Sveiki {name}, šiandien yra {weather}",
+    "Hello {name}" : "Sveiki, {name},",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Paieškos rezultatai:<script>alert(1)</script></strong>",
+    "new" : "naujas",
+    "_download %n file_::_download %n files_" : ["atsisiųsti %n failą","atsisiųsti %n failus","atsisiųsti %n failų","atsisiųsti %n failą"],
+    "Direct link copied to clipboard" : "Tiesioginė nuoroda nukopijuota į iškarpinę",
+    "Searching …" : "Ieškoma…",
+    "Logging in …" : "Prisijungiama …",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Dėl daugkartinių nesėkmingų bandymų prisijungti iš jūsų IP adreso, prisijungimai bus uždelsti iki 30 sekundžių.",
+    "Loading apps …" : "Įkeliamos programėlės…",
+    "Installing apps …" : "Įdiegiamos programėlės…",
+    "Loading your contacts …" : "Įkeliami jūsų adresatai…",
+    "Looking for {term} …" : "Ieškoma {term} ...",
+    "Search contacts …" : "Ieškoti adresatų…",
+    "Loading more results …" : "Įkeliama daugiau rezultatų…",
+    "Search {types} …" : "Ieškoti {types}…",
+    "Saving …" : "Įrašoma…",
     "Very weak password" : "Labai silpnas slaptažodis",
     "Weak password" : "Silpnas slaptažodis",
     "So-so password" : "Neblogas slaptažodis",
     "Good password" : "Geras slaptažodis",
     "Strong password" : "Stiprus slaptažodis",
-    "Profile not found" : "Profilis nerastas",
-    "The profile does not exist." : "Profilio nėra.",
+    "No action available" : "Jokie veiksmai negalimi",
+    "Error fetching contact actions" : "Klaida gaunant veiksmus darbui su adresatais",
+    "Non-existing tag #{tag}" : "Neegzistuojanti žyma #{tag}",
+    "Restricted" : "Apribota",
+    "Delete" : "Ištrinti",
+    "Rename" : "Pervadinti",
+    "Collaborative tags" : "Bendradarbiavimo žymos",
+    "No tags found" : "Nerasta jokių žymų",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Jūsų duomenų katalogas ir failai, tikriausiai, yra prieinami per internetą, nes .htaccess failas neveikia.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Išsamesnei informacijai apie tai kaip tinkamai sukonfigūruoti savo serverį, žiūrėkite <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaciją</a>.",
     "Show password" : "Rodyti slaptažodį",
     "Toggle password visibility" : "Perjungti slaptažodžio matomumą",
     "Configure the database" : "Konfigūruokite duomenų bazę",
     "Only %s is available." : "Yra prieinama tik %s.",
-    "Database account" : "Duomenų bazės paskyra"
+    "Database account" : "Duomenų bazės paskyra",
+    "Installing …" : "Įdiegiama…",
+    "Please log in before granting %1$s access to your %2$s account." : "Prieš suteikdami %1$s prieigą prie savo %2$s paskyros, prisijunkite.",
+    "Currently logged in as %1$s (%2$s)." : "Šiuo metu prisijungta kaip %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Ketinate suteikti %1$s prieigą prie savo %2$s paskyros."
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
