@@ -42,6 +42,7 @@ OC.L10N.register(
     "Not found" : "Не найдено",
     "Node is locked" : "Узел заблокирован",
     "Bad request" : "Неверный запрос",
+    "Input text is too long" : "Введённый текст слишком длинный",
     "Requested task type does not exist" : "Запрошенный тип задачи не существует",
     "Necessary language model provider is not available" : "Необходимый поставщик языковой модели недоступен",
     "No text to image provider is available" : "Поставщик преобразования текста в изображение недоступен",
@@ -49,6 +50,7 @@ OC.L10N.register(
     "No translation provider available" : "Поставщик услуг перевода недоступен",
     "Could not detect language" : "Не удалось определить язык",
     "Unable to translate" : "Не удается перевести",
+    "No valid filters provided" : "Нет подходящих фильтров",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Шаг восстановления:",
     "Repair info:" : "Информация восстановления:",
@@ -204,12 +206,15 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Обновление не удалось. Сообщите об этой проблеме <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">сообществу Nextcloud</a>.",
     "Continue to {productName}" : "Перейти к {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Обновление выполнено успешно. Перенаправление в {productName} через %n секунду.","Обновление выполнено успешно. Перенаправление в {productName} через %n секунды.","Обновление выполнено успешно. Перенаправление в {productName} через %n секунд.","Обновление выполнено успешно. Перенаправление в {productName} через %n секунд."],
+    "Done" : "Выполненные",
     "Applications menu" : "Меню приложений",
     "Apps" : "Приложения",
     "More apps" : "Ещё приложения",
     "_{count} notification_::_{count} notifications_" : ["{count} уведомление","{count} уведомлений","{count} уведомлений","{count} уведомлений"],
     "No" : "Нет",
     "Yes" : "Да",
+    "App password" : "Пароль приложения",
+    "Grant access" : "Разрешить доступ",
     "The remote URL must include the user." : "Удаленный URL-адрес должен содержать имя пользователя.",
     "Invalid remote URL." : "Неверный удаленный URL-адрес.",
     "Failed to add the public link to your Nextcloud" : "Не удалось создать общедоступную ссылку",
@@ -225,7 +230,9 @@ OC.L10N.register(
     "Search in current app" : "Поиск в текущем приложении",
     "Clear search" : "Очистить поиск",
     "Search everywhere" : "Искать везде",
+    "Searching …" : "Поиск …",
     "Start typing to search" : "Начните вводить символы для поиска",
+    "Minimum search length is {minSearchLength} characters" : "Минимальная длина поиска - {minSearchLength} символов",
     "No matching results" : "Нет совпадающих результатов",
     "Today" : "Сегодня",
     "Last 7 days" : "Последние 7 дней",
@@ -245,10 +252,10 @@ OC.L10N.register(
     "Load more results" : "Загрузить дополнительные результаты",
     "Search in" : "Искать в",
     "Log in" : "Войти",
+    "Logging in …" : "Вход в систему …",
     "Log in to {productName}" : "Вход в {productName}",
     "Wrong login or password." : "Неверное имя пользователя или пароль.",
     "This account is disabled" : "Эта учётная запись отключена",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "С вашего IP-адреса было выполнено множество неудачных попыток входа в систему. Следующую попытку можно будет выполнить через 30 секунд.",
     "Account name or email" : "Учётная запись или адрес эл. почты",
     "Account name" : "Имя учётной записи",
     "Server side authentication failed!" : "Ошибка аутентификации на стороне сервера!",
@@ -258,6 +265,7 @@ OC.L10N.register(
     "An internal error occurred." : "Произошла внутренняя ошибка.",
     "Please try again or contact your administrator." : "Попробуйте ещё раз или свяжитесь со своим администратором",
     "Password" : "Пароль",
+    "Remember me" : "Запомнить меня",
     "Log in with a device" : "Войти с устройства",
     "Login or email" : "Имя пользователя или адрес эл. почты",
     "Your account is not setup for passwordless login." : "Ваша учётная запись не настроена на вход без пароля.",
@@ -281,16 +289,28 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Совместная работа с документами, таблицами и презентациями, основанная на Collabora Online.",
     "Distraction free note taking app." : "Простые приложение для ведения заметок.",
     "Recommended apps" : "Рекомендованные приложения",
+    "Loading apps …" : "Загрузка приложений …",
     "Could not fetch list of apps from the App Store." : "Не удалось получить список приложений.",
     "App download or installation failed" : "Не удалось скачать или установить приложение",
     "Cannot install this app because it is not compatible" : "Приложение не может быть установлено, так как оно несовместимо",
     "Cannot install this app" : "Это приложение не может быть установлено",
     "Skip" : "Пропустить",
+    "Installing apps …" : "Установка приложений …",
     "Install recommended apps" : "Установить рекомендуемые приложения",
+    "Online" : "В сети",
+    "Away" : "Неактивен",
+    "Busy" : "Занят",
+    "Do not disturb" : "Не беспокоить",
+    "Mute all notifications" : "Без уведомлений",
+    "Invisible" : "Невидимый",
+    "Appear offline" : "\"Не в сети\" для остальных",
     "Avatar of {displayName}" : "Изображение профиля {displayName}",
     "Settings menu" : "Меню настроек",
+    "Loading your contacts …" : "Загрузка контактов …",
+    "Looking for {term} …" : "Поиск {term} …",
     "Search contacts" : "Поиск контактов",
     "Reset search" : "Очистить поиск",
+    "Search contacts …" : "Поиск контактов …",
     "Could not load your contacts" : "Ошибка получения контактов",
     "No contacts found" : "Контактов не найдено",
     "Show all contacts" : "Показать все контакты",
@@ -302,11 +322,20 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Произошла ошибка при поиске {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Поиск начнётся при наборе текста. Для перехода к результатам поиска используйте клавиши со стрелками.",
     "Search for {name} only" : "Искать только для «{name}»",
+    "Loading more results …" : "Загрузка дополнительных результатов …",
     "Forgot password?" : "Забыли пароль?",
     "Back to login form" : "Вернуться к форме входа",
     "Back" : "Назад",
     "Login form is disabled." : "Форма входа отключена.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Диалог входа отключен. Используйте другой способ входа или свяжитесь с администратором.",
+    "Connect to your account" : "Вход в систему",
+    "Security warning" : "Предупреждение безопасности",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Если вы не пытались настроить новое устройство или приложение, значит, кто-то пытается получить доступ к вашим данным. В этом случае свяжитесь с администратором системы.",
+    "Alternative log in using app password" : "Другой способ входа с использованием пароля приложения",
+    "Account connected" : "Аккаунт подключен",
+    "Your client should now be connected!" : "Приложение-клиент подключено.",
+    "You can close this window." : "Можете закрыть это окно.",
+    "Account access" : "Доступ к аккаунту",
     "More actions" : "Больше действий",
     "User menu" : "Меню пользователя",
     "Your guest name: {user}" : "Ваше гостевое имя: {user}",
@@ -324,13 +353,13 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Информацию о том, как правильно настроить сервер,{linkStart} смотрите в документации.{linkEnd}",
     "Autoconfig file detected" : "Обнаружен файл автоконфигурации",
     "The setup form below is pre-filled with the values from the config file." : "Форма настройки ниже, предварительно заполнена значениями из файла конфигурации.",
-    "Security warning" : "Предупреждение безопасности",
     "Create administration account" : "Создать учетную запись администратора",
     "Administration account name" : "Имя учетной записи администратора",
     "Administration account password" : "Пароль учетной записи администратора",
     "Storage & database" : "Хранилище и база данных",
     "Data folder" : "Каталог с данными",
     "Database configuration" : "Конфигурация базы данных",
+    "Database type" : "Тип базы данных",
     "Only {firstAndOnlyDatabase} is available." : "Только {firstAndOnlyDatabase} доступно.",
     "Install and activate additional PHP modules to choose other database types." : "Установите и активируйте дополнительные модули PHP для возможности выбора других типов баз данных.",
     "For more details check out the documentation." : "За дополнительными сведениями обратитесь к документации.",
@@ -338,6 +367,7 @@ OC.L10N.register(
     "You chose SQLite as database." : "Вы выбрали SQLite в качестве базы данных.",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite следует использовать только для минимальных и разрабатываемых экземпляров. Для производства мы рекомендуем другую базу данных.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Настоятельно не рекомендуется использовать механизм баз данных SQLite при использовании синхронизации файлов с использованием приложений-клиентов.",
+    "Database connection" : "Соединение с базой данных",
     "Database user" : "Пользователь базы данных",
     "Database password" : "Пароль базы данных",
     "Database name" : "Имя базы данных",
@@ -345,6 +375,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Пожалуйста укажите номер порта вместе с именем хоста (напр. localhost:5432)",
     "Database host" : "Хост базы данных",
     "localhost" : "локальный хост",
+    "Installing …" : "Установка …",
     "Install" : "Установить",
     "Need help?" : "Требуется помощь?",
     "See the documentation" : "Посмотреть документацию",
@@ -353,6 +384,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Используемый браузер не поддерживается. Обновитесь до более новой версии или используйте другой браузер.",
     "Continue with this unsupported browser" : "Продолжить с использованием неподдерживаемого браузера",
     "Supported versions" : "Поддерживаемые версии",
+    "Search {types} …" : "Поиск {types} …",
     "Choose {file}" : "Выбран «{file}»",
     "Choose" : "Выбрать",
     "Copy to {target}" : "Скопировать в {target}",
@@ -373,6 +405,9 @@ OC.L10N.register(
     "({count} selected)" : "(выбрано: {count})",
     "Error loading file exists template" : "Ошибка при загрузке шаблона существующего файла",
     "Saving …" : "Сохранение…",
+    "Groups" : "Группы",
+    "Group list is empty" : "Список групп пуст",
+    "Unable to retrieve the group list" : "Не удалось получить список групп",
     "seconds ago" : "только что",
     "Connection to server lost" : "Потеряно подключение к серверу",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Возникла проблема при загрузке страницы, повторная попытка через %n секунду","Возникла проблема при загрузке страницы, повторная попытка через %n секунды","Возникла проблема при загрузке страницы, повторная попытка через %n секунд","Возникла проблема при загрузке страницы, повторная попытка через %n секунд"],
@@ -423,18 +458,6 @@ OC.L10N.register(
     "Skip to navigation of app" : "Перейти к навигации по приложению",
     "Go to %s" : "Перейти к %s",
     "Get your own free account" : "Создайте свою бесплатную учётную запись",
-    "Connect to your account" : "Вход в систему",
-    "Please log in before granting %1$s access to your %2$s account." : "Для предоставления %1$s доступа к учётной записи %2$s необходимо войти в систему.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Если вы не пытались настроить новое устройство или приложение, значит, кто-то пытается получить доступ к вашим данным. В этом случае свяжитесь с администратором системы.",
-    "App password" : "Пароль приложения",
-    "Grant access" : "Разрешить доступ",
-    "Alternative log in using app password" : "Другой способ входа с использованием пароля приложения",
-    "Account access" : "Доступ к аккаунту",
-    "Currently logged in as %1$s (%2$s)." : "Вход в систему выполнен под именем %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Вы собираетесь разрешить приложению %1$s доступ к своей учётной записи %2$s.",
-    "Account connected" : "Аккаунт подключен",
-    "Your client should now be connected!" : "Приложение-клиент подключено.",
-    "You can close this window." : "Можете закрыть это окно.",
     "Previous" : "Предыдущий",
     "This share is password-protected" : "Доступ к этому ресурсу защищён паролем",
     "The password is wrong or expired. Please try again or request a new one." : "Введённый пароль неверен или срок его действия истёк. Попробуйте снова ввести его или запросите новый пароль.",
@@ -487,6 +510,7 @@ OC.L10N.register(
     "Direct link copied to clipboard" : "Прямая ссылка, скопированная в буфер обмена",
     "Searching …" : "Поиск…",
     "Logging in …" : "Вход в систему…",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "С вашего IP-адреса было выполнено множество неудачных попыток входа в систему. Следующую попытку можно будет выполнить через 30 секунд.",
     "Loading apps …" : "Получение списка приложений…",
     "Installing apps …" : "Установка приложений…",
     "Loading your contacts …" : "Загрузка контактов…",
@@ -504,7 +528,6 @@ OC.L10N.register(
     "Error fetching contact actions" : "Ошибка получения действий контакта",
     "Non-existing tag #{tag}" : "Несуществующая метка #{tag}",
     "Restricted" : "Ограниченный",
-    "Invisible" : "Невидимый",
     "Delete" : "Удалить",
     "Rename" : "Переименовать",
     "Collaborative tags" : "Совместные теги",
@@ -519,6 +542,9 @@ OC.L10N.register(
     "Configure the database" : "Настройка базы данных",
     "Only %s is available." : "Доступен только %s.",
     "Database account" : "Учётная запись базы данных",
-    "Installing …" : "Установка ..."
+    "Installing …" : "Установка ...",
+    "Please log in before granting %1$s access to your %2$s account." : "Для предоставления %1$s доступа к учётной записи %2$s необходимо войти в систему.",
+    "Currently logged in as %1$s (%2$s)." : "Вход в систему выполнен под именем %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Вы собираетесь разрешить приложению %1$s доступ к своей учётной записи %2$s."
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
