@@ -42,6 +42,7 @@ OC.L10N.register(
     "Not found" : "Nenájdené",
     "Node is locked" : "Uzol je uzamknutý",
     "Bad request" : "Neplatná požiadavka",
+    "Input text is too long" : "Vstupný text je príliš dlhý.",
     "Requested task type does not exist" : "Vyžiadaný typ úlohy neexistuje",
     "Necessary language model provider is not available" : "Potrebný poskytovateľ jazykového modelu nie je dostupný",
     "No text to image provider is available" : "Nie je dostupný žiadny poskytovateľ služby \"text na obrázok\"",
@@ -49,6 +50,7 @@ OC.L10N.register(
     "No translation provider available" : "Nie je dostupný žiadny poskytovateľ prekladu",
     "Could not detect language" : "Nepodarilo sa zistiť jazyk",
     "Unable to translate" : "Nie je možné preložiť",
+    "No valid filters provided" : "Žiadne platné filtre poskytnuté",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Krok opravy:",
     "Repair info:" : "Informácie o oprave:",
@@ -77,8 +79,10 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (nekompatibilná)",
     "The following apps have been disabled: %s" : "Nasledujúce aplikácie boli vypnuté: %s",
     "Already up to date" : "Už aktuálne",
+    "Windows Command Script" : "Skript príkazov Windows",
     "Electronic book document" : "Dokument elektronickej knihy",
     "TrueType Font Collection" : "Kolekcia fontov TrueType",
+    "Web Open Font Format" : "Web Open Font Format",
     "GPX geographic data" : "GPX geografické dáta",
     "Gzip archive" : "Gzip archív",
     "Adobe Illustrator document" : "Dokument Adobe Illustrator",
@@ -152,6 +156,48 @@ OC.L10N.register(
     "WebM audio" : "WebM audio",
     "MP3 ShoutCast playlist" : "MP3 ShoutCast playlist",
     "Windows BMP image" : "Obrázok Windows BMP",
+    "Better Portable Graphics image" : "Lepší prenosný grafický obrázok",
+    "EMF image" : "EMF obrázok",
+    "GIF image" : "GIF obrázok",
+    "HEIC image" : "HEIC obrázok",
+    "HEIF image" : "HEIF obrázok",
+    "JPEG-2000 JP2 image" : "JPEG-2000 JP2 obrázok",
+    "JPEG image" : "JPEG obrázok",
+    "PNG image" : "PNG obrázok",
+    "SVG image" : "SVG obrázok",
+    "Truevision Targa image" : "Truevision Targa obrázok",
+    "TIFF image" : "TIFF obrázok",
+    "WebP image" : "WebP obrázok",
+    "Digital raw image" : "Digital raw obrázok",
+    "Windows Icon" : "Windows ikona",
+    "Email message" : "E-mailová správa",
+    "VCS/ICS calendar" : "VCS/ICS kalendár",
+    "CSS stylesheet" : "CSS štýlový list",
+    "CSV document" : "CSV dokument",
+    "HTML document" : "HTML dokument",
+    "Markdown document" : "Markdown dokument",
+    "Org-mode file" : "Org-mode súbor",
+    "Plain text document" : "Dokument v čistom texte",
+    "Rich Text document" : "Dokument vo formátovanom texte",
+    "Electronic business card" : "Elektronická vizitka",
+    "C++ source code" : "C++ zdrojový kód",
+    "LDIF address book" : "Adresár LDIF",
+    "NFO document" : "NFO dokument",
+    "PHP source" : "PHP zdroj",
+    "Python script" : "Python skript",
+    "ReStructuredText document" : "ReStructuredText dokument",
+    "3GPP multimedia file" : "3GPP multimediálny súbor",
+    "MPEG video" : "MPEG video",
+    "DV video" : "DV video",
+    "MPEG-2 transport stream" : "MPEG-2 transportný tok",
+    "MPEG-4 video" : "MPEG-4 video",
+    "Ogg video" : "Ogg video",
+    "QuickTime video" : "QuickTime video",
+    "WebM video" : "WebM video",
+    "Flash video" : "Flash video",
+    "Matroska video" : "Matroska video",
+    "Windows Media video" : "Windows Media video",
+    "AVI video" : "AVI video",
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Aktualizácie prebieha. V niektorých prostrediach môže opustenie tejto stránky spôsobiť prerušenie aktualizácie.",
     "Update to {version}" : "Aktualizuj na {version}",
     "An error occurred." : "Vyskytla sa chyba.",
@@ -160,18 +206,22 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Aktualizácia bola neúspešná. Oznámte prosím tento problém <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">komunite Nextcloud</a>.",
     "Continue to {productName}" : "Pokračovať na {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Aktualizácia prebehla úspešne. O %n sekundu budete presmerovaní na {productName}.","Aktualizácia prebehla úspešne. O %n sekundy budete presmerovaní na {productName}.","Aktualizácia prebehla úspešne. O %n sekúnd budete presmerovaní na {productName}.","Aktualizácia prebehla úspešne. O %n sekúnd budete presmerovaní na {productName}."],
+    "Done" : "Hotovo",
     "Applications menu" : "Ponuka aplikácií",
     "Apps" : "Aplikácie",
     "More apps" : "Viac aplikácií",
     "_{count} notification_::_{count} notifications_" : ["{count} upozornenie","{count} upozornenia","{count} upozornení","{count} upozornenia"],
     "No" : "Nie",
     "Yes" : "Áno",
+    "App password" : "Heslo aplikácie",
+    "Grant access" : "Povoliť prístup",
     "The remote URL must include the user." : "Vzdialená adresa URL musí zahŕňať užívateľa.",
     "Invalid remote URL." : "Neplatná vzdialená adresa URL.",
     "Failed to add the public link to your Nextcloud" : "Pridanie verejne dostupného odkazu do vášho Nextcloud zlyhalo",
     "Federated user" : "Združený užívateľ",
     "user@your-nextcloud.org" : "user@your-nextcloud.org",
     "Create share" : "Vytvoriť zdieľanie",
+    "Direct link copied" : "Priamy odkaz skopírovaný",
     "Please copy the link manually:" : "Prosím skopírujte odkaz manuálne:",
     "Custom date range" : "Vlastné rozpätie dátumov",
     "Pick start date" : "Vyberte dátum začiatku",
@@ -180,13 +230,16 @@ OC.L10N.register(
     "Search in current app" : "Hľadať v aktuálnej aplikácii",
     "Clear search" : "Vymazať hľadanie",
     "Search everywhere" : "Hľadať všade",
+    "Searching …" : "Vyhľadáva sa …",
     "Start typing to search" : "Začnite písať pre vyhľadanie",
+    "Minimum search length is {minSearchLength} characters" : "Minimálna dĺžka vyhľadávania je {minSearchLength} znakov",
     "No matching results" : "Žiadne zhodujúce výsledky",
     "Today" : "Dnes",
     "Last 7 days" : "Posledných 7 dní",
     "Last 30 days" : "Posledných 30 dní",
     "This year" : "Tento rok",
     "Last year" : "Minulý rok",
+    "Between {startDate} and {endDate}" : "Medzi {startDate} a {endDate}",
     "Unified search" : "Jednotné vyhľadávanie",
     "Search apps, files, tags, messages" : "Hľadať aplikácie, súbory, štítky a správy",
     "Places" : "Miesta",
@@ -194,14 +247,17 @@ OC.L10N.register(
     "Search people" : "Hľadať ľudí",
     "People" : "Ľudia",
     "Filter in current view" : "Filter v aktuálnom zobrazení",
+    "Search connected services" : "Vyhľadávať pripojené služby",
     "Results" : "Výsledky",
     "Load more results" : "Načítať viac výsledkov",
     "Search in" : "Hľadať v",
+    "Partial matches" : "Čiastočné zhody",
     "Log in" : "Prihlásiť sa",
+    "Logging in …" : "Prebieha prihlasovanie …",
     "Log in to {productName}" : "Prihlásiť sa do {productName}u",
     "Wrong login or password." : "Nesprávne meno alebo heslo.",
     "This account is disabled" : "Tento účet je deaktivovaný",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Zaznamenali sme viacnásobné chybné prihlásenie z vašej IP adresy. Vaše nasledujúce prihlásenie bude pozdržané o 30 sekúnd.",
+    "Too many incorrect login attempts. Please try again in 30 seconds." : "Príliš veľa neúspešných pokusov o prihlásenie. Skúste to znova o 30 sekúnd.",
     "Account name or email" : "Názov účtu alebo e-mail",
     "Account name" : "Názov účtu",
     "Server side authentication failed!" : "Autentifikácia na serveri zlyhala!",
@@ -211,6 +267,7 @@ OC.L10N.register(
     "An internal error occurred." : "Došlo k vnútornej chybe.",
     "Please try again or contact your administrator." : "Skúste to znovu, alebo sa obráťte na vášho administrátora.",
     "Password" : "Heslo",
+    "Remember me" : "Zapamätať si ma",
     "Log in with a device" : "Prihlásiť sa pomocou zariadenia",
     "Login or email" : "Prihlasovacie meno alebo email",
     "Your account is not setup for passwordless login." : "Váš účet nie je nastavený pre bezheslové overovanie.",
@@ -234,16 +291,28 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Kolaboratívne dokumenty, tabuľky a prezentácie postavené na Collabora Online.",
     "Distraction free note taking app." : "Aplikácia pre písanie poznámok bez rozptyľovania.",
     "Recommended apps" : "Odporúčané apky",
+    "Loading apps …" : "Načítavanie aplikácií ...",
     "Could not fetch list of apps from the App Store." : "Nepodarilo sa načítať zoznam apiek z Obchodu s aplikáciami.",
     "App download or installation failed" : "Nepodarilo sa prevziať alebo nainštalovať apku",
     "Cannot install this app because it is not compatible" : "Táto apka sa nedá nainštalovať, pretože nie je kompatibilná",
     "Cannot install this app" : "Táto aplikácia sa nedá nainštalovať",
     "Skip" : "Preskočiť",
+    "Installing apps …" : "Inštalácia aplikácií …",
     "Install recommended apps" : "Nainštalovať odporúčané apky",
+    "Online" : "Pripojený",
+    "Away" : "Preč",
+    "Busy" : "Zaneprázdnený",
+    "Do not disturb" : "Nerušiť",
+    "Mute all notifications" : "Stlmiť všetky upozornenia",
+    "Invisible" : "Neviditeľný",
+    "Appear offline" : "Zdá sa byť offline",
     "Avatar of {displayName}" : "Avatar užívateľa {displayName}",
     "Settings menu" : "Menu nastavení",
+    "Loading your contacts …" : "Načítavanie vašich kontaktov...",
+    "Looking for {term} …" : "Hľadá sa {term}...",
     "Search contacts" : "Prehľadať kontakty",
     "Reset search" : "Vynuluj vyhľadávanie",
+    "Search contacts …" : "Prehľadať kontakty ...",
     "Could not load your contacts" : "Nie je možné načítať Vaše kontakty",
     "No contacts found" : "Kontakty nenájdené",
     "Show all contacts" : "Zobraziť všetky kontakty",
@@ -255,12 +324,26 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Počas hľadania {type} sa vyskytla chyba",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Hľadanie sa začína, keď začnete písať a výsledky môžete dosiahnuť pomocou šípiek.",
     "Search for {name} only" : "Hľadať iba {name}",
+    "Loading more results …" : "Načítava sa viac výsledkov …",
     "Forgot password?" : "Zabudli ste heslo?",
     "Back to login form" : "Späť na prihlásenie",
     "Back" : "Späť",
     "Login form is disabled." : "Prihlasovací formulár je vypnutý.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Prihlasovanie do Nextcloud je zakázané. Použite inú možnosť prihlásenia, ak je k dispozícii, alebo kontaktujte svojho administrátora.",
+    "Connect to your account" : "Pripojte sa k svojmu účtu",
+    "Security warning" : "Bezpečnostné varovanie",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Ak sa nesnažíte nastaviť nové zariadenie alebo aplikáciu, niekto sa vás pokúša oklamať, aby ste im poskytli prístup k vašim údajom. V takom prípade nepokračujte a obráťte sa na správcu systému.",
+    "Alternative log in using app password" : "Alternatívne prihlásenie pomocou hesla aplikácie",
+    "Account connected" : "Účet pripojený",
+    "Your client should now be connected!" : "Váš klient by mal byť pripojený!",
+    "You can close this window." : "Toto okno už môžete zatvoriť.",
+    "Account access" : "Prístup k účtu",
     "More actions" : "Viac akcií",
+    "User menu" : "Používateľské menu",
+    "Your guest name: {user}" : "Vaše meno hosťa: {user}",
+    "You are currently not identified." : "Momentálne nie ste identifikovaní.",
+    "Set public name" : "Nastaviť verejné meno",
+    "Change public name" : "Zmeniť verejné meno",
     "Password is too weak" : "Heslo je príliš jednoduché",
     "Password is weak" : "Heslo je jednoduché",
     "Password is average" : "Heslo je priemerné",
@@ -272,13 +355,13 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Pre informácie o tom, ako správne nakonfigurovať server, prosím navštívte {linkStart} dokumentáciu {linkEnd}",
     "Autoconfig file detected" : "Detekovaný súbor automatickej konfigurácie",
     "The setup form below is pre-filled with the values from the config file." : "Inštalačný formulár nižšie je vopred vyplnený hodnotami z konfiguračného súboru.",
-    "Security warning" : "Bezpečnostné varovanie",
     "Create administration account" : "Vytvoriť účet administrátora",
     "Administration account name" : "Názov účtu administrátora",
     "Administration account password" : "Heslo účtu administrátora",
     "Storage & database" : "Úložisko & databáza",
     "Data folder" : "Priečinok dát",
     "Database configuration" : "Konfigurácia Databáze",
+    "Database type" : "Typ databázy",
     "Only {firstAndOnlyDatabase} is available." : "Je dostupná iba {firstAndOnlyDatabase}",
     "Install and activate additional PHP modules to choose other database types." : "Pri výbere iného typu databázy bude potrebné nainštalovať a aktivovať ďalšie PHP moduly.",
     "For more details check out the documentation." : "Viac informácií nájdete v dokumentácii.",
@@ -286,6 +369,7 @@ OC.L10N.register(
     "You chose SQLite as database." : "Ako databázu ste vybrali SQLite.",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite by sa malo používať len pre naozaj maličké alebo vývojové inštancie. Pre produkčné použitie výrazne odporúčame použiť robustnejšiu databázu.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ak používate klientské aplikácie pre synchronizáciu súborov, tak výrazne odporúčame nepoužívať SQLite.",
+    "Database connection" : "Pripojenie k databáze",
     "Database user" : "Používateľ databázy",
     "Database password" : "Heslo databázy",
     "Database name" : "Meno databázy",
@@ -293,6 +377,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Zadajte číslo portu spolu s názvom hostiteľa (napr. localhost:5432).",
     "Database host" : "Server databázy",
     "localhost" : "localhost",
+    "Installing …" : "Inštalujem ...",
     "Install" : "Inštalovať",
     "Need help?" : "Potrebujete pomoc?",
     "See the documentation" : "Pozri dokumentáciu",
@@ -301,6 +386,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Váš prehliadač nie je podporovaný. Inovujte na novšiu alebo podporovanú verziu.",
     "Continue with this unsupported browser" : "Pokračovať s nepodporovaným prehliadačom",
     "Supported versions" : "Podporované verzie",
+    "Search {types} …" : "Vyhľadať {types} ...",
     "Choose {file}" : "Vyberte {file}",
     "Choose" : "Vybrať",
     "Copy to {target}" : "Kopírovať do {target}",
@@ -321,6 +407,9 @@ OC.L10N.register(
     "({count} selected)" : "({count} vybraných)",
     "Error loading file exists template" : "Chyba pri nahrávaní šablóny existencie súboru",
     "Saving …" : "Ukladanie …",
+    "Groups" : "Skupiny",
+    "Group list is empty" : "Zoznam skupín je prázdny",
+    "Unable to retrieve the group list" : "Nie je možné načítať zoznam skupín",
     "seconds ago" : "pred sekundami",
     "Connection to server lost" : "Stratené spojenie so serverom",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Nepodarilo sa načítať stránku, opätovný pokus o %n sekundu","Nepodarilo sa načítať stránku, opätovný pokus o %n sekundy","Nepodarilo sa načítať stránku, opätovný pokus o %n sekúnd","Nepodarilo sa načítať stránku, opätovný pokus o %n sekúnd"],
@@ -343,6 +432,7 @@ OC.L10N.register(
     "Admin" : "Administrácia",
     "Help" : "Pomoc",
     "Access forbidden" : "Prístup odmietnutý",
+    "You are not allowed to access this page." : "Nie je vám povolený prístup na túto stránku.",
     "Back to %s" : "Späť na %s",
     "Page not found" : "Stránka nenájdená",
     "The page could not be found on the server or you may not be allowed to view it." : "Túto stránku sa nepodarilo na serveri nájsť alebo nemáte oprávnenie na jej zobrazenie.",
@@ -370,18 +460,6 @@ OC.L10N.register(
     "Skip to navigation of app" : "Preskočiť do navigácie apky",
     "Go to %s" : "Prejsť na %s",
     "Get your own free account" : "Získajte zdarma svoj vlastný účet",
-    "Connect to your account" : "Pripojte sa k svojmu účtu",
-    "Please log in before granting %1$s access to your %2$s account." : "Skôr než udelíte prístup pre %1$s do vášho účtu %2$s je potrebné sa prihlásiť.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Ak sa nesnažíte nastaviť nové zariadenie alebo aplikáciu, niekto sa vás pokúša oklamať, aby ste im poskytli prístup k vašim údajom. V takom prípade nepokračujte a obráťte sa na správcu systému.",
-    "App password" : "Heslo aplikácie",
-    "Grant access" : "Povoliť prístup",
-    "Alternative log in using app password" : "Alternatívne prihlásenie pomocou hesla aplikácie",
-    "Account access" : "Prístup k účtu",
-    "Currently logged in as %1$s (%2$s)." : "Momentálne ste prihlásený ako %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Chystáte sa udeliť %1$s prístup k svojmu %2$s účtu.",
-    "Account connected" : "Účet pripojený",
-    "Your client should now be connected!" : "Váš klient by mal byť pripojený!",
-    "You can close this window." : "Toto okno už môžete zatvoriť.",
     "Previous" : "Predchádzajúce",
     "This share is password-protected" : "Toto zdieľanie je chránené heslom",
     "The password is wrong or expired. Please try again or request a new one." : "Heslo je nesprávne alebo jeho platnosť vypršala. Skúste to znova alebo požiadajte o nové heslo.",
@@ -434,6 +512,7 @@ OC.L10N.register(
     "Direct link copied to clipboard" : "Priamy odkaz bol skopírovný do schránky",
     "Searching …" : "Hľadá sa…",
     "Logging in …" : "Prihlasujem ...",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Zaznamenali sme viacnásobné chybné prihlásenie z vašej IP adresy. Vaše nasledujúce prihlásenie bude pozdržané o 30 sekúnd.",
     "Loading apps …" : "Načítavanie apiek...",
     "Installing apps …" : "Inštalácia apiek...",
     "Loading your contacts …" : "Načítavam vaše kontakty...",
@@ -451,7 +530,6 @@ OC.L10N.register(
     "Error fetching contact actions" : "Chyba počas získavania akcií kontaktu",
     "Non-existing tag #{tag}" : "Neexistujúci štítok #{tag}",
     "Restricted" : "Obmedzené",
-    "Invisible" : "Neviditeľný",
     "Delete" : "Zmazať",
     "Rename" : "Premenovať",
     "Collaborative tags" : "Štítky pre spoluprácu",
@@ -466,6 +544,9 @@ OC.L10N.register(
     "Configure the database" : "Nastaviť databázu",
     "Only %s is available." : "Je dostupný len %s.",
     "Database account" : "Databázový účet",
-    "Installing …" : "Inštalujem ..."
+    "Installing …" : "Inštalujem ...",
+    "Please log in before granting %1$s access to your %2$s account." : "Skôr než udelíte prístup pre %1$s do vášho účtu %2$s je potrebné sa prihlásiť.",
+    "Currently logged in as %1$s (%2$s)." : "Momentálne ste prihlásený ako %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Chystáte sa udeliť %1$s prístup k svojmu %2$s účtu."
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
