@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "Непознат тип фајла",
     "An error occurred. Please contact your admin." : "Дошло је до грешке. Контактирајте администратора.",
     "Invalid image" : "Неисправна слика",
-    "No temporary profile picture available, try again" : "Нема привремене слике профила. Покушајте поново",
-    "No crop data provided" : "Нема података о опсецању",
-    "No valid crop data provided" : "Нема исправних података о опсецању",
-    "Crop is not square" : "Опсецање није квадратног облика",
     "State token does not match" : "Стање жетона се не слаже",
     "Invalid app password" : "Неисправна апликативна лозинка",
     "Could not complete login" : "Не могу да довршим пријављивање",
@@ -53,6 +49,7 @@ OC.L10N.register(
     "No translation provider available" : "Није доступан ниједан пружалац услуге превода",
     "Could not detect language" : "Не може да се детектује језик",
     "Unable to translate" : "Не може да се преведе",
+    "No valid filters provided" : "Нису наведени важећи филтери",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Корак поправке:",
     "Repair info:" : "Инфо о поправци:",
@@ -200,16 +197,6 @@ OC.L10N.register(
     "Matroska video" : "Matroska видео",
     "Windows Media video" : "Windows Media видео",
     "AVI video" : "AVI видео",
-    "Error occurred while checking server setup" : "Дошло је до грешке при провери поставки сервера",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "За више детаља погледајте {linkstart}документацију ↗{linkend}.",
-    "unknown text" : "непознат текст",
-    "Hello world!" : "Здраво свете!",
-    "sunny" : "сунчано",
-    "Hello {name}, the weather is {weather}" : "Здраво {name}, време је {weather}",
-    "Hello {name}" : "Здраво {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Ово су резултати Ваше претраге<script>alert(1)</script></strong>",
-    "new" : "ново",
-    "_download %n file_::_download %n files_" : ["преузми %n фајл","преузми %n фајла","преузми %n фајлова"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Ажурирање је у току. У неким окружењима, напуштање ове стране може да прекине овај процес.",
     "Update to {version}" : "Ажурирај на {version}",
     "An error occurred." : "Дошло је до грешке.",
@@ -218,18 +205,22 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Ажурирање није успело. Пријавите овај проблем <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Некстклауд заједници</a>.",
     "Continue to {productName}" : "Наставите на {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Ажурирање је било успешно. Преусмеравате се на {productName} за %n секунду.","Ажурирање је било успешно. Преусмеравате се на {productName} за %n секунде.","Ажурирање је било успешно. Преусмеравате се на {productName} за  %n секунди."],
+    "Done" : "Завршено",
     "Applications menu" : "Мени апликација",
     "Apps" : "Апликације",
     "More apps" : "Још апликација",
     "_{count} notification_::_{count} notifications_" : ["{count} обавештење","{count} обавештења","{count} обавештења"],
     "No" : "Не",
     "Yes" : "Да",
+    "App password" : "Лозинка апликације",
+    "Grant access" : "Одобри приступ",
     "The remote URL must include the user." : "Удаљени URL мора да садржи кориника.",
     "Invalid remote URL." : "Неисправан удаљени URL.",
     "Failed to add the public link to your Nextcloud" : "Неуспело додавање јавне везе ка Вашем Некстклауду",
     "Federated user" : "Федерисани корисник",
     "user@your-nextcloud.org" : "korisnik@vas-nextcloud.org",
     "Create share" : "Kreirajte deljenje",
+    "Direct link copied" : "Директни линк је копиран",
     "Please copy the link manually:" : "Молимо вас да ручно корпирате линк:",
     "Custom date range" : "Произвољни опсег датума",
     "Pick start date" : "Изаберите почетни датум",
@@ -238,14 +229,16 @@ OC.L10N.register(
     "Search in current app" : "Претражи у тренутној апликацији",
     "Clear search" : "Обриши претрагу",
     "Search everywhere" : "Претражи свуда",
-    "Searching …" : "Тражим…",
+    "Searching …" : "Тражи се …",
     "Start typing to search" : "Почните да куцате да бисте претраживали",
+    "Minimum search length is {minSearchLength} characters" : "Минимална дужина претраге је {minSearchLength} карактера",
     "No matching results" : "Претрага није дала резултате",
     "Today" : "Данас",
     "Last 7 days" : "Последњих 7 дана",
     "Last 30 days" : "Последњих 30 дана",
     "This year" : "Ове године",
     "Last year" : "Прошле године",
+    "Between {startDate} and {endDate}" : "У периоду од {startDate} до {endDate}",
     "Unified search" : "Обједињена претрага",
     "Search apps, files, tags, messages" : "Претражи апликације, фајлове, ознаке, поруке",
     "Places" : "Места",
@@ -253,15 +246,15 @@ OC.L10N.register(
     "Search people" : "Претрага људи",
     "People" : "Људи",
     "Filter in current view" : "Филтрирај у текућем погледу",
+    "Search connected services" : "Претражи повезане уређаје",
     "Results" : "Резултати",
     "Load more results" : "Учитај још резултата",
     "Search in" : "Претражи у",
     "Log in" : "Пријава",
-    "Logging in …" : "Пријављивање …",
+    "Logging in …" : "Пријављивање …",
     "Log in to {productName}" : "Пријавите се на {productName}",
     "Wrong login or password." : "Погрешно име за пријаву или лозинка",
     "This account is disabled" : "Овај налог је искључен",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Приметили смо више неисправних покушаја пријава са Ваше IP адресе. Следећа пријава ће бити могућа тек за 30 секунди.",
     "Account name or email" : "Име налога или е-адреса",
     "Account name" : "Име рачуна",
     "Server side authentication failed!" : "Потврда идентитета на серверу није успела!",
@@ -294,21 +287,28 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Заједнички документи, табеле и презентације, изграђени на Collabora Online.",
     "Distraction free note taking app." : "Апликација за вођење бележака без ометања.",
     "Recommended apps" : "Препоручене апликације",
-    "Loading apps …" : "Учитавам апликације…",
+    "Loading apps …" : "Учитавају се апликације …",
     "Could not fetch list of apps from the App Store." : "Листа апликација није могла да се преузме са продавнице апликација.",
     "App download or installation failed" : "Скидање или инсталирање апликације није успело",
     "Cannot install this app because it is not compatible" : "Ова апликација не може да се инсталира јер није компатибилна",
     "Cannot install this app" : "Ова апликација не може да се инсталира",
     "Skip" : "Preskoči",
-    "Installing apps …" : "Инсталирам апликације…",
+    "Installing apps …" : "Инсталирају се апликације …",
     "Install recommended apps" : "Инсталирајте препоручене апликације",
+    "Online" : "На мрежи",
+    "Away" : "Одсутан",
+    "Busy" : "Заузет",
+    "Do not disturb" : "Не узнемиравај",
+    "Mute all notifications" : "Искључи сва обавештења",
+    "Invisible" : "Невидљива",
+    "Appear offline" : "Прикажи као ван мреже",
     "Avatar of {displayName}" : "Аватар корисника {displayName}",
     "Settings menu" : "Мени подешавања",
-    "Loading your contacts …" : "Учитавам контакте ...",
-    "Looking for {term} …" : "Тражим {term} …",
+    "Loading your contacts …" : "Учитавају се ваши контакти …",
+    "Looking for {term} …" : "Тражи се {term}  …",
     "Search contacts" : "Претрага контакта",
     "Reset search" : "Ресетуј претрагу",
-    "Search contacts …" : "Претражи контакте ...",
+    "Search contacts …" : "Претрага контаката …",
     "Could not load your contacts" : "Не могу да учитам Ваше контакте",
     "No contacts found" : "Контакти нису нађени",
     "Show all contacts" : "Прикажи све контакте",
@@ -320,15 +320,23 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Десила се грешка приликом тражења за {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Претрага започиње чим почнете да куцате и до резултата долазите курсорским тастерима",
     "Search for {name} only" : "Тражи само за {name}",
-    "Loading more results …" : "Учитавам још резултата…",
+    "Loading more results …" : "Учитава се још резултата …",
     "Forgot password?" : "Заборавили сте лозинку?",
     "Back to login form" : "Назад на формулар за пријаву",
     "Back" : "Назад",
     "Login form is disabled." : "Форма за пријаву је искључена.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud формулар за пријаву је искључен. Ако је доступна, користите неку другу могућност пријаве, или се обратите администрацији.",
+    "Connect to your account" : "Повежите се на Ваш налог",
+    "Security warning" : "Безбедносно упозорење",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Ако не покушавате да подесите нови уређај или апликацију, неко покушава да Вас превари да му дате приступ Вашим подацима. У том случају, не настављајте и контактирајте администратора Вашег система.",
+    "Alternative log in using app password" : "Алтернативна пријава коришћењем лозинк апликације",
+    "Account connected" : "Налог повезан",
+    "Your client should now be connected!" : "Ваш клијент сада треба да је повезан!",
+    "You can close this window." : "Можете затворити овај прозор.",
+    "Account access" : "Приступ налогу",
     "More actions" : "Још акција",
     "User menu" : "Кориснички мени",
-    "You will be identified as {user} by the account owner." : "Власник налога ће вас идентификовати као {user}.",
+    "Your guest name: {user}" : "Ваше име госта: {user}",
     "You are currently not identified." : "Тренутно нисте идентификовани.",
     "Set public name" : "Постави јавно име",
     "Change public name" : "Измени јавно име",
@@ -343,13 +351,13 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "За информације у вези са правилним подешавањем вашег сервера, молимо вас да {linkStart}погледајте документацију{linkEnd}",
     "Autoconfig file detected" : "Откривен је фајл аутоматског подешавања",
     "The setup form below is pre-filled with the values from the config file." : "Формулар подешавања испод је унапред попуњен са вредностима из конфигурационог фајла.",
-    "Security warning" : "Безбедносно упозорење",
     "Create administration account" : "Направи административни налог",
     "Administration account name" : "Име административног налога",
     "Administration account password" : "Лозинка административног налога",
     "Storage & database" : "Складиште и база података",
     "Data folder" : "Фасцикла за податке",
     "Database configuration" : "Конфигурација базе података",
+    "Database type" : "Тип базе података",
     "Only {firstAndOnlyDatabase} is available." : "Доступна је само {firstAndOnlyDatabase}.",
     "Install and activate additional PHP modules to choose other database types." : "Инсталирајте и активирајте додатне „ПХП“ модуле за одабир других база података.",
     "For more details check out the documentation." : "За више детаља погледајте документацију.",
@@ -357,6 +365,7 @@ OC.L10N.register(
     "You chose SQLite as database." : "Одабрали сте SQLite за базу података.",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite треба да се користи само за најмање инстанце или за инстанце за развој. За продукцију, препоручујемо други тип база података.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Коришћење SQLite базе података нарочите није препоручљиво ако користите клијенте за синхронизацију фајлова.",
+    "Database connection" : "Веза са базом података",
     "Database user" : "Корисник базе",
     "Database password" : "Лозинка базе",
     "Database name" : "Назив базе",
@@ -364,7 +373,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Наведите и број порта у имену домаћина (нпр. localhost:5432).",
     "Database host" : "Домаћин базе",
     "localhost" : "локални хост",
-    "Installing …" : "Инсталирам ...",
+    "Installing …" : "Инсталира се …",
     "Install" : "Инсталирај",
     "Need help?" : "Треба вам помоћ?",
     "See the documentation" : "Погледајте документацију",
@@ -373,7 +382,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Ваш веб читач није подржан. Молимо вас да га ажурирате на новију верзију, или да инсталирате подржани читач.",
     "Continue with this unsupported browser" : "Настави са овим неподржаним читачем",
     "Supported versions" : "Подржане верзије",
-    "Search {types} …" : "Претражи {types}…",
+    "Search {types} …" : "Претрага {types} …",
     "Choose {file}" : "Изабери {file}",
     "Choose" : "Изаберите",
     "Copy to {target}" : "Копирај у {target}",
@@ -393,7 +402,10 @@ OC.L10N.register(
     "(all selected)" : "(све изабрано)",
     "({count} selected)" : "(изабрано: {count})",
     "Error loading file exists template" : "Грешка при учитавању шаблона „Фајл постоји“",
-    "Saving …" : "Чувам…",
+    "Saving …" : "Чувам …",
+    "Groups" : "Групе",
+    "Group list is empty" : "Списак група је празан",
+    "Unable to retrieve the group list" : "Не могу да добавим списак група",
     "seconds ago" : "пре пар секунди",
     "Connection to server lost" : "Изгубљена је веза са сервером",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Грешка приликом учитавања стране, пробам поново за %n секунду","Грешка приликом учитавања стране, пробам поново за %n секунде","Грешка приликом учитавања стране, пробам поново за %n секунди"],
@@ -408,17 +420,8 @@ OC.L10N.register(
     "Type to search for existing projects" : "Крените да куцате да тражите постојеће пројекте",
     "New in" : "Ново у",
     "View changelog" : "Погледајте дневник измена",
-    "No action available" : "Нема доступне радње",
-    "Error fetching contact actions" : "Грешка приликом дохватања акција над контактима",
     "Close \"{dialogTitle}\" dialog" : "Затвори дијалог „{dialogTitle}”",
     "Email length is at max (255)" : "Дужина и-мејла је максимална (255)",
-    "Non-existing tag #{tag}" : "Непостојећа ознака #{tag}",
-    "Restricted" : "Ограничена",
-    "Invisible" : "Невидљива",
-    "Delete" : "Обриши",
-    "Rename" : "Преименуј",
-    "Collaborative tags" : "Oзнаке сарадње",
-    "No tags found" : "Ознаке нису нађене",
     "Clipboard not available, please copy manually" : "Клипборд није доступан, молимо вас да ручно копирате",
     "Personal" : "Лично",
     "Accounts" : "Налози",
@@ -453,18 +456,6 @@ OC.L10N.register(
     "Skip to navigation of app" : "Прескочи на навигацију апликације",
     "Go to %s" : "Иди на %s",
     "Get your own free account" : "Узмите бесплатан налог",
-    "Connect to your account" : "Повежите се на Ваш налог",
-    "Please log in before granting %1$s access to your %2$s account." : "Прво се пријавите пре него што одобрите привилегију %1$s приступ Вашем налогу %2$s.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Ако не покушавате да подесите нови уређај или апликацију, неко покушава да Вас превари да му дате приступ Вашим подацима. У том случају, не настављајте и контактирајте администратора Вашег система.",
-    "App password" : "Лозинка апликације",
-    "Grant access" : "Одобри приступ",
-    "Alternative log in using app password" : "Алтернативна пријава коришћењем лозинк апликације",
-    "Account access" : "Приступ налогу",
-    "Currently logged in as %1$s (%2$s)." : "Тренутно пријављен као %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Управо ћете одобрити %1$s приступ Вашем %2$s налогу.",
-    "Account connected" : "Налог повезан",
-    "Your client should now be connected!" : "Ваш клијент сада треба да је повезан!",
-    "You can close this window." : "Можете затворити овај прозор.",
     "Previous" : "Претходно",
     "This share is password-protected" : "Ово дељење је заштићено лозинком",
     "The password is wrong or expired. Please try again or request a new one." : "Лозинка је погрешна или је истекла. Молимо вас да покушате поново, или затражите нову.",
@@ -504,19 +495,41 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Овај %s је тренутно у режиму одржавања што може потрајати.",
     "This page will refresh itself when the instance is available again." : "Ова страница ће се сама освежити када инстанца постане поново доступна.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Контактирајте администратора ако се порука понавља или се неочекивано појавила.",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Ћаскање, видео позиви, дељење екрана, састанци на интернету & веб конференције – на десктоп рачунару и преко мобилних апликација.",
-    "You have not added any info yet" : "Још увек нисте додали никакве информације",
-    "{user} has not added any info yet" : "{user} још увек није унео никакве информације",
-    "Error opening the user status modal, try hard refreshing the page" : "Грешка приликом отварања модалног прозора за статус корисника, покушајте да освежите страну уз брисање кеша",
-    "Edit Profile" : "Уреди профил",
-    "The headline and about sections will show up here" : "Овде ће се појавити насловна линија и одељак „о”",
+    "Error occurred while checking server setup" : "Дошло је до грешке при провери поставки сервера",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "За више детаља погледајте {linkstart}документацију ↗{linkend}.",
+    "unknown text" : "непознат текст",
+    "Hello world!" : "Здраво свете!",
+    "sunny" : "сунчано",
+    "Hello {name}, the weather is {weather}" : "Здраво {name}, време је {weather}",
+    "Hello {name}" : "Здраво {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Ово су резултати Ваше претраге<script>alert(1)</script></strong>",
+    "new" : "ново",
+    "_download %n file_::_download %n files_" : ["преузми %n фајл","преузми %n фајла","преузми %n фајлова"],
+    "Direct link copied to clipboard" : "Директни линк је копиран у клипборд",
+    "Searching …" : "Тражим…",
+    "Logging in …" : "Пријављивање …",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Приметили смо више неисправних покушаја пријава са Ваше IP адресе. Следећа пријава ће бити могућа тек за 30 секунди.",
+    "Loading apps …" : "Учитавам апликације…",
+    "Installing apps …" : "Инсталирам апликације…",
+    "Loading your contacts …" : "Учитавам контакте ...",
+    "Looking for {term} …" : "Тражим {term} …",
+    "Search contacts …" : "Претражи контакте ...",
+    "Loading more results …" : "Учитавам још резултата…",
+    "Search {types} …" : "Претражи {types}…",
+    "Saving …" : "Чувам…",
     "Very weak password" : "Веома слаба лозинка",
     "Weak password" : "Слаба лозинка",
     "So-so password" : "Осредња лозинка",
     "Good password" : "Добра лозинка",
     "Strong password" : "Јака лозинка",
-    "Profile not found" : "Није пронађен профил",
-    "The profile does not exist." : "Профил не постоји.",
+    "No action available" : "Нема доступне радње",
+    "Error fetching contact actions" : "Грешка приликом дохватања акција над контактима",
+    "Non-existing tag #{tag}" : "Непостојећа ознака #{tag}",
+    "Restricted" : "Ограничена",
+    "Delete" : "Обриши",
+    "Rename" : "Преименуј",
+    "Collaborative tags" : "Oзнаке сарадње",
+    "No tags found" : "Ознаке нису нађене",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Ваш директоријум са подацима и фајлови су вероватно доступни са интернета јер .htaccess не ради.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "За информације како да правилно подесите Ваш сервер, погледајте <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">документацију</a>.",
     "<strong>Create an admin account</strong>" : " <strong>Направи административни налог</strong>",
@@ -527,6 +540,9 @@ OC.L10N.register(
     "Configure the database" : "Подешавање базе",
     "Only %s is available." : "Само %s је доступна.",
     "Database account" : "Налог базе података",
-    "Direct link copied to clipboard" : "Директни линк је копиран у клипборд"
+    "Installing …" : "Инсталирам ...",
+    "Please log in before granting %1$s access to your %2$s account." : "Прво се пријавите пре него што одобрите привилегију %1$s приступ Вашем налогу %2$s.",
+    "Currently logged in as %1$s (%2$s)." : "Тренутно пријављен као %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Управо ћете одобрити %1$s приступ Вашем %2$s налогу."
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
