@@ -1,95 +1,59 @@
 <?php
-/**
- * @copyright Copyright (c) 2016, ownCloud, Inc.
- *
- * @author Arthur Schiwon <blizzz@arthur-schiwon.de>
- * @author Bart Visscher <bartv@thisnet.nl>
- * @author Björn Schießle <bjoern@schiessle.org>
- * @author Frank Karlitschek <frank@karlitschek.de>
- * @author Georg Ehrke <oc.list@georgehrke.com>
- * @author Individual IT Services <info@individual-it.net>
- * @author Jens-Christian Fischer <jens-christian.fischer@switch.ch>
- * @author Joas Schilling <coding@schilljs.com>
- * @author Julius Härtl <jus@bitgrid.net>
- * @author Lukas Reschke <lukas@statuscode.ch>
- * @author Michael Gapczynski <GapczynskiM@gmail.com>
- * @author Morris Jobke <hey@morrisjobke.de>
- * @author Nicolas Grekas <nicolas.grekas@gmail.com>
- * @author Pellaeon Lin <nfsmwlin@gmail.com>
- * @author Randolph Carter <RandolphCarter@fantasymail.de>
- * @author Robin Appelman <robin@icewind.nl>
- * @author Robin McCorkell <robin@mccorkell.me.uk>
- * @author Roeland Jago Douma <roeland@famdouma.nl>
- * @author Stefan Herbrechtsmeier <stefan@herbrechtsmeier.net>
- * @author Thomas Müller <thomas.mueller@tmit.eu>
- * @author Thomas Tanghus <thomas@tanghus.net>
- * @author Victor Dubiniuk <dubiniuk@owncloud.com>
- * @author Vincent Petry <pvince81@owncloud.com>
- *
- * @license AGPL-3.0
- *
- * This code is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License, version 3,
- * along with this program.  If not, see <http://www.gnu.org/licenses/>
- *
- */
 
 /**
- * Public interface of ownCloud for apps to use.
- * Utility Class.
- *
+ * SPDX-FileCopyrightText: 2016-2024 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2016 ownCloud, Inc.
+ * SPDX-License-Identifier: AGPL-3.0-only
  */
-
 // use OCP namespace for all classes that are considered public.
-// This means that they should be used by apps instead of the internal ownCloud classes
+// This means that they should be used by apps instead of the internal Nextcloud classes
+
 namespace OCP;
 
+use bantu\IniGetWrapper\IniGetWrapper;
+use OC\AppScriptDependency;
+use OC\AppScriptSort;
+use OC\Security\CSRF\CsrfTokenManager;
+use OCP\L10N\IFactory;
+use OCP\Mail\IMailer;
+use OCP\Share\IManager;
+use Psr\Container\ContainerExceptionInterface;
+
 /**
  * This class provides different helper functions to make the life of a developer easier
+ *
  * @since 4.0.0
  */
 class Util {
-	/**
-	 * @deprecated 14.0.0 use \OCP\ILogger::DEBUG
-	 */
-	const DEBUG=0;
-	/**
-	 * @deprecated 14.0.0 use \OCP\ILogger::INFO
-	 */
-	const INFO=1;
-	/**
-	 * @deprecated 14.0.0 use \OCP\ILogger::WARN
-	 */
-	const WARN=2;
-	/**
-	 * @deprecated 14.0.0 use \OCP\ILogger::ERROR
-	 */
-	const ERROR=3;
-	/**
-	 * @deprecated 14.0.0 use \OCP\ILogger::FATAL
-	 */
-	const FATAL=4;
+	private static ?IManager $shareManager = null;
 
-	/** \OCP\Share\IManager */
-	private static $shareManager;
+	private static array $scriptsInit = [];
+	private static array $scripts = [];
+	private static array $scriptDeps = [];
 
 	/**
 	 * get the current installed version of Nextcloud
 	 * @return array
 	 * @since 4.0.0
+	 * @deprecated 31.0.0 Use \OCP\ServerVersion::getVersion
 	 */
 	public static function getVersion() {
-		return \OC_Util::getVersion();
+		return Server::get(ServerVersion::class)->getVersion();
 	}
-	
+
+	/**
+	 * @since 17.0.0
+	 */
+	public static function hasExtendedSupport(): bool {
+		try {
+			/** @var \OCP\Support\Subscription\IRegistry */
+			$subscriptionRegistry = Server::get(\OCP\Support\Subscription\IRegistry::class);
+			return $subscriptionRegistry->delegateHasExtendedSupport();
+		} catch (ContainerExceptionInterface $e) {
+		}
+		return \OC::$server->getConfig()->getSystemValueBool('extendedSupport', false);
+	}
+
 	/**
 	 * Set current update channel
 	 * @param string $channel
@@ -98,39 +62,15 @@ class Util {
 	public static function setChannel($channel) {
 		\OC::$server->getConfig()->setSystemValue('updater.release.channel', $channel);
 	}
-	
+
 	/**
 	 * Get current update channel
 	 * @return string
 	 * @since 8.1.0
+	 * @deprecated 31.0.0 Use \OCP\ServerVersion::getChannel
 	 */
 	public static function getChannel() {
-		return \OC_Util::getChannel();
-	}
-
-	/**
-	 * write a message in the log
-	 * @param string $app
-	 * @param string $message
-	 * @param int $level
-	 * @since 4.0.0
-	 * @deprecated 13.0.0 use log of \OCP\ILogger
-	 */
-	public static function writeLog( $app, $message, $level ) {
-		$context = ['app' => $app];
-		\OC::$server->getLogger()->log($level, $message, $context);
-	}
-
-	/**
-	 * write exception into the log
-	 * @param string $app app name
-	 * @param \Exception $ex exception to log
-	 * @param int $level log level, defaults to \OCP\Util::FATAL
-	 * @since ....0.0 - parameter $level was added in 7.0.0
-	 * @deprecated 8.2.0 use logException of \OCP\ILogger
-	 */
-	public static function logException( $app, \Exception $ex, $level = ILogger::FATAL) {
-		\OC::$server->getLogger()->logException($ex, ['app' => $app]);
+		return \OCP\Server::get(ServerVersion::class)->getChannel();
 	}
 
 	/**
@@ -138,11 +78,11 @@ class Util {
 	 *
 	 * @return boolean
 	 * @since 7.0.0
-	 * @deprecated 9.1.0 Use \OC::$server->getShareManager()->sharingDisabledForUser
+	 * @deprecated 9.1.0 Use \OC::$server->get(\OCP\Share\IManager::class)->sharingDisabledForUser
 	 */
 	public static function isSharingDisabledForUser() {
 		if (self::$shareManager === null) {
-			self::$shareManager = \OC::$server->getShareManager();
+			self::$shareManager = \OC::$server->get(IManager::class);
 		}
 
 		$user = \OC::$server->getUserSession()->getUser();
@@ -155,13 +95,10 @@ class Util {
 
 	/**
 	 * get l10n object
-	 * @param string $application
-	 * @param string|null $language
-	 * @return \OCP\IL10N
 	 * @since 6.0.0 - parameter $language was added in 8.0.0
 	 */
-	public static function getL10N($application, $language = null) {
-		return \OC::$server->getL10N($application, $language);
+	public static function getL10N(string $application, ?string $language = null): IL10N {
+		return Server::get(\OCP\L10N\IFactory::class)->get($application, $language);
 	}
 
 	/**
@@ -170,28 +107,122 @@ class Util {
 	 * @param string $file
 	 * @since 4.0.0
 	 */
-	public static function addStyle( $application, $file = null ) {
-		\OC_Util::addStyle( $application, $file );
+	public static function addStyle($application, $file = null) {
+		\OC_Util::addStyle($application, $file);
+	}
+
+	/**
+	 * Add a standalone init js file that is loaded for initialization
+	 *
+	 * Be careful loading scripts using this method as they are loaded early
+	 * and block the initial page rendering. They should not have dependencies
+	 * on any other scripts than core-common and core-main.
+	 *
+	 * @since 28.0.0
+	 */
+	public static function addInitScript(string $application, string $file): void {
+		if (!empty($application)) {
+			$path = "$application/js/$file";
+		} else {
+			$path = "js/$file";
+		}
+
+		// We need to handle the translation BEFORE the init script
+		// is loaded, as the init script might use translations
+		if ($application !== 'core' && !str_contains($file, 'l10n')) {
+			self::addTranslations($application, null, true);
+		}
+
+		self::$scriptsInit[] = $path;
 	}
 
 	/**
 	 * add a javascript file
+	 *
 	 * @param string $application
-	 * @param string $file
+	 * @param string|null $file
+	 * @param string $afterAppId
+	 * @param bool $prepend
 	 * @since 4.0.0
 	 */
-	public static function addScript( $application, $file = null ) {
-		\OC_Util::addScript( $application, $file );
+	public static function addScript(string $application, ?string $file = null, string $afterAppId = 'core', bool $prepend = false): void {
+		if (!empty($application)) {
+			$path = "$application/js/$file";
+		} else {
+			$path = "js/$file";
+		}
+
+		// Inject js translations if we load a script for
+		// a specific app that is not core, as those js files
+		// need separate handling
+		if ($application !== 'core'
+			&& $file !== null
+			&& !str_contains($file, 'l10n')) {
+			self::addTranslations($application);
+		}
+
+		// store app in dependency list
+		if (!array_key_exists($application, self::$scriptDeps)) {
+			self::$scriptDeps[$application] = new AppScriptDependency($application, [$afterAppId]);
+		} else {
+			self::$scriptDeps[$application]->addDep($afterAppId);
+		}
+
+		if ($prepend) {
+			array_unshift(self::$scripts[$application], $path);
+		} else {
+			self::$scripts[$application][] = $path;
+		}
+	}
+
+	/**
+	 * Return the list of scripts injected to the page
+	 *
+	 * @return array
+	 * @since 24.0.0
+	 */
+	public static function getScripts(): array {
+		// Sort scriptDeps into sortedScriptDeps
+		$scriptSort = \OC::$server->get(AppScriptSort::class);
+		$sortedScripts = $scriptSort->sort(self::$scripts, self::$scriptDeps);
+
+		// Flatten array and remove duplicates
+		$sortedScripts = array_merge([self::$scriptsInit], $sortedScripts);
+		$sortedScripts = array_merge(...array_values($sortedScripts));
+
+		// Override core-common and core-main order
+		if (in_array('core/js/main', $sortedScripts)) {
+			array_unshift($sortedScripts, 'core/js/main');
+		}
+		if (in_array('core/js/common', $sortedScripts)) {
+			array_unshift($sortedScripts, 'core/js/common');
+		}
+
+		return array_unique($sortedScripts);
 	}
 
 	/**
 	 * Add a translation JS file
 	 * @param string $application application id
 	 * @param string $languageCode language code, defaults to the current locale
+	 * @param bool $init whether the translations should be loaded early or not
 	 * @since 8.0.0
 	 */
-	public static function addTranslations($application, $languageCode = null) {
-		\OC_Util::addTranslations($application, $languageCode);
+	public static function addTranslations($application, $languageCode = null, $init = false) {
+		if (is_null($languageCode)) {
+			$languageCode = \OC::$server->get(IFactory::class)->findLanguage($application);
+		}
+		if (!empty($application)) {
+			$path = "$application/l10n/$languageCode";
+		} else {
+			$path = "l10n/$languageCode";
+		}
+
+		if ($init) {
+			self::$scriptsInit[] = $path;
+		} else {
+			self::$scripts[$application][] = $path;
+		}
 	}
 
 	/**
@@ -203,7 +234,7 @@ class Util {
 	 * @param string $text the text content for the element
 	 * @since 4.0.0
 	 */
-	public static function addHeader($tag, $attributes, $text=null) {
+	public static function addHeader($tag, $attributes, $text = null) {
 		\OC_Util::addHeader($tag, $attributes, $text);
 	}
 
@@ -212,11 +243,11 @@ class Util {
 	 * @param string $app app
 	 * @param string $file file
 	 * @param array $args array with param=>value, will be appended to the returned url
-	 * 	The value of $args will be urlencoded
+	 *                    The value of $args will be urlencoded
 	 * @return string the url
 	 * @since 4.0.0 - parameter $args was added in 4.5.0
 	 */
-	public static function linkToAbsolute( $app, $file, $args = array() ) {
+	public static function linkToAbsolute($app, $file, $args = []) {
 		$urlGenerator = \OC::$server->getURLGenerator();
 		return $urlGenerator->getAbsoluteURL(
 			$urlGenerator->linkTo($app, $file, $args)
@@ -229,7 +260,7 @@ class Util {
 	 * @return string the url
 	 * @since 4.0.0
 	 */
-	public static function linkToRemote( $service ) {
+	public static function linkToRemote($service) {
 		$urlGenerator = \OC::$server->getURLGenerator();
 		$remoteBase = $urlGenerator->linkTo('', 'remote.php') . '/' . $service;
 		return $urlGenerator->getAbsoluteURL(
@@ -237,16 +268,6 @@ class Util {
 		);
 	}
 
-	/**
-	 * Creates an absolute url for public use
-	 * @param string $service id
-	 * @return string the url
-	 * @since 4.5.0
-	 */
-	public static function linkToPublic($service) {
-		return \OC_Helper::linkToPublic($service);
-	}
-
 	/**
 	 * Returns the server host name without an eventual port number
 	 * @return string the server hostname
@@ -256,7 +277,7 @@ class Util {
 		$host_name = \OC::$server->getRequest()->getServerHost();
 		// strip away port number (if existing)
 		$colon_pos = strpos($host_name, ':');
-		if ($colon_pos != FALSE) {
+		if ($colon_pos != false) {
 			$host_name = substr($host_name, 0, $colon_pos);
 		}
 		return $host_name;
@@ -278,41 +299,52 @@ class Util {
 	 * is passed to this function
 	 * @since 5.0.0
 	 */
-	public static function getDefaultEmailAddress($user_part) {
+	public static function getDefaultEmailAddress(string $user_part): string {
 		$config = \OC::$server->getConfig();
-		$user_part = $config->getSystemValue('mail_from_address', $user_part);
+		$user_part = $config->getSystemValueString('mail_from_address', $user_part);
 		$host_name = self::getServerHostName();
-		$host_name = $config->getSystemValue('mail_domain', $host_name);
-		$defaultEmailAddress = $user_part.'@'.$host_name;
+		$host_name = $config->getSystemValueString('mail_domain', $host_name);
+		$defaultEmailAddress = $user_part . '@' . $host_name;
 
-		$mailer = \OC::$server->getMailer();
+		$mailer = \OC::$server->get(IMailer::class);
 		if ($mailer->validateMailAddress($defaultEmailAddress)) {
 			return $defaultEmailAddress;
 		}
 
 		// in case we cannot build a valid email address from the hostname let's fallback to 'localhost.localdomain'
-		return $user_part.'@localhost.localdomain';
+		return $user_part . '@localhost.localdomain';
+	}
+
+	/**
+	 * Converts string to int of float depending if it fits an int
+	 * @param numeric-string|float|int $number numeric string
+	 * @return int|float int if it fits, float if it is too big
+	 * @since 26.0.0
+	 */
+	public static function numericToNumber(string|float|int $number): int|float {
+		/* This is a hack to cast to (int|float) */
+		return 0 + (string)$number;
 	}
 
 	/**
 	 * Make a human file size (2048 to 2 kB)
-	 * @param int $bytes file size in bytes
+	 * @param int|float $bytes file size in bytes
 	 * @return string a human readable file size
 	 * @since 4.0.0
 	 */
-	public static function humanFileSize($bytes) {
+	public static function humanFileSize(int|float $bytes): string {
 		return \OC_Helper::humanFileSize($bytes);
 	}
 
 	/**
 	 * Make a computer file size (2 kB to 2048)
 	 * @param string $str file size in a fancy format
-	 * @return float a file size in bytes
+	 * @return false|int|float a file size in bytes
 	 *
-	 * Inspired by: http://www.php.net/manual/en/function.filesize.php#92418
+	 * Inspired by: https://www.php.net/manual/en/function.filesize.php#92418
 	 * @since 4.0.0
 	 */
-	public static function computerFileSize($str) {
+	public static function computerFileSize(string $str): false|int|float {
 		return \OC_Helper::computerFileSize($str);
 	}
 
@@ -329,8 +361,9 @@ class Util {
 	 *
 	 * TODO: write example
 	 * @since 4.0.0
+	 * @deprecated 21.0.0 use \OCP\EventDispatcher\IEventDispatcher::addListener
 	 */
-	static public function connectHook($signalClass, $signalName, $slotClass, $slotName) {
+	public static function connectHook($signalClass, $signalName, $slotClass, $slotName) {
 		return \OC_Hook::connect($signalClass, $signalName, $slotClass, $slotName);
 	}
 
@@ -343,8 +376,9 @@ class Util {
 	 *
 	 * TODO: write example
 	 * @since 4.0.0
+	 * @deprecated 21.0.0 use \OCP\EventDispatcher\IEventDispatcher::dispatchTypedEvent
 	 */
-	static public function emitHook($signalclass, $signalname, $params = array()) {
+	public static function emitHook($signalclass, $signalname, $params = []) {
 		return \OC_Hook::emit($signalclass, $signalname, $params);
 	}
 
@@ -361,36 +395,20 @@ class Util {
 	 * @since 4.5.0
 	 */
 	public static function callRegister() {
-		if(self::$token === '') {
-			self::$token = \OC::$server->getCsrfTokenManager()->getToken()->getEncryptedValue();
+		if (self::$token === '') {
+			self::$token = \OC::$server->get(CsrfTokenManager::class)->getToken()->getEncryptedValue();
 		}
 		return self::$token;
 	}
 
-	/**
-	 * Check an ajax get/post call if the request token is valid. exit if not.
-	 * @since 4.5.0
-	 * @deprecated 9.0.0 Use annotations based on the app framework.
-	 */
-	public static function callCheck() {
-		if(!\OC::$server->getRequest()->passesStrictCookieCheck()) {
-			header('Location: '.\OC::$WEBROOT);
-			exit();
-		}
-
-		if (!\OC::$server->getRequest()->passesCSRFCheck()) {
-			exit();
-		}
-	}
-
 	/**
 	 * Used to sanitize HTML
 	 *
 	 * This function is used to sanitize HTML and should be applied on any
 	 * string or array of strings before displaying it on a web page.
 	 *
-	 * @param string|array $value
-	 * @return string|array an array of sanitized strings or a single sanitized string, depends on the input parameter.
+	 * @param string|string[] $value
+	 * @return string|string[] an array of sanitized strings or a single sanitized string, depends on the input parameter.
 	 * @since 4.5.0
 	 */
 	public static function sanitizeHTML($value) {
@@ -425,38 +443,6 @@ class Util {
 		return \OC_Helper::mb_array_change_key_case($input, $case, $encoding);
 	}
 
-	/**
-	 * replaces a copy of string delimited by the start and (optionally) length parameters with the string given in replacement.
-	 *
-	 * @param string $string The input string. Opposite to the PHP build-in function does not accept an array.
-	 * @param string $replacement The replacement string.
-	 * @param int $start If start is positive, the replacing will begin at the start'th offset into string. If start is negative, the replacing will begin at the start'th character from the end of string.
-	 * @param int $length Length of the part to be replaced
-	 * @param string $encoding The encoding parameter is the character encoding. Defaults to UTF-8
-	 * @return string
-	 * @since 4.5.0
-	 * @deprecated 8.2.0 Use substr_replace() instead.
-	 */
-	public static function mb_substr_replace($string, $replacement, $start, $length = null, $encoding = 'UTF-8') {
-		return substr_replace($string, $replacement, $start, $length);
-	}
-
-	/**
-	 * Replace all occurrences of the search string with the replacement string
-	 *
-	 * @param string $search The value being searched for, otherwise known as the needle. String.
-	 * @param string $replace The replacement string.
-	 * @param string $subject The string or array being searched and replaced on, otherwise known as the haystack.
-	 * @param string $encoding The encoding parameter is the character encoding. Defaults to UTF-8
-	 * @param int $count If passed, this will be set to the number of replacements performed.
-	 * @return string
-	 * @since 4.5.0
-	 * @deprecated 8.2.0 Use str_replace() instead.
-	 */
-	public static function mb_str_replace($search, $replace, $subject, $encoding = 'UTF-8', &$count = null) {
-		return str_replace($search, $replace, $subject, $count);
-	}
-
 	/**
 	 * performs a search in a nested array
 	 *
@@ -465,6 +451,7 @@ class Util {
 	 * @param mixed $index optional, only search this key name
 	 * @return mixed the key of the matching field, otherwise false
 	 * @since 4.5.0
+	 * @deprecated 15.0.0
 	 */
 	public static function recursiveArraySearch($haystack, $needle, $index = null) {
 		return \OC_Helper::recursiveArraySearch($haystack, $needle, $index);
@@ -474,52 +461,40 @@ class Util {
 	 * calculates the maximum upload size respecting system settings, free space and user quota
 	 *
 	 * @param string $dir the current folder where the user currently operates
-	 * @param int $free the number of bytes free on the storage holding $dir, if not set this will be received from the storage directly
-	 * @return int number of bytes representing
+	 * @param int|float|null $free the number of bytes free on the storage holding $dir, if not set this will be received from the storage directly
+	 * @return int|float number of bytes representing
 	 * @since 5.0.0
 	 */
-	public static function maxUploadFilesize($dir, $free = null) {
+	public static function maxUploadFilesize(string $dir, int|float|null $free = null): int|float {
 		return \OC_Helper::maxUploadFilesize($dir, $free);
 	}
 
 	/**
 	 * Calculate free space left within user quota
 	 * @param string $dir the current folder where the user currently operates
-	 * @return int number of bytes representing
+	 * @return int|float number of bytes representing
 	 * @since 7.0.0
 	 */
-	public static function freeSpace($dir) {
+	public static function freeSpace(string $dir): int|float {
 		return \OC_Helper::freeSpace($dir);
 	}
 
 	/**
 	 * Calculate PHP upload limit
 	 *
-	 * @return int number of bytes representing
+	 * @return int|float number of bytes representing
 	 * @since 7.0.0
 	 */
-	public static function uploadLimit() {
+	public static function uploadLimit(): int|float {
 		return \OC_Helper::uploadLimit();
 	}
 
-	/**
-	 * Returns whether the given file name is valid
-	 * @param string $file file name to check
-	 * @return bool true if the file name is valid, false otherwise
-	 * @deprecated 8.1.0 use \OC\Files\View::verifyPath()
-	 * @since 7.0.0
-	 * @suppress PhanDeprecatedFunction
-	 */
-	public static function isValidFileName($file) {
-		return \OC_Util::isValidFileName($file);
-	}
-
 	/**
 	 * Compare two strings to provide a natural sort
 	 * @param string $a first string to compare
 	 * @param string $b second string to compare
 	 * @return int -1 if $b comes before $a, 1 if $a comes before $b
-	 * or 0 if the strings are identical
+	 *             or 0 if the strings are identical
 	 * @since 7.0.0
 	 */
 	public static function naturalSortCompare($a, $b) {
@@ -527,12 +502,14 @@ class Util {
 	}
 
 	/**
-	 * check if a password is required for each public link
+	 * Check if a password is required for each public link
+	 *
+	 * @param bool $checkGroupMembership Check group membership exclusion
 	 * @return boolean
 	 * @since 7.0.0
 	 */
-	public static function isPublicLinkPasswordRequired() {
-		return \OC_Util::isPublicLinkPasswordRequired();
+	public static function isPublicLinkPasswordRequired(bool $checkGroupMembership = true) {
+		return \OC_Util::isPublicLinkPasswordRequired($checkGroupMembership);
 	}
 
 	/**
@@ -554,18 +531,50 @@ class Util {
 	 */
 	public static function needUpgrade() {
 		if (!isset(self::$needUpgradeCache)) {
-			self::$needUpgradeCache=\OC_Util::needUpgrade(\OC::$server->getSystemConfig());
-		}		
+			self::$needUpgradeCache = \OC_Util::needUpgrade(\OC::$server->getSystemConfig());
+		}
 		return self::$needUpgradeCache;
 	}
 
 	/**
-	 * is this Internet explorer ?
+	 * Sometimes a string has to be shortened to fit within a certain maximum
+	 * data length in bytes. substr() you may break multibyte characters,
+	 * because it operates on single byte level. mb_substr() operates on
+	 * characters, so does not ensure that the shortened string satisfies the
+	 * max length in bytes.
 	 *
-	 * @return boolean
-	 * @since 14.0.0
+	 * For example, json_encode is messing with multibyte characters a lot,
+	 * replacing them with something along "\u1234".
+	 *
+	 * This function shortens the string with by $accuracy (-5) from
+	 * $dataLength characters, until it fits within $dataLength bytes.
+	 *
+	 * @since 23.0.0
 	 */
-	public static function isIe() {
-		return \OC_Util::isIe();
+	public static function shortenMultibyteString(string $subject, int $dataLength, int $accuracy = 5): string {
+		$temp = mb_substr($subject, 0, $dataLength);
+		// json encodes encapsulates the string in double quotes, they need to be substracted
+		while ((strlen(json_encode($temp)) - 2) > $dataLength) {
+			$temp = mb_substr($temp, 0, -$accuracy);
+		}
+		return $temp;
+	}
+
+	/**
+	 * Check if a function is enabled in the php configuration
+	 *
+	 * @since 25.0.0
+	 */
+	public static function isFunctionEnabled(string $functionName): bool {
+		if (!function_exists($functionName)) {
+			return false;
+		}
+		$ini = Server::get(IniGetWrapper::class);
+		$disabled = explode(',', $ini->get('disable_functions') ?: '');
+		$disabled = array_map('trim', $disabled);
+		if (in_array($functionName, $disabled)) {
+			return false;
+		}
+		return true;
 	}
 }
